import argparse
import os
import os.path
import random
import select
import socket
import sys

__version__ = "0.2.2"

parser = argparse.ArgumentParser()
parser.add_argument(
    "-v", "--version", help="Print version and exit", action="store_true", default=False
)
parser.add_argument(
    "--root",
    help="File root - a `nouns.txt` and `adjectives.txt` must be found here.",
    default=os.path.dirname(os.path.abspath(__file__)),
)
parser.add_argument(
    "--host",
    help="Host or IP address to listen on",
    default=os.environ.get("HOST", "0.0.0.0"),
)
parser.add_argument(
    "--port", help="Port to listen on", type=int, default=os.environ.get("PORT", 8000)
)
parser.add_argument(
    "--launch",
    choices=("single", "select", "epoll"),
    help="The type of server to run.",
    default="single",
)
parser.add_argument(
    "--one",
    action="store_true",
    default=False,
    help="Only generate a single passphrase on the command line.",
)

#  {{{ Nouns
NOUNS = [
    "aardvark",
    "abyssinian",
    "accelerator",
    "accordion",
    "account",
    "accountant",
    "acknowledgment",
    "acoustic",
    "acrylic",
    "act",
    "action",
    "active",
    "activity",
    "actor",
    "actress",
    "adapter",
    "addition",
    "address",
    "adjustment",
    "adult",
    "advantage",
    "advertisement",
    "advice",
    "afghanistan",
    "africa",
    "aftermath",
    "afternoon",
    "aftershave",
    "afterthought",
    "age",
    "agenda",
    "agreement",
    "air",
    "airbus",
    "airmail",
    "airplane",
    "airport",
    "airship",
    "alarm",
    "albatross",
    "alcohol",
    "algebra",
    "algeria",
    "alibi",
    "alley",
    "alligator",
    "alloy",
    "almanac",
    "alphabet",
    "alto",
    "aluminium",
    "aluminum",
    "ambulance",
    "america",
    "amount",
    "amusement",
    "anatomy",
    "anethesiologist",
    "anger",
    "angle",
    "angora",
    "animal",
    "anime",
    "ankle",
    "answer",
    "ant",
    "antarctica",
    "anteater",
    "antelope",
    "anthony",
    "anthropology",
    "apartment",
    "apology",
    "apparatus",
    "apparel",
    "appeal",
    "appendix",
    "apple",
    "appliance",
    "approval",
    "april",
    "aquarius",
    "arch",
    "archaeology",
    "archeology",
    "archer",
    "architecture",
    "area",
    "argentina",
    "argument",
    "aries",
    "arithmetic",
    "arm",
    "armadillo",
    "armchair",
    "armenian",
    "army",
    "arrow",
    "art",
    "ash",
    "ashtray",
    "asia",
    "asparagus",
    "asphalt",
    "asterisk",
    "astronomy",
    "athlete",
    "atm",
    "atom",
    "attack",
    "attempt",
    "attention",
    "attic",
    "attraction",
    "august",
    "aunt",
    "australia",
    "australian",
    "author",
    "authorisation",
    "authority",
    "authorization",
    "avenue",
    "babies",
    "baboon",
    "baby",
    "back",
    "backbone",
    "bacon",
    "badge",
    "badger",
    "bag",
    "bagel",
    "bagpipe",
    "bail",
    "bait",
    "baker",
    "bakery",
    "balance",
    "balinese",
    "ball",
    "balloon",
    "bamboo",
    "banana",
    "band",
    "bandana",
    "bangladesh",
    "bangle",
    "banjo",
    "bank",
    "bankbook",
    "banker",
    "bar",
    "barbara",
    "barber",
    "barge",
    "baritone",
    "barometer",
    "base",
    "baseball",
    "basement",
    "basin",
    "basket",
    "basketball",
    "bass",
    "bassoon",
    "bat",
    "bath",
    "bathroom",
    "bathtub",
    "battery",
    "battle",
    "bay",
    "beach",
    "bead",
    "beam",
    "bean",
    "bear",
    "beard",
    "beast",
    "beat",
    "beautician",
    "beauty",
    "beaver",
    "bed",
    "bedroom",
    "bee",
    "beech",
    "beef",
    "beer",
    "beet",
    "beetle",
    "beggar",
    "beginner",
    "begonia",
    "behavior",
    "belgian",
    "belief",
    "believe",
    "bell",
    "belt",
    "bench",
    "bengal",
    "beret",
    "berry",
    "bestseller",
    "betty",
    "bibliography",
    "bicycle",
    "bike",
    "bill",
    "billboard",
    "biology",
    "biplane",
    "birch",
    "bird",
    "birth",
    "birthday",
    "bit",
    "bite",
    "black",
    "bladder",
    "blade",
    "blanket",
    "blinker",
    "blizzard",
    "block",
    "blood",
    "blouse",
    "blow",
    "blowgun",
    "blue",
    "board",
    "boat",
    "bobcat",
    "body",
    "bolt",
    "bomb",
    "bomber",
    "bone",
    "bongo",
    "bonsai",
    "book",
    "bookcase",
    "booklet",
    "boot",
    "border",
    "botany",
    "bottle",
    "bottom",
    "boundary",
    "bow",
    "bowl",
    "bowling",
    "box",
    "boy",
    "bra",
    "brace",
    "bracket",
    "brain",
    "brake",
    "branch",
    "brand",
    "brandy",
    "brass",
    "brazil",
    "bread",
    "break",
    "breakfast",
    "breath",
    "brian",
    "brick",
    "bridge",
    "british",
    "broccoli",
    "brochure",
    "broker",
    "bronze",
    "brother",
    "brother-in-law",
    "brow",
    "brown",
    "brush",
    "bubble",
    "bucket",
    "budget",
    "buffer",
    "buffet",
    "bugle",
    "building",
    "bulb",
    "bull",
    "bulldozer",
    "bumper",
    "bun",
    "burglar",
    "burma",
    "burn",
    "burst",
    "bus",
    "bush",
    "business",
    "butane",
    "butcher",
    "butter",
    "button",
    "buzzard",
    "cabbage",
    "cabinet",
    "cable",
    "cactus",
    "cafe",
    "cake",
    "calculator",
    "calculus",
    "calendar",
    "calf",
    "call",
    "camel",
    "camera",
    "camp",
    "can",
    "canada",
    "canadian",
    "cancer",
    "candle",
    "cannon",
    "canoe",
    "canvas",
    "cap",
    "capital",
    "cappelletti",
    "capricorn",
    "captain",
    "caption",
    "car",
    "caravan",
    "carbon",
    "card",
    "cardboard",
    "cardigan",
    "care",
    "carnation",
    "carol",
    "carp",
    "carpenter",
    "carriage",
    "carrot",
    "cart",
    "cartoon",
    "case",
    "cast",
    "castanet",
    "cat",
    "catamaran",
    "caterpillar",
    "cathedral",
    "catsup",
    "cattle",
    "cauliflower",
    "cause",
    "caution",
    "cave",
    "c-clamp",
    "cd",
    "ceiling",
    "celery",
    "celeste",
    "cell",
    "cellar",
    "cello",
    "celsius",
    "cement",
    "cemetery",
    "cent",
    "centimeter",
    "century",
    "ceramic",
    "cereal",
    "certification",
    "chain",
    "chair",
    "chalk",
    "chance",
    "change",
    "channel",
    "character",
    "chard",
    "charles",
    "chauffeur",
    "check",
    "cheek",
    "cheese",
    "cheetah",
    "chef",
    "chemistry",
    "cheque",
    "cherries",
    "cherry",
    "chess",
    "chest",
    "chick",
    "chicken",
    "chicory",
    "chief",
    "child",
    "children",
    "chill",
    "chime",
    "chimpanzee",
    "chin",
    "china",
    "chinese",
    "chive",
    "chocolate",
    "chord",
    "christmas",
    "christopher",
    "chronometer",
    "church",
    "cicada",
    "cinema",
    "circle",
    "circulation",
    "cirrus",
    "citizenship",
    "city",
    "clam",
    "clarinet",
    "class",
    "claus",
    "clave",
    "clef",
    "clerk",
    "click",
    "client",
    "climb",
    "clipper",
    "cloakroom",
    "clock",
    "close",
    "closet",
    "cloth",
    "cloud",
    "cloudy",
    "clover",
    "club",
    "clutch",
    "coach",
    "coal",
    "coast",
    "coat",
    "cobweb",
    "cockroach",
    "cocktail",
    "cocoa",
    "cod",
    "coffee",
    "coil",
    "coin",
    "coke",
    "cold",
    "collar",
    "college",
    "collision",
    "colombia",
    "colon",
    "colony",
    "color",
    "colt",
    "column",
    "columnist",
    "comb",
    "comfort",
    "comic",
    "comma",
    "command",
    "commission",
    "committee",
    "community",
    "company",
    "comparison",
    "competition",
    "competitor",
    "composer",
    "composition",
    "computer",
    "condition",
    "condor",
    "cone",
    "confirmation",
    "conga",
    "congo",
    "conifer",
    "connection",
    "consonant",
    "continent",
    "control",
    "cook",
    "cooking",
    "copper",
    "copy",
    "copyright",
    "cord",
    "cork",
    "cormorant",
    "corn",
    "cornet",
    "correspondent",
    "cost",
    "cotton",
    "couch",
    "cougar",
    "cough",
    "country",
    "course",
    "court",
    "cousin",
    "cover",
    "cow",
    "cowbell",
    "crab",
    "crack",
    "cracker",
    "craftsman",
    "crate",
    "crawdad",
    "crayfish",
    "crayon",
    "cream",
    "creator",
    "creature",
    "credit",
    "creditor",
    "creek",
    "crib",
    "cricket",
    "crime",
    "criminal",
    "crocodile",
    "crocus",
    "croissant",
    "crook",
    "crop",
    "cross",
    "crow",
    "crowd",
    "crown",
    "crush",
    "cry",
    "cub",
    "cuban",
    "cucumber",
    "cultivator",
    "cup",
    "cupboard",
    "cupcake",
    "curler",
    "currency",
    "current",
    "curtain",
    "curve",
    "cushion",
    "custard",
    "customer",
    "cut",
    "cuticle",
    "cycle",
    "cyclone",
    "cylinder",
    "cymbal",
    "dad",
    "daffodil",
    "dahlia",
    "daisy",
    "damage",
    "dance",
    "dancer",
    "danger",
    "daniel",
    "dash",
    "dashboard",
    "database",
    "date",
    "daughter",
    "david",
    "day",
    "dead",
    "deadline",
    "deal",
    "death",
    "deborah",
    "debt",
    "debtor",
    "decade",
    "december",
    "decimal",
    "decision",
    "decrease",
    "dedication",
    "deer",
    "defense",
    "deficit",
    "degree",
    "delete",
    "delivery",
    "den",
    "denim",
    "dentist",
    "deodorant",
    "department",
    "deposit",
    "description",
    "desert",
    "design",
    "desire",
    "desk",
    "dessert",
    "destruction",
    "detail",
    "detective",
    "development",
    "dew",
    "diamond",
    "diaphragm",
    "dibble",
    "dictionary",
    "dietician",
    "difference",
    "digestion",
    "digger",
    "digital",
    "dill",
    "dime",
    "dimple",
    "dinghy",
    "dinner",
    "dinosaur",
    "diploma",
    "dipstick",
    "direction",
    "dirt",
    "disadvantage",
    "discovery",
    "discussion",
    "disease",
    "disgust",
    "dish",
    "distance",
    "distribution",
    "distributor",
    "diving",
    "division",
    "divorced",
    "dock",
    "doctor",
    "dog",
    "dogsled",
    "doll",
    "dollar",
    "dolphin",
    "domain",
    "donald",
    "donkey",
    "donna",
    "door",
    "dorothy",
    "double",
    "doubt",
    "downtown",
    "dragon",
    "dragonfly",
    "drain",
    "drake",
    "drama",
    "draw",
    "drawbridge",
    "drawer",
    "dream",
    "dredger",
    "dress",
    "dresser",
    "dressing",
    "drill",
    "drink",
    "drive",
    "driver",
    "driving",
    "drizzle",
    "drop",
    "drug",
    "drum",
    "dry",
    "dryer",
    "duck",
    "duckling",
    "dugout",
    "dungeon",
    "dust",
    "eagle",
    "ear",
    "earth",
    "earthquake",
    "ease",
    "east",
    "edge",
    "edger",
    "editor",
    "editorial",
    "education",
    "edward",
    "eel",
    "effect",
    "egg",
    "eggnog",
    "eggplant",
    "egypt",
    "eight",
    "elbow",
    "element",
    "elephant",
    "elizabeth",
    "ellipse",
    "emery",
    "employee",
    "employer",
    "encyclopedia",
    "end",
    "enemy",
    "energy",
    "engine",
    "engineer",
    "engineering",
    "english",
    "enquiry",
    "entrance",
    "environment",
    "epoch",
    "epoxy",
    "equinox",
    "equipment",
    "era",
    "error",
    "estimate",
    "ethernet",
    "ethiopia",
    "euphonium",
    "europe",
    "evening",
    "event",
    "examination",
    "example",
    "exchange",
    "exclamation",
    "exhaust",
    "ex-husband",
    "existence",
    "expansion",
    "experience",
    "expert",
    "explanation",
    "ex-wife",
    "eye",
    "eyebrow",
    "eyelash",
    "eyeliner",
    "face",
    "facilities",
    "fact",
    "factory",
    "fahrenheit",
    "fairies",
    "fall",
    "family",
    "fan",
    "fang",
    "farm",
    "farmer",
    "fat",
    "father",
    "father-in-law",
    "faucet",
    "fear",
    "feast",
    "feather",
    "feature",
    "february",
    "fedelini",
    "feedback",
    "feeling",
    "feet",
    "felony",
    "female",
    "fender",
    "ferry",
    "ferryboat",
    "fertilizer",
    "fiber",
    "fiberglass",
    "fibre",
    "fiction",
    "field",
    "fifth",
    "fight",
    "fighter",
    "file",
    "find",
    "fine",
    "finger",
    "fir",
    "fire",
    "fired",
    "fireman",
    "fireplace",
    "firewall",
    "fish",
    "fisherman",
    "flag",
    "flame",
    "flare",
    "flat",
    "flavor",
    "flax",
    "flesh",
    "flight",
    "flock",
    "flood",
    "floor",
    "flower",
    "flugelhorn",
    "flute",
    "fly",
    "foam",
    "fog",
    "fold",
    "font",
    "food",
    "foot",
    "football",
    "footnote",
    "force",
    "forecast",
    "forehead",
    "forest",
    "forgery",
    "fork",
    "form",
    "format",
    "fortnight",
    "foundation",
    "fountain",
    "fowl",
    "fox",
    "foxglove",
    "fragrance",
    "frame",
    "france",
    "freckle",
    "freeze",
    "freezer",
    "freighter",
    "french",
    "freon",
    "friction",
    "friday",
    "fridge",
    "friend",
    "frog",
    "front",
    "frost",
    "frown",
    "fruit",
    "fuel",
    "fur",
    "furniture",
    "galley",
    "gallon",
    "game",
    "gander",
    "garage",
    "garden",
    "garlic",
    "gas",
    "gasoline",
    "gate",
    "gateway",
    "gauge",
    "gazelle",
    "gear",
    "gearshift",
    "geese",
    "gemini",
    "gender",
    "geography",
    "geology",
    "geometry",
    "george",
    "geranium",
    "german",
    "germany",
    "ghana",
    "ghost",
    "giant",
    "giraffe",
    "girdle",
    "girl",
    "gladiolus",
    "glass",
    "glider",
    "gliding",
    "glockenspiel",
    "glove",
    "glue",
    "goal",
    "goat",
    "gold",
    "goldfish",
    "golf",
    "gondola",
    "gong",
    "good-bye",
    "goose",
    "gore-tex",
    "gorilla",
    "gosling",
    "government",
    "governor",
    "grade",
    "grain",
    "gram",
    "granddaughter",
    "grandfather",
    "grandmother",
    "grandson",
    "grape",
    "graphic",
    "grass",
    "grasshopper",
    "gray",
    "grease",
    "great-grandfather",
    "great-grandmother",
    "greece",
    "greek",
    "green",
    "grenade",
    "grey",
    "grill",
    "grip",
    "ground",
    "group",
    "grouse",
    "growth",
    "guarantee",
    "guatemalan",
    "guide",
    "guilty",
    "guitar",
    "gum",
    "gun",
    "gym",
    "gymnast",
    "hacksaw",
    "hail",
    "hair",
    "haircut",
    "half-brother",
    "half-sister",
    "halibut",
    "hall",
    "hallway",
    "hamburger",
    "hammer",
    "hamster",
    "hand",
    "handball",
    "handicap",
    "handle",
    "handsaw",
    "harbor",
    "hardboard",
    "hardcover",
    "hardhat",
    "hardware",
    "harmonica",
    "harmony",
    "harp",
    "hat",
    "hate",
    "hawk",
    "head",
    "headlight",
    "headline",
    "health",
    "hearing",
    "heart",
    "heat",
    "heaven",
    "hedge",
    "height",
    "helen",
    "helicopter",
    "helium",
    "hell",
    "helmet",
    "help",
    "hemp",
    "hen",
    "heron",
    "herring",
    "hexagon",
    "hill",
    "himalayan",
    "hip",
    "hippopotamus",
    "history",
    "hobbies",
    "hockey",
    "hoe",
    "hole",
    "holiday",
    "home",
    "honey",
    "hood",
    "hook",
    "hope",
    "horn",
    "horse",
    "hose",
    "hospital",
    "hot",
    "hour",
    "hourglass",
    "house",
    "hovercraft",
    "hub",
    "hubcap",
    "humidity",
    "humor",
    "hurricane",
    "hyacinth",
    "hydrant",
    "hydrofoil",
    "hydrogen",
    "hyena",
    "hygienic",
    "ice",
    "icebreaker",
    "icicle",
    "icon",
    "idea",
    "ikebana",
    "illegal",
    "imprisonment",
    "improvement",
    "impulse",
    "inch",
    "income",
    "increase",
    "index",
    "india",
    "indonesia",
    "industry",
    "ink",
    "innocent",
    "input",
    "insect",
    "instruction",
    "instrument",
    "insulation",
    "insurance",
    "interactive",
    "interest",
    "internet",
    "interviewer",
    "intestine",
    "invention",
    "inventory",
    "invoice",
    "iran",
    "iraq",
    "iris",
    "iron",
    "island",
    "israel",
    "italian",
    "italy",
    "jacket",
    "jaguar",
    "jail",
    "jam",
    "james",
    "january",
    "japan",
    "japanese",
    "jar",
    "jasmine",
    "jason",
    "jaw",
    "jeans",
    "jeep",
    "jeff",
    "jelly",
    "jellyfish",
    "jennifer",
    "jet",
    "jewel",
    "jogging",
    "john",
    "join",
    "joke",
    "joseph",
    "journey",
    "judge",
    "judo",
    "juice",
    "july",
    "jumbo",
    "jump",
    "jumper",
    "june",
    "jury",
    "justice",
    "jute",
    "kale",
    "kamikaze",
    "kangaroo",
    "karate",
    "karen",
    "kayak",
    "kendo",
    "kenneth",
    "kenya",
    "ketchup",
    "kettle",
    "kettledrum",
    "kevin",
    "key",
    "keyboard",
    "keyboarding",
    "kick",
    "kidney",
    "kilogram",
    "kilometer",
    "kimberly",
    "kiss",
    "kitchen",
    "kite",
    "kitten",
    "kitty",
    "knee",
    "knickers",
    "knife",
    "knight",
    "knot",
    "knowledge",
    "kohlrabi",
    "korean",
    "laborer",
    "lace",
    "ladybug",
    "lake",
    "lamb",
    "lamp",
    "lan",
    "land",
    "landmine",
    "language",
    "larch",
    "lasagna",
    "latency",
    "latex",
    "lathe",
    "laugh",
    "laundry",
    "laura",
    "law",
    "lawyer",
    "layer",
    "lead",
    "leaf",
    "learning",
    "leather",
    "leek",
    "leg",
    "legal",
    "lemonade",
    "lentil",
    "leo",
    "leopard",
    "letter",
    "lettuce",
    "level",
    "libra",
    "library",
    "license",
    "lier",
    "lift",
    "light",
    "lightning",
    "lilac",
    "lily",
    "limit",
    "linda",
    "line",
    "linen",
    "link",
    "lion",
    "lip",
    "lipstick",
    "liquid",
    "liquor",
    "lisa",
    "list",
    "literature",
    "litter",
    "liver",
    "lizard",
    "llama",
    "loaf",
    "loan",
    "lobster",
    "lock",
    "locket",
    "locust",
    "look",
    "loss",
    "lotion",
    "love",
    "low",
    "lumber",
    "lunch",
    "lunchroom",
    "lung",
    "lunge",
    "lute",
    "luttuce",
    "lycra",
    "lynx",
    "lyocell",
    "lyre",
    "lyric",
    "macaroni",
    "machine",
    "macrame",
    "magazine",
    "magic",
    "magician",
    "maid",
    "mail",
    "mailbox",
    "mailman",
    "makeup",
    "malaysia",
    "male",
    "mall",
    "mallet",
    "man",
    "manager",
    "mandolin",
    "manicure",
    "manx",
    "map",
    "maple",
    "maraca",
    "marble",
    "march",
    "margaret",
    "margin",
    "maria",
    "marimba",
    "mark",
    "market",
    "married",
    "mary",
    "mascara",
    "mask",
    "mass",
    "match",
    "math",
    "mattock",
    "may",
    "mayonnaise",
    "meal",
    "measure",
    "meat",
    "mechanic",
    "medicine",
    "meeting",
    "melody",
    "memory",
    "men",
    "menu",
    "mercury",
    "message",
    "metal",
    "meteorology",
    "meter",
    "methane",
    "mexican",
    "mexico",
    "mice",
    "michael",
    "michelle",
    "microwave",
    "middle",
    "mile",
    "milk",
    "milkshake",
    "millennium",
    "millimeter",
    "millisecond",
    "mimosa",
    "mind",
    "mine",
    "minibus",
    "mini-skirt",
    "minister",
    "mint",
    "minute",
    "mirror",
    "missile",
    "mist",
    "mistake",
    "mitten",
    "moat",
    "modem",
    "mole",
    "mom",
    "monday",
    "money",
    "monkey",
    "month",
    "moon",
    "morning",
    "morocco",
    "mosque",
    "mosquito",
    "mother",
    "mother-in-law",
    "motion",
    "motorboat",
    "motorcycle",
    "mountain",
    "mouse",
    "moustache",
    "mouth",
    "move",
    "multi-hop",
    "multimedia",
    "muscle",
    "museum",
    "music",
    "musician",
    "mustard",
    "myanmar",
    "nail",
    "name",
    "nancy",
    "napkin",
    "narcissus",
    "nation",
    "neck",
    "need",
    "needle",
    "neon",
    "nepal",
    "nephew",
    "nerve",
    "nest",
    "net",
    "network",
    "news",
    "newsprint",
    "newsstand",
    "nic",
    "nickel",
    "niece",
    "nigeria",
    "night",
    "nitrogen",
    "node",
    "noise",
    "noodle",
    "north",
    "north america",
    "north korea",
    "norwegian",
    "nose",
    "note",
    "notebook",
    "notify",
    "novel",
    "november",
    "number",
    "numeric",
    "nurse",
    "nut",
    "nylon",
    "oak",
    "oatmeal",
    "objective",
    "oboe",
    "observation",
    "occupation",
    "ocean",
    "ocelot",
    "octagon",
    "octave",
    "october",
    "octopus",
    "odometer",
    "offence",
    "offer",
    "office",
    "oil",
    "okra",
    "olive",
    "onion",
    "open",
    "opera",
    "operation",
    "ophthalmologist",
    "opinion",
    "option",
    "orange",
    "orchestra",
    "orchid",
    "order",
    "organ",
    "organisation",
    "organization",
    "ornament",
    "ostrich",
    "otter",
    "ounce",
    "output",
    "outrigger",
    "oval",
    "oven",
    "overcoat",
    "owl",
    "owner",
    "ox",
    "oxygen",
    "oyster",
    "package",
    "packet",
    "page",
    "pail",
    "pain",
    "paint",
    "pair",
    "pajama",
    "pakistan",
    "palm",
    "pamphlet",
    "pan",
    "pancake",
    "pancreas",
    "panda",
    "pansy",
    "panther",
    "panties",
    "pantry",
    "pants",
    "panty",
    "pantyhose",
    "paper",
    "paperback",
    "parade",
    "parallelogram",
    "parcel",
    "parent",
    "parentheses",
    "park",
    "parrot",
    "parsnip",
    "part",
    "particle",
    "partner",
    "partridge",
    "party",
    "passbook",
    "passenger",
    "passive",
    "pasta",
    "paste",
    "pastor",
    "pastry",
    "patch",
    "path",
    "patient",
    "patio",
    "patricia",
    "paul",
    "payment",
    "pea",
    "peace",
    "peak",
    "peanut",
    "pear",
    "pedestrian",
    "pediatrician",
    "peen",
    "peer-to-peer",
    "pelican",
    "pen",
    "penalty",
    "pencil",
    "pendulum",
    "pentagon",
    "peony",
    "pepper",
    "perch",
    "perfume",
    "period",
    "periodical",
    "peripheral",
    "permission",
    "persian",
    "person",
    "peru",
    "pest",
    "pet",
    "pharmacist",
    "pheasant",
    "philippines",
    "philosophy",
    "phone",
    "physician",
    "piano",
    "piccolo",
    "pickle",
    "picture",
    "pie",
    "pig",
    "pigeon",
    "pike",
    "pillow",
    "pilot",
    "pimple",
    "pin",
    "pine",
    "ping",
    "pink",
    "pint",
    "pipe",
    "pisces",
    "pizza",
    "place",
    "plain",
    "plane",
    "planet",
    "plant",
    "plantation",
    "plaster",
    "plasterboard",
    "plastic",
    "plate",
    "platinum",
    "play",
    "playground",
    "playroom",
    "pleasure",
    "plier",
    "plot",
    "plough",
    "plow",
    "plywood",
    "pocket",
    "poet",
    "point",
    "poison",
    "poland",
    "police",
    "policeman",
    "polish",
    "politician",
    "pollution",
    "polo",
    "polyester",
    "pond",
    "popcorn",
    "poppy",
    "population",
    "porch",
    "porcupine",
    "port",
    "porter",
    "position",
    "possibility",
    "postage",
    "postbox",
    "pot",
    "potato",
    "poultry",
    "pound",
    "powder",
    "power",
    "precipitation",
    "preface",
    "prepared",
    "pressure",
    "price",
    "priest",
    "print",
    "printer",
    "prison",
    "probation",
    "process",
    "processing",
    "produce",
    "product",
    "production",
    "professor",
    "profit",
    "promotion",
    "propane",
    "property",
    "prose",
    "prosecution",
    "protest",
    "protocol",
    "pruner",
    "psychiatrist",
    "psychology",
    "ptarmigan",
    "puffin",
    "pull",
    "puma",
    "pump",
    "pumpkin",
    "punch",
    "punishment",
    "puppy",
    "purchase",
    "purple",
    "purpose",
    "push",
    "pvc",
    "pyjama",
    "pyramid",
    "quail",
    "quality",
    "quart",
    "quarter",
    "quartz",
    "queen",
    "question",
    "quicksand",
    "quiet",
    "quill",
    "quilt",
    "quince",
    "quit",
    "quiver",
    "quotation",
    "rabbi",
    "rabbit",
    "racing",
    "radar",
    "radiator",
    "radio",
    "radish",
    "raft",
    "rail",
    "railway",
    "rain",
    "rainbow",
    "raincoat",
    "rainstorm",
    "rake",
    "ramie",
    "random",
    "range",
    "rat",
    "rate",
    "raven",
    "ravioli",
    "ray",
    "rayon",
    "reaction",
    "reading",
    "reason",
    "receipt",
    "recess",
    "record",
    "recorder",
    "rectangle",
    "red",
    "reduction",
    "refrigerator",
    "refund",
    "regret",
    "reindeer",
    "relation",
    "relative",
    "religion",
    "relish",
    "reminder",
    "repair",
    "replace",
    "report",
    "representative",
    "request",
    "resolution",
    "respect",
    "responsibility",
    "rest",
    "restaurant",
    "result",
    "retailer",
    "revolve",
    "revolver",
    "reward",
    "rhinoceros",
    "rhythm",
    "rice",
    "richard",
    "riddle",
    "rifle",
    "ring",
    "rise",
    "risk",
    "river",
    "riverbed",
    "road",
    "roadway",
    "roast",
    "robert",
    "robin",
    "rock",
    "rocket",
    "rod",
    "roll",
    "romania",
    "romanian",
    "ronald",
    "roof",
    "room",
    "rooster",
    "root",
    "rose",
    "rotate",
    "route",
    "router",
    "rowboat",
    "rub",
    "rubber",
    "rugby",
    "rule",
    "run",
    "russia",
    "russian",
    "rutabaga",
    "ruth",
    "sack",
    "sagittarius",
    "sail",
    "sailboat",
    "sailor",
    "salad",
    "salary",
    "sale",
    "salesman",
    "salmon",
    "salt",
    "sampan",
    "samurai",
    "sand",
    "sandra",
    "sandwich",
    "santa",
    "sarah",
    "sardine",
    "satin",
    "saturday",
    "sauce",
    "saudi arabia",
    "sausage",
    "save",
    "saw",
    "saxophone",
    "scale",
    "scallion",
    "scanner",
    "scarecrow",
    "scarf",
    "scene",
    "scent",
    "schedule",
    "school",
    "science",
    "scissors",
    "scooter",
    "scorpio",
    "scorpion",
    "scraper",
    "screen",
    "screw",
    "screwdriver",
    "sea",
    "seagull",
    "seal",
    "seaplane",
    "search",
    "seashore",
    "season",
    "seat",
    "second",
    "secretary",
    "secure",
    "security",
    "seed",
    "seeder",
    "segment",
    "select",
    "selection",
    "self",
    "semicircle",
    "semicolon",
    "sense",
    "sentence",
    "separated",
    "september",
    "servant",
    "server",
    "session",
    "sex",
    "shade",
    "shadow",
    "shake",
    "shallot",
    "shame",
    "shampoo",
    "shape",
    "share",
    "shark",
    "sharon",
    "shears",
    "sheep",
    "sheet",
    "shelf",
    "shell",
    "shield",
    "shingle",
    "ship",
    "shirt",
    "shock",
    "shoe",
    "shoemaker",
    "shop",
    "shorts",
    "shoulder",
    "shovel",
    "show",
    "shrimp",
    "shrine",
    "siamese",
    "siberian",
    "side",
    "sideboard",
    "sidecar",
    "sidewalk",
    "sign",
    "signature",
    "silica",
    "silk",
    "silver",
    "sing",
    "singer",
    "single",
    "sink",
    "sister",
    "sister-in-law",
    "size",
    "skate",
    "skiing",
    "skill",
    "skin",
    "skirt",
    "sky",
    "slash",
    "slave",
    "sled",
    "sleep",
    "sleet",
    "slice",
    "slime",
    "slip",
    "slipper",
    "slope",
    "smash",
    "smell",
    "smile",
    "smoke",
    "snail",
    "snake",
    "sneeze",
    "snow",
    "snowboarding",
    "snowflake",
    "snowman",
    "snowplow",
    "snowstorm",
    "soap",
    "soccer",
    "society",
    "sociology",
    "sock",
    "soda",
    "sofa",
    "softball",
    "softdrink",
    "software",
    "soil",
    "soldier",
    "son",
    "song",
    "soprano",
    "sort",
    "sound",
    "soup",
    "sousaphone",
    "south africa",
    "south america",
    "south korea",
    "soy",
    "soybean",
    "space",
    "spade",
    "spaghetti",
    "spain",
    "spandex",
    "spark",
    "sparrow",
    "spear",
    "specialist",
    "speedboat",
    "sphere",
    "sphynx",
    "spider",
    "spike",
    "spinach",
    "spleen",
    "sponge",
    "spoon",
    "spot",
    "spring",
    "sprout",
    "spruce",
    "spy",
    "square",
    "squash",
    "squid",
    "squirrel",
    "stage",
    "staircase",
    "stamp",
    "star",
    "start",
    "starter",
    "state",
    "statement",
    "station",
    "statistic",
    "steam",
    "steel",
    "stem",
    "step",
    "step-aunt",
    "step-brother",
    "stepdaughter",
    "step-daughter",
    "step-father",
    "step-grandfather",
    "step-grandmother",
    "stepmother",
    "step-mother",
    "step-sister",
    "stepson",
    "step-son",
    "step-uncle",
    "steven",
    "stew",
    "stick",
    "stinger",
    "stitch",
    "stock",
    "stocking",
    "stomach",
    "stone",
    "stool",
    "stop",
    "stopsign",
    "stopwatch",
    "store",
    "storm",
    "story",
    "stove",
    "stranger",
    "straw",
    "stream",
    "street",
    "streetcar",
    "stretch",
    "string",
    "structure",
    "study",
    "sturgeon",
    "submarine",
    "substance",
    "subway",
    "success",
    "sudan",
    "suede",
    "sugar",
    "suggestion",
    "suit",
    "summer",
    "sun",
    "sunday",
    "sundial",
    "sunflower",
    "sunshine",
    "supermarket",
    "supply",
    "support",
    "surfboard",
    "surgeon",
    "surname",
    "surprise",
    "susan",
    "sushi",
    "swallow",
    "swamp",
    "swan",
    "sweater",
    "sweatshirt",
    "sweatshop",
    "swedish",
    "sweets",
    "swim",
    "swimming",
    "swing",
    "swiss",
    "switch",
    "sword",
    "swordfish",
    "sycamore",
    "syria",
    "syrup",
    "system",
    "table",
    "tablecloth",
    "tabletop",
    "tachometer",
    "tadpole",
    "tail",
    "tailor",
    "taiwan",
    "talk",
    "tank",
    "tanker",
    "tanzania",
    "target",
    "taste",
    "taurus",
    "tax",
    "taxi",
    "taxicab",
    "tea",
    "teacher",
    "teaching",
    "team",
    "technician",
    "teeth",
    "television",
    "teller",
    "temper",
    "temperature",
    "temple",
    "tempo",
    "tendency",
    "tennis",
    "tenor",
    "tent",
    "territory",
    "test",
    "text",
    "textbook",
    "texture",
    "thailand",
    "theater",
    "theory",
    "thermometer",
    "thing",
    "thistle",
    "thomas",
    "thought",
    "thread",
    "thrill",
    "throat",
    "throne",
    "thumb",
    "thunder",
    "thunderstorm",
    "thursday",
    "ticket",
    "tie",
    "tiger",
    "tights",
    "tile",
    "timbale",
    "time",
    "timer",
    "timpani",
    "tin",
    "tip",
    "tire",
    "titanium",
    "title",
    "toad",
    "toast",
    "toe",
    "toenail",
    "toilet",
    "tomato",
    "tom-tom",
    "ton",
    "tongue",
    "tooth",
    "toothbrush",
    "toothpaste",
    "top",
    "tornado",
    "tortellini",
    "tortoise",
    "touch",
    "tower",
    "town",
    "toy",
    "tractor",
    "trade",
    "traffic",
    "trail",
    "train",
    "tramp",
    "transaction",
    "transmission",
    "transport",
    "trapezoid",
    "tray",
    "treatment",
    "tree",
    "trial",
    "triangle",
    "trick",
    "trigonometry",
    "trip",
    "trombone",
    "trouble",
    "trousers",
    "trout",
    "trowel",
    "truck",
    "trumpet",
    "trunk",
    "t-shirt",
    "tsunami",
    "tub",
    "tuba",
    "tuesday",
    "tugboat",
    "tulip",
    "tuna",
    "tune",
    "turkey",
    "turkish",
    "turn",
    "turnip",
    "turnover",
    "turret",
    "turtle",
    "tv",
    "twig",
    "twilight",
    "twine",
    "twist",
    "typhoon",
    "tyvek",
    "uganda",
    "ukraine",
    "ukrainian",
    "umbrella",
    "uncle",
    "underclothes",
    "underpants",
    "undershirt",
    "underwear",
    "unit",
    "united kingdom",
    "unshielded",
    "use",
    "utensil",
    "uzbekistan",
    "vacation",
    "vacuum",
    "valley",
    "value",
    "van",
    "vase",
    "vault",
    "vegetable",
    "vegetarian",
    "veil",
    "vein",
    "velvet",
    "venezuela",
    "venezuelan",
    "verdict",
    "vermicelli",
    "verse",
    "vessel",
    "vest",
    "veterinarian",
    "vibraphone",
    "vietnam",
    "view",
    "vinyl",
    "viola",
    "violet",
    "violin",
    "virgo",
    "viscose",
    "vise",
    "vision",
    "visitor",
    "voice",
    "volcano",
    "volleyball",
    "voyage",
    "vulture",
    "waiter",
    "waitress",
    "walk",
    "wall",
    "wallaby",
    "wallet",
    "walrus",
    "war",
    "warm",
    "wash",
    "washer",
    "wasp",
    "waste",
    "watch",
    "watchmaker",
    "water",
    "waterfall",
    "wave",
    "wax",
    "way",
    "wealth",
    "weapon",
    "weasel",
    "weather",
    "wedge",
    "wednesday",
    "weed",
    "weeder",
    "week",
    "weight",
    "whale",
    "wheel",
    "whip",
    "whiskey",
    "whistle",
    "white",
    "wholesaler",
    "whorl",
    "wilderness",
    "william",
    "willow",
    "wind",
    "windchime",
    "window",
    "windscreen",
    "windshield",
    "wine",
    "wing",
    "winter",
    "wire",
    "wish",
    "witch",
    "withdrawal",
    "witness",
    "wolf",
    "woman",
    "women",
    "wood",
    "wool",
    "woolen",
    "word",
    "work",
    "workshop",
    "worm",
    "wound",
    "wrecker",
    "wren",
    "wrench",
    "wrinkle",
    "wrist",
    "writer",
    "xylophone",
    "yacht",
    "yak",
    "yam",
    "yard",
    "yarn",
    "year",
    "yellow",
    "yew",
    "yogurt",
    "yoke",
    "yugoslavian",
    "zebra",
    "zephyr",
    "zinc",
    "zipper",
    "zone",
    "zoo",
    "zoology",
]
#  }}}

#  {{{ Adjectives
ADJECTIVES = [
    "abaft",
    "abandoned",
    "abased",
    "abashed	",
    "abasic",
    "abbatial",
    "abdicable",
    "abdicant",
    "abdicative",
    "abdominal",
    "abdominous",
    "abducent",
    "aberrant",
    "aberrational",
    "abeyant",
    "abhorrent",
    "abiotic",
    "ablaze",
    "able",
    "able-bodied",
    "ablutophobic",
    "abnormal",
    "abolitionary",
    "abominable",
    "aboriginal",
    "above",
    "aboveground ",
    "abrupt",
    "absent",
    "absent-minded",
    "absolute",
    "absolutistic",
    "abstract",
    "abstracted",
    "absurd",
    "abusive",
    "abysmal",
    "abyssal",
    "academic",
    "academic",
    "academical",
    "acardiac",
    "acceptable",
    "accepted",
    "accessible",
    "acclimatable",
    "acclimatisable",
    "acculturational",
    "acculturative",
    "accurate",
    "accused",
    "achluophobic",
    "achronite",
    "acid",
    "acid-fast",
    "acid-forming",
    "acidic",
    "acidifiable",
    "acidimetric",
    "acidimetrical",
    "acidophilic",
    "acidophobic",
    "acidotic",
    "acidulous",
    "aciduric",
    "acidy",
    "acoustic",
    "acquiescent",
    "acrid",
    "acrobatic",
    "acrophobic",
    "acrylic",
    "actinide",
    "actinium",
    "activated",
    "active",
    "actual",
    "actuarial",
    "actuarian",
    "acute",
    "adamantine",
    "adamantium",
    "added",
    "addictive",
    "additional",
    "addlebrained",
    "adept",
    "adequate",
    "adhesive",
    "adjacent",
    "adjoining",
    "administrative",
    "adobe",
    "adolescent",
    "adorable",
    "adored",
    "adoring",
    "adrenal",
    "adriot",
    "adult",
    "advanced",
    "advantageous",
    "adventureful",
    "adventuresome",
    "adventurous",
    "adversarial",
    "adverse",
    "advertent",
    "aerial",
    "aerobic",
    "aerodynamic",
    "aerodynamical",
    "aeromarine",
    "aeromedical",
    "aeronautic",
    "aeronautical",
    "aerophobic",
    "aesthetic",
    "afeard",
    "affable",
    "affectionate",
    "affirmative",
    "afflicted",
    "affluent",
    "affordable",
    "aforementioned",
    "afraid",
    "agate",
    "agatoid",
    "age-old",
    "aged",
    "ageless",
    "aggressive",
    "aghast",
    "agile",
    "agitable",
    "agitational",
    "agitative",
    "agonizing",
    "agoraphobic",
    "agrarian",
    "agreeable",
    "agreed",
    "agricultural",
    "agrobiologic",
    "agrobiological",
    "agrologic",
    "agrological",
    "agronomic",
    "agronomical",
    "agrostographic",
    "agrostographical",
    "agrostologic",
    "agrostological",
    "ahistoric",
    "ahistorical",
    "aichmophobic",
    "ailing",
    "ailurophilic",
    "ailurophobic",
    "aimless",
    "airborne",
    "airsick",
    "airtight",
    "airworthy",
    "airy",
    "alabaster",
    "alamode",
    "albinic",
    "albinistic",
    "albino",
    "albite",
    "alchemic",
    "alchemistical",
    "alert",
    "algebraic",
    "algophobic",
    "algorithmic",
    "alien",
    "alive",
    "alkalic",
    "alkaline",
    "alkalisable",
    "alkalizable",
    "alkaloidal",
    "alkylic",
    "all-powerful",
    "all-purpose",
    "all-star",
    "allayed",
    "alleged",
    "allegorical",
    "allegoristic",
    "allegro",
    "allergenic",
    "allergic",
    "allied",
    "alliterative",
    "alluring",
    "almond",
    "almondy",
    "alphabetic",
    "alphabetical",
    "alphameric",
    "alphanumeric",
    "alright",
    "alternative",
    "altophobic",
    "altruistic",
    "amaranth",
    "amateur",
    "amateurish",
    "amaxophobic",
    "amazing",
    "amber",
    "amberous",
    "ambery",
    "ambient",
    "ambigious",
    "ambisyllabic",
    "ambitious",
    "ambivalent",
    "amebic",
    "ameboid",
    "amenable",
    "americium",
    "amethyst",
    "amethystine",
    "amiable",
    "amicable",
    "ammoniac",
    "ammoniacal",
    "ammonic",
    "ammonitic",
    "ammonitoid",
    "ammophilic",
    "amnestic",
    "amoebaean",
    "amoebalike",
    "amoebic",
    "amoeboid",
    "amoral",
    "amphibian",
    "amphibiotic",
    "amphibious",
    "amphibole",
    "amphibolic",
    "amphibolite",
    "amphisbaenian",
    "amphisbaenic",
    "amphisbaenoid",
    "amphisbaenous",
    "amphitheatric",
    "amphitheatrical",
    "ample",
    "amputated",
    "amused",
    "amusing",
    "anachronic",
    "anachronistic",
    "anachronous	",
    "anaemic",
    "anaesthetic",
    "analogical",
    "analogistic",
    "analogous",
    "analytical",
    "anarchic",
    "anarchistic",
    "anarthric",
    "anarthrous",
    "anatomical",
    "ancestral",
    "ancient",
    "androgenic",
    "androgenous",
    "androgynous",
    "androphagous",
    "androphilic",
    "anecdotal",
    "anesthetic",
    "angelic",
    "angelic",
    "angry",
    "angst-ridden ",
    "angsty",
    "anguished",
    "angular",
    "anhydrite",
    "animalic",
    "animalistic",
    "animated",
    "animist",
    "animistic",
    "annihilated",
    "annoyed",
    "annoying",
    "anonymous",
    "anorthite",
    "anorthosite",
    "antagonisable",
    "antagonistic",
    "antarctic",
    "antarthritic",
    "antebellum",
    "antediluvian",
    "antelopian",
    "antelopine",
    "anthophilic",
    "anthophobic",
    "anthracite",
    "anthropocentric",
    "anthropoid",
    "anthropoidal",
    "anthropological",
    "anthropomorphic",
    "anthropophobic",
    "anti-capitalist",
    "anti-heroic",
    "antiallergenic",
    "anticapitalist",
    "anticlimactic",
    "antidemocratic",
    "antidemocratical",
    "antidotal",
    "antidotical",
    "antifeminist",
    "antifeministic",
    "antifungal",
    "antigorite",
    "antigovernment",
    "antigovernmental",
    "antigravitation",
    "antigravitational",
    "antihuman",
    "antihumanistic",
    "antihygienic",
    "antimagnetic",
    "antimediaeval",
    "antimedical",
    "antimedication",
    "antimedicative",
    "antimedicine",
    "antimilitaristic",
    "antimilitary",
    "antimonarch",
    "antimonarchal",
    "antimonarchial",
    "antimonarchic",
    "antimonarchical",
    "antimonarchistic",
    "antimonarchy",
    "antimoral",
    "antimoralistic",
    "antimorality",
    "antimystical",
    "antinational",
    "antinationalisation",
    "antinationalistic",
    "antinatural",
    "antinaturalistic",
    "antinihilistic",
    "antioptimistic",
    "antioptimistical",
    "antipacifistic",
    "antipestilence",
    "antipestilent",
    "antipestilential",
    "antiphilosophic",
    "antiphilosophical",
    "antiphilosophy",
    "antipolitical",
    "antipolitics",
    "antiquarian",
    "antiquated",
    "antique",
    "antirational",
    "antirationalistic",
    "antiromance",
    "antiromantic",
    "antischolastic",
    "antischool",
    "antiscience",
    "antiscientific",
    "antisocial",
    "antisolar",
    "antiterrorist",
    "antitoxic",
    "antiutopian",
    "antiutopic",
    "antiviral",
    "antivirus",
    "antsy",
    "anxious",
    "apathetic",
    "apelike",
    "aphidian",
    "aphidious",
    "apian",
    "apiarian",
    "apicultural",
    "apidologic",
    "apidological",
    "apiologic",
    "apiological",
    "apiphobic",
    "apish",
    "apivorous",
    "apocalyptic",
    "apolitical",
    "apostolic",
    "apostrophic",
    "apothecial",
    "appalling",
    "apparent",
    "apparitional",
    "appealing",
    "appercetive",
    "appetitive",
    "appetizing",
    "applicable",
    "appreciative",
    "apprehensive",
    "apprentice",
    "appropriate",
    "apricot",
    "aquamarine",
    "aquaphobic",
    "aquarial",
    "aquatic",
    "aqueous",
    "aquicultural",
    "aquiline",
    "arachnidan",
    "arachnivorous",
    "arachnologic",
    "arachnological",
    "arachnophobic",
    "aragonite",
    "arbitrary",
    "arboraceous",
    "arboreal",
    "arbored",
    "arboreous",
    "arborescent",
    "arboresque",
    "arboricultural",
    "arborous",
    "arcane",
    "archaeological",
    "archaic",
    "archaistic",
    "archangelic",
    "archangelical",
    "archeologic",
    "archeological",
    "archetypal",
    "archetypic",
    "architectural",
    "archival",
    "arctic",
    "arctophilic",
    "ardent",
    "arduous",
    "argumentative",
    "arid",
    "aristocratic",
    "armed",
    "armless",
    "armour-clad",
    "armour-piercing",
    "armoured",
    "armourplated",
    "aromatic",
    "arrogant",
    "arterial",
    "artful",
    "arthralgic",
    "arthritic",
    "arthritical",
    "arthrodial",
    "arthrodic",
    "arthromeric",
    "artificial",
    "artistic",
    "artistic",
    "artless",
    "artsy-craftsy",
    "arty",
    "arty-crafty",
    "asbestine",
    "asbestoid",
    "asbestoidal",
    "asbestos",
    "asbestous",
    "ashamed",
    "ashen",
    "ashy",
    "asinine",
    "asocial",
    "asparaginous",
    "asphalt",
    "asphaltic",
    "asphaltum",
    "aspherical",
    "asphyxiated",
    "aspiring",
    "assertive",
    "assiduous",
    "assistant",
    "associated",
    "associative",
    "astatine",
    "asteria",
    "asthmatic",
    "asthmatoid",
    "astonishing	",
    "astounding",
    "astrakhan",
    "astral",
    "astraphobic",
    "astrapophobic",
    "astrobiological",
    "astrochemical",
    "astrographic",
    "astrolabical",
    "astrological",
    "astromantic",
    "astrometric",
    "astronautic",
    "astronomical",
    "astrophilic",
    "astrophotographic",
    "astrophysical",
    "astute",
    "asyllabic",
    "atheistic",
    "athletic",
    "atmospheric",
    "atomic ",
    "atrocious",
    "atrophic",
    "atrophied",
    "attack",
    "attentive",
    "attractive",
    "atypical",
    "auburn",
    "audacious",
    "audiophilic",
    "augite",
    "augmented",
    "auroral-",
    "aurorean",
    "aurous",
    "auspicial",
    "auspicious",
    "autecologic",
    "autecological",
    "authentic",
    "authorial",
    "authoritarian",
    "authoritative",
    "authorized",
    "autobiographical",
    "autographic",
    "autographical",
    "autoimmune",
    "automatic",
    "automotive",
    "autonomous",
    "autophobic",
    "autositic",
    "autumnal",
    "auxiliary",
    "available",
    "avaricious",
    "avengeful",
    "aventurine",
    "average",
    "avian",
    "aviaphobic",
    "aviophobic",
    "avoided",
    "awake",
    "aware",
    "awe-inspiring",
    "awe-stricken",
    "awe-struck",
    "awesome",
    "awful",
    "awkward",
    "axiomatic",
    "azure",
    "baboonish",
    "baby-faced",
    "babyish",
    "babyx",
    "bacciferous",
    "bacciform",
    "baccivorous",
    "bacillophobic",
    "background",
    "backward",
    "bacterial",
    "bactericidal",
    "bacteriologic",
    "bacteriological",
    "bacteriophobic",
    "bacteroid",
    "bad",
    "bad-tempered",
    "baffling",
    "baggy",
    "bairnish",
    "bairnly",
    "balanced",
    "bald",
    "baldheaded",
    "balding",
    "baldish",
    "baleful",
    "balky",
    "balladic",
    "balmy",
    "balneal",
    "balneologic",
    "balneological",
    "balsamaceous",
    "balsamic",
    "balsamiferous",
    "balsaminaceous",
    "balsamy",
    "banal",
    "baneful",
    "barathea",
    "barbarian",
    "barbaric",
    "barbarous",
    "bardic",
    "bardish",
    "bardlike",
    "bardy",
    "bare",
    "bared",
    "barite",
    "barky",
    "barnacled",
    "baroque",
    "barren",
    "baryte",
    "basalt",
    "basaltic",
    "basaltine",
    "base",
    "baseborn",
    "basehearted",
    "bashful",
    "basic",
    "batiste",
    "battle-scarred",
    "battlesome",
    "batty",
    "beachy",
    "beaming",
    "beamish",
    "beamlike",
    "beamy",
    "beaten",
    "beatific",
    "beauish",
    "beauteous",
    "beautiful",
    "becoming",
    "bediasite",
    "bedridden",
    "beef-witted",
    "beef-wittedly",
    "beefy",
    "beelike",
    "beeswax",
    "befuddled",
    "befuddling",
    "beggarly",
    "beguiling",
    "behavioral",
    "beige",
    "belated",
    "bellicose",
    "belligerent",
    "belocolus",
    "belonephobic",
    "beloved",
    "bemused",
    "beneficent",
    "beneficial",
    "benevolent",
    "benighted",
    "benign",
    "benignant",
    "bereaved",
    "bereft",
    "beribboned",
    "berkelium",
    "berrylike",
    "berserk",
    "beryl",
    "besotted",
    "best",
    "bestial",
    "beton",
    "betrothed",
    "bewildered",
    "bewitched",
    "bewitching",
    "bibliographic",
    "bibliographical",
    "bibliolatrous",
    "bibliological",
    "bibliomaniacal",
    "bibliophagous",
    "bibliophilic",
    "bicolor",
    "big-boned",
    "big-hearted",
    "biggish",
    "bigheaded",
    "bigoted",
    "bilinear",
    "bilineate",
    "bilingual",
    "bimetallic",
    "bimetallistic",
    "binary",
    "binding",
    "bioclimatic",
    "bioclimatological",
    "biodegradable",
    "bioecologic",
    "bioecological",
    "bioeconomic",
    "bioeconomical",
    "biological",
    "biomedical",
    "bionic",
    "biophilic",
    "biotechnological",
    "biotite",
    "bipartisan",
    "bird-brained",
    "birdbrained",
    "birdlike",
    "birthstone",
    "bite-sized",
    "bitter",
    "bitty",
    "bitumen",
    "bixbite",
    "bizarre",
    "black",
    "black-coated",
    "black-hearted",
    "blackish",
    "blamable",
    "blameable",
    "blameful",
    "blameless",
    "blameworthy",
    "bland",
    "blank",
    "blasphemous",
    "bleached",
    "bleak	",
    "bleakish",
    "blear-eyed",
    "bleary",
    "blessed",
    "blind",
    "blissful",
    "blithe",
    "blitheful",
    "blithesome",
    "blizzardly",
    "blizzardy",
    "bloated",
    "blockish",
    "blocky",
    "blond",
    "blonde",
    "blondish",
    "bloodcurdling",
    "bloodshot",
    "bloodsucking",
    "bloodthirsty",
    "blotchy",
    "blousy ",
    "blowsy",
    "blowy",
    "blowzy",
    "blubbery",
    "blue",
    "blue-black",
    "blue-collar",
    "blue-ribbon",
    "bluecoated",
    "blueish",
    "blunt",
    "blushing",
    "blusterous-",
    "boarish",
    "boastful",
    "bohrium",
    "boiled",
    "boiling",
    "bold",
    "bold-faced",
    "boldhearted",
    "bolstered",
    "bombastic",
    "bone-dry",
    "boneheaded",
    "bonelike",
    "bonny",
    "bony",
    "book-learned",
    "bookish",
    "boolean",
    "boorish",
    "bootlicking",
    "boreal",
    "bored",
    "boring",
    "bort",
    "bosky",
    "bossy",
    "botanical",
    "botanic",
    "botchy",
    "bothersome",
    "bottle-green",
    "bottom",
    "bouncy",
    "boundless",
    "bovid",
    "bovine",
    "boyish",
    "braced",
    "braided",
    "brainless",
    "brainsick",
    "brainy",
    "brambly",
    "branny",
    "brashy",
    "brash",
    "brass",
    "brassbound",
    "brassish",
    "brassy",
    "brattish",
    "bratty",
    "brave",
    "braving",
    "brazen",
    "breaded",
    "breakable",
    "breathless",
    "breathtaking",
    "breezelike",
    "breezy",
    "bribable",
    "bribeable",
    "brick",
    "brick-red",
    "brickish",
    "brickred",
    "bricky",
    "bridal",
    "brief",
    "brigandish",
    "bright",
    "brightish",
    "brilliant",
    "brimstone",
    "brimstony",
    "brinish",
    "briny",
    "brisk",
    "brittle",
    "broad",
    "broad-faced",
    "broad-minded",
    "broadish",
    "brocatel",
    "brocatello",
    "broke",
    "broken",
    "broken-down",
    "broken-hearted",
    "brokenhearted",
    "bronchial",
    "brontophobic",
    "bronze",
    "bronze",
    "bronzy",
    "broody",
    "brotherlike",
    "brotherly",
    "brown",
    "brownish",
    "browny",
    "brunette",
    "brusque",
    "brutal",
    "brutalitarian",
    "brutish",
    "bubbly",
    "bubonic",
    "buckskin",
    "buggy",
    "bulletproof",
    "bullish",
    "bulllike",
    "bullous",
    "bumbling",
    "bumpkinish",
    "bumpkinly",
    "bumpy",
    "buoyant",
    "burdensome",
    "bureaucratic",
    "burglarious",
    "burgundy",
    "buried",
    "burlap",
    "burly",
    "burned",
    "burned-out",
    "burning",
    "burnt",
    "bushy",
    "busied",
    "busy",
    "busying",
    "butterfingered",
    "buttery",
    "byzantine",
    "byzantium",
    "cabbagy",
    "cacophonophilic",
    "cacotopic",
    "cactus-like",
    "cactuslike",
    "cadaveric",
    "cadaverous",
    "caffeinated",
    "caffeinic",
    "cagophilic",
    "cainophobic",
    "cainotophobic",
    "calceiform",
    "calciphilic",
    "calciphobic",
    "calcite",
    "calcivorous",
    "calicoed",
    "californium",
    "calligraphic",
    "calligraphical",
    "callous",
    "calm",
    "calmative",
    "calmy",
    "caloric",
    "caloried",
    "calorifacient",
    "calorific",
    "calx",
    "camera-shy",
    "camlet",
    "camoflage",
    "camouflage",
    "campy",
    "cancellable",
    "candid",
    "candied",
    "candy-coated",
    "candy-striped",
    "canine",
    "cankered",
    "cankerous",
    "cannibal",
    "cannibalistic",
    "canophilic",
    "cantankerous",
    "capable",
    "capillary",
    "capitalist",
    "capitalistic",
    "capitate",
    "capless",
    "capricious",
    "capsizable",
    "captious",
    "captivating",
    "captivative",
    "capturable",
    "carbasus",
    "carbon",
    "carbonaceous",
    "carbonic",
    "carboniferous",
    "carbonless",
    "carbonous",
    "carcinogenic",
    "cardboard",
    "cardiac",
    "cardinal",
    "cardiographic",
    "cardiologic",
    "cardiological",
    "cardiotonic",
    "cardiovascular",
    "carefree",
    "careful",
    "careless",
    "caressive",
    "careworn",
    "caring",
    "carmine	",
    "carnauba",
    "carnelian",
    "carneous",
    "carniferous",
    "carnivalesque",
    "carnivallike",
    "carnivoral",
    "carnivorous",
    "carnose",
    "carnous",
    "carping",
    "carriable",
    "carroty",
    "carryable",
    "carsick",
    "cashmere",
    "cast-iron",
    "cast-off",
    "cast-steel",
    "castoff",
    "cataclysmic",
    "catastrophal",
    "catastrophic ",
    "catastrophical",
    "catatonic",
    "catchable",
    "catching",
    "catchy",
    "catechisable",
    "categorical",
    "catlike",
    "catoptrophobic",
    "cattish",
    "cattlehide",
    "catty",
    "cauliflorous-",
    "causable",
    "causational",
    "causative",
    "causeless",
    "caustic",
    "caustical",
    "cautious",
    "cavalier",
    "cavelike",
    "cavernous",
    "cavitied",
    "cayenned",
    "celadon",
    "celebrated",
    "celebrative",
    "celebratory",
    "celestial",
    "celestine",
    "celestite",
    "cell-like",
    "cellular",
    "cement",
    "cementitious",
    "censorable",
    "censorial",
    "censorian",
    "censorious",
    "censual",
    "censurable",
    "censureless",
    "centaurial",
    "centaurian",
    "centauric",
    "centerable",
    "centered",
    "centipedal",
    "centophobic",
    "centralistic",
    "centralized",
    "central",
    "centric",
    "centrifugal",
    "cepevorous",
    "cephalic",
    "cepivorous",
    "ceramic",
    "cerate",
    "cere",
    "cerebellar",
    "cerebral",
    "cerebric",
    "cerebroid",
    "cerebrospinal",
    "cerise",
    "certain",
    "certifiable",
    "certificatory",
    "certified",
    "cerulean",
    "cetologic",
    "cetological",
    "chain-driven",
    "chain-reacting",
    "chalcedony",
    "chalcopyrite",
    "chalk",
    "chalkstony",
    "chalky",
    "challenging",
    "chanceful",
    "chancy",
    "changeable",
    "changeful",
    "chantable",
    "chaotic",
    "characterful",
    "characteristic",
    "characterless",
    "charcoal",
    "charcoaly",
    "chargeable",
    "chargeful",
    "chargeless",
    "charismatic",
    "charityless",
    "charlatanical",
    "charlatanish",
    "charlatanistic",
    "charming",
    "charred",
    "charterable",
    "chartiable",
    "chartreuse",
    "chaseable",
    "chasmophilic",
    "chaste",
    "chattable",
    "chattery",
    "chatty",
    "chauvinist",
    "chauvinistic",
    "cheap",
    "cheatable",
    "checkable",
    "checked",
    "checkered",
    "cheeky",
    "cheerful",
    "cheerless",
    "cheery",
    "cheese-like",
    "cheesecloth",
    "cheesy",
    "chelonaphilic",
    "chemic",
    "chemical",
    "chemophobic",
    "cherishable",
    "cherubic",
    "cherubical",
    "chevrette",
    "chevroned",
    "chewable",
    "chewed",
    "chewy",
    "chiasmic",
    "chic",
    "chicken-hearted",
    "chicken-livered",
    "chief",
    "chiffon",
    "childish",
    "childless",
    "childlike",
    "childly",
    "childproof",
    "childsafe",
    "chilled",
    "chilly",
    "chino",
    "chintzy",
    "chippable",
    "chipper",
    "chiropterophilic",
    "chiroptophobic",
    "chiselled",
    "chitchatty",
    "chivalric",
    "chivalrous",
    "chloroformic",
    "chocolate",
    "chocolatey",
    "chocolaty",
    "choky",
    "choleric",
    "chondrite",
    "choosable",
    "choosey",
    "choosy",
    "choppy",
    "choral",
    "chordal",
    "chordamesodermal",
    "chordamesodermic",
    "chorded",
    "choreographic",
    "chorographic",
    "chorographical",
    "chosen",
    "chromatinic",
    "chromatnic",
    "chromic",
    "chromite",
    "chromium",
    "chromophilic",
    "chromophobic",
    "chromosomal",
    "chronogrammatic",
    "chronogrammatical",
    "chronographic",
    "chronological",
    "chronometric",
    "chronometrical",
    "chrysophilic",
    "chrysoprase",
    "chubby",
    "chuckleheaded",
    "chuffy",
    "chummy",
    "chunky",
    "churchless",
    "churchly",
    "churchy",
    "churlish",
    "churnable",
    "cibophobic",
    "cilia",
    "cilium",
    "cinderlike",
    "cinderous",
    "cindery",
    "cinematic",
    "cinematographic",
    "cinnabar",
    "cinnamic",
    "cinnamoned",
    "cinnamonic",
    "cipolin",
    "circular",
    "circulatory",
    "circumfluent",
    "circumnavigable",
    "circumnavigatory",
    "circumspect",
    "circumstantial",
    "citable",
    "citatory",
    "citeable",
    "citied",
    "citified	",
    "citizenly",
    "citreous",
    "citric",
    "citrine",
    "citylike",
    "civic",
    "civil",
    "civil-law",
    "civilian",
    "civilisable",
    "civilisational",
    "civilisatory",
    "civilized",
    "claimable",
    "clairvoyant",
    "clamlike",
    "clammy",
    "clandestine",
    "clannish",
    "class-conscious",
    "classic",
    "classical",
    "classified ",
    "classless",
    "classy",
    "claustrophilic",
    "claustrophobic",
    "clay",
    "clayey",
    "clayish",
    "clean",
    "clean-cut",
    "clean-faced",
    "clean-handed",
    "clean-limbed",
    "clean-shaven",
    "cleanable",
    "cleansable",
    "clear-cut",
    "clear-eyed",
    "clear-headed",
    "clear-sighted",
    "clearable",
    "clearall",
    "clerical",
    "clerkish",
    "clever",
    "cleverish",
    "cliffy",
    "climactic",
    "climatic",
    "climatologic",
    "climatological",
    "climbing",
    "clingy",
    "clinical",
    "clinophilic",
    "clippable",
    "clockwork",
    "cloddy",
    "cloggy",
    "cloistered",
    "cloned",
    "close-by",
    "close-fitting",
    "close-in",
    "close-knit",
    "closed",
    "close",
    "clothed",
    "cloth",
    "clotty",
    "cloudy",
    "clown-like",
    "clownish",
    "clubbable",
    "clubby",
    "clubfooted",
    "clueless",
    "clumpish",
    "clumpy",
    "clumsy",
    "cluttered",
    "co-ed",
    "coachable",
    "coal",
    "coaly",
    "coarse",
    "coarse-grained",
    "coastal",
    "coated",
    "cob",
    "cobblestone",
    "cobwebby",
    "cockeyed",
    "cocksure",
    "cocky",
    "cocoa",
    "codependent",
    "coeducational",
    "coercionary",
    "coercive",
    "coessential",
    "coexistent",
    "coffee-colored",
    "cogitative",
    "cognisant",
    "cognitive",
    "cognizant",
    "coherent",
    "cohesive",
    "cold",
    "cold-blooded",
    "cold-hearted",
    "cold-heartedly",
    "cold-water",
    "coldish",
    "collaborative",
    "collapsible",
    "collective",
    "collielike",
    "collinear",
    "colloquial",
    "collusive",
    "colluvium",
    "colonial",
    "colonisable",
    "coloristic",
    "colossal",
    "colour-blind",
    "colourable",
    "colourational",
    "coloured",
    "colourific",
    "colouristic",
    "colourless",
    "coltish",
    "columnar",
    "columnarized",
    "columned",
    "combatable",
    "combative",
    "combustible",
    "combustive",
    "comedial",
    "comely",
    "comfortable",
    "comfortable",
    "comfortless",
    "comfy",
    "comic",
    "comical",
    "commanding",
    "commenceable",
    "commendable",
    "commendatory",
    "commensurable",
    "commensurate",
    "commentable",
    "commentarial",
    "commentative",
    "commentatorial",
    "commercial",
    "commercialistic",
    "comminative",
    "comminatory",
    "commiserable",
    "commiserative",
    "committable",
    "commodious",
    "common",
    "common-law",
    "commonable",
    "commonplace",
    "commonsense",
    "commonsensible",
    "commonsensical",
    "communal",
    "communalistic",
    "communicable",
    "communicative",
    "communicatory",
    "communionable",
    "communist",
    "communistic",
    "communistical",
    "communital",
    "community",
    "commutable",
    "commutative",
    "commutual",
    "compact",
    "compactable",
    "companionable",
    "companionless",
    "companyless",
    "comparable",
    "comparative",
    "compassable",
    "compassionate",
    "compassionless",
    "compatible",
    "compatriotic",
    "compellable",
    "compellent",
    "compensable",
    "compensational",
    "compensatory",
    "compentant",
    "competitive",
    "complacent",
    "complainable",
    "complaisant",
    "complementable",
    "complementary",
    "complemented",
    "completable",
    "complete",
    "complex",
    "complexional",
    "complexioned",
    "complexionless",
    "compliable",
    "compliant",
    "complicated",
    "componental",
    "componented",
    "comprehensive",
    "compressive",
    "comprisable",
    "compulsive",
    "compulsory",
    "computable",
    "computational",
    "computative",
    "concave",
    "conceited",
    "conceivable",
    "concentrative",
    "conceptual",
    "concerned",
    "concessible",
    "concessionary",
    "concessive",
    "conchin",
    "conchiolin",
    "conchologic",
    "conchological",
    "concise",
    "concludable",
    "concludible",
    "conclusional",
    "conclusive",
    "concrete",
    "concretionary",
    "concurrent",
    "condemnable",
    "condemnatory	",
    "condemned",
    "condensable",
    "condensational",
    "condensative",
    "condensed",
    "condescending",
    "condescensive",
    "conditioned",
    "confident",
    "confidential",
    "configurational",
    "configurative",
    "confineable",
    "confined",
    "confirmable",
    "confirmatory",
    "confirmed",
    "confiscable",
    "confiscatory",
    "conflictive",
    "conflictory",
    "confluent",
    "confounded ",
    "confounding",
    "confused",
    "confusing",
    "confusional",
    "congenial",
    "congested",
    "congratulant",
    "congratulational",
    "congratulatory",
    "congregational",
    "congregative",
    "congressional",
    "congruent",
    "congruous",
    "connectable",
    "connectible",
    "conscientious",
    "conscionable",
    "conscious",
    "consecutive",
    "consensual",
    "consentaneous",
    "consentient",
    "conservable",
    "conservational",
    "conservative",
    "conservative",
    "considerable",
    "considerate",
    "consignable",
    "consistent",
    "consolable",
    "consolatory",
    "consolidative",
    "conspicuous",
    "conspirative",
    "conspiratorial",
    "constant",
    "constellatory",
    "constituent",
    "constitutional",
    "constitutive",
    "constrainable",
    "constrained",
    "constrictive",
    "constringent",
    "construable",
    "constructible",
    "constuctional",
    "constuctive",
    "consumable",
    "consummate",
    "consumptive",
    "contactual",
    "contagious",
    "containable",
    "contained",
    "contaminable",
    "contaminated",
    "contaminative",
    "contaminous",
    "contemnible",
    "contemplable",
    "contemplative",
    "contemporaneous",
    "contemporary",
    "contemptible",
    "contemptile",
    "contemptuous",
    "content",
    "contentable",
    "contented",
    "contentional",
    "contentious",
    "contestable",
    "contextual",
    "contiguous",
    "continental",
    "continual",
    "continued",
    "continuing",
    "continuous",
    "continuous",
    "contorted",
    "contortional",
    "contortioned",
    "contortionistic",
    "contortive",
    "contractible",
    "contractile",
    "contractional",
    "contractive",
    "contractual",
    "contractured",
    "contradictable",
    "contradictious",
    "contradictive",
    "contradictory",
    "contrary",
    "contributable",
    "contrite",
    "contrivable",
    "contrived",
    "controlled",
    "controlless",
    "controversial",
    "controvertible",
    "contumelious",
    "contusioned",
    "convectional",
    "convective",
    "convenable",
    "convenient",
    "conventional",
    "conventual",
    "convergent",
    "conversable",
    "conversant",
    "conversational",
    "converted",
    "convertible",
    "conveyable",
    "convictable",
    "convictible",
    "convictional",
    "convictive",
    "convincible",
    "convincing",
    "convivial",
    "convulsant",
    "convulsible",
    "convulsionary",
    "convulsive",
    "cookable",
    "cooked",
    "cool",
    "cooperative",
    "copacetic",
    "coplanar",
    "copper",
    "coppery",
    "copyrightable",
    "coquettish",
    "coral",
    "coralliferous",
    "coralline",
    "coralloid",
    "cordial",
    "corduroy",
    "corelative",
    "cork",
    "corked",
    "corking",
    "corky",
    "corn-colored",
    "cornmeal",
    "corny",
    "coronary",
    "corporal",
    "corporate",
    "corporational",
    "corporatist",
    "corporative",
    "corporeal",
    "correct",
    "correctable",
    "correctible",
    "correctional",
    "corrective",
    "correlatable",
    "correlational",
    "correlative",
    "corroborant",
    "corroborative",
    "corrodible",
    "corrosional",
    "corrosive",
    "corrupt",
    "corrupted",
    "corruptful",
    "corruptible",
    "corrupting",
    "corruptive",
    "cosey",
    "coseys",
    "cosie",
    "cosies",
    "cosmetological",
    "cosmic",
    "cosmogonal",
    "cosmogonic",
    "cosmogonical",
    "cosmographic",
    "cosmographical",
    "cosmologic",
    "cosmological",
    "cosmonautic",
    "cost-effective",
    "costless",
    "costly",
    "cosy",
    "cotton",
    "cottony",
    "coulrophobic",
    "councilmanic",
    "counselable",
    "countable",
    "counteractive",
    "countercoloured",
    "counterproductive",
    "counterterrorist",
    "countrified",
    "country-bred",
    "country-wide",
    "couped",
    "courageous",
    "courteous",
    "courtly",
    "coverable",
    "covered",
    "covert",
    "covetable",
    "coveting",
    "covetous",
    "cowardly",
    "cowlike",
    "coyish",
    "cozey",
    "cozy",
    "crabbed",
    "crabby",
    "crackable",
    "cracked",
    "crackless	",
    "crafty",
    "craggy",
    "cramped",
    "cranial",
    "craniate",
    "craniological",
    "craniometric",
    "craniometrical",
    "cranioscopical",
    "cranky",
    "crashing",
    "crass",
    "craven",
    "crawly",
    "crazed",
    "crazy",
    "cream",
    "cream-colored",
    "creamy",
    "creased",
    "creasy",
    "creatable",
    "creational ",
    "creationary",
    "creationistic",
    "creative",
    "creatural",
    "creaturely",
    "credentialed",
    "credible",
    "creditable",
    "credulous",
    "creeded",
    "creepy",
    "crematory",
    "creophagous",
    "crestfallen",
    "cretaceous",
    "cretinoid",
    "cretinous",
    "creviced",
    "criminal",
    "criminative",
    "criminologic",
    "criminological",
    "crimpy",
    "crimson",
    "crippling",
    "crispy",
    "critical",
    "criticisable",
    "crocodiloid",
    "cronish",
    "crooked",
    "cross-legged",
    "crotchety",
    "crowning",
    "crucial",
    "crude",
    "cruel",
    "cruelhearted",
    "crumbable",
    "crumbly",
    "crumby",
    "crumply",
    "crurophilic",
    "cruse",
    "crushable",
    "crushing",
    "crustaceous",
    "crusted",
    "crusty",
    "crying",
    "cryogenic",
    "cryophilic",
    "cryptic",
    "cryptocrystalline",
    "cryptographical",
    "cryptographic",
    "cryptovolcanic",
    "cryptozoic",
    "crystal",
    "crystalliferous",
    "crystalline",
    "crystallisable",
    "crystallitic",
    "crystallographic",
    "crystalloid",
    "crystalloidal",
    "cthonophagous",
    "cubic",
    "cubical",
    "cubiform",
    "cubistic",
    "cuboid",
    "cuddlesome",
    "cuddly",
    "culinary",
    "culm",
    "culpable",
    "cultic",
    "cultish",
    "cultivable",
    "cultivated",
    "cultual",
    "cultural",
    "cultured",
    "cultureless",
    "cumbersome",
    "cumbrous",
    "cummy",
    "cumulative",
    "cuneiform",
    "cunning",
    "cupulate",
    "curable",
    "curative",
    "curatorial",
    "curbable",
    "curdy",
    "cured",
    "curious",
    "curium",
    "curly",
    "curmudgeonly",
    "current",
    "curricular",
    "cursed",
    "cursive",
    "cursorial",
    "cursory",
    "curt",
    "curvaceous",
    "curved",
    "curvilinear",
    "curvy",
    "cushiony",
    "cushy",
    "cussed",
    "custodial",
    "custom-built",
    "custom-made",
    "customable",
    "customary",
    "cut-price",
    "cut-rate",
    "cute",
    "cuttable",
    "cyan",
    "cybernetic",
    "cyberpunk",
    "cycadaceous",
    "cyclopean",
    "cylinderlike",
    "cylindraceous",
    "cylindrical",
    "cynical",
    "cynophobic",
    "cystic",
    "czarist",
    "dacite",
    "daemonic",
    "daffy",
    "daft",
    "dainty",
    "damageable",
    "damaged",
    "damaging",
    "damask",
    "damp",
    "damp-proof",
    "dampish",
    "dampproof",
    "dandriffy",
    "dandruffy",
    "dangerous",
    "dank",
    "dapper",
    "dapple-gray",
    "daredevil",
    "daring",
    "dark",
    "darkish",
    "darksome",
    "darmstadtium",
    "dashing",
    "dastardly",
    "dated",
    "daughterlike",
    "daughterly",
    "dauntless",
    "daydreaming",
    "daydreamy",
    "dazed",
    "dazzling",
    "deactivated",
    "dead",
    "dead-smooth",
    "deadbeat",
    "deadly",
    "deadpan",
    "dear",
    "deathful",
    "deathless",
    "deathlike",
    "deathly",
    "debatable",
    "debilitated",
    "debilitative",
    "debonair",
    "decadent",
    "decagonal",
    "decahedral",
    "decapitated",
    "decasyllabic",
    "decayable",
    "decayed",
    "deceased",
    "deceitful",
    "decent",
    "deceptive",
    "decidophobic",
    "deciduous",
    "decipherable",
    "decisive",
    "declamatory",
    "declarative",
    "declaratory",
    "declared",
    "declinable",
    "declinate",
    "declinational",
    "declinatory",
    "decomposable",
    "decomposed",
    "decontaminative",
    "decorated",
    "decorative",
    "decorous",
    "decrepit",
    "dedicated",
    "deducible",
    "deductible",
    "deductive",
    "deep",
    "deerskin",
    "defaceable",
    "defamatory",
    "defeasible",
    "defeated",
    "defectible",
    "defective",
    "defenceless",
    "defenestrated",
    "defensive	",
    "deferable",
    "deferent",
    "deferential",
    "defiable",
    "defiant",
    "deficient",
    "definable",
    "definite",
    "definitive",
    "deflated",
    "deflationary",
    "deflectable",
    "deformable",
    "deformational",
    "deformative",
    "deformed",
    "deft",
    "defunct",
    "defunctive",
    "degenerative",
    "degradable",
    "degraded",
    "degrading ",
    "dehydrated",
    "deific",
    "deiform",
    "deistic",
    "deistical",
    "dejected",
    "dejected",
    "delayable",
    "delayed",
    "delectable",
    "delegable",
    "deliberate",
    "deliberative",
    "delicate",
    "delicious",
    "delighted",
    "delighted",
    "delightful",
    "delightless",
    "delightsome",
    "delirious",
    "delusional",
    "delusive",
    "demagnetisable",
    "demagnetizable",
    "demandable",
    "demanding",
    "demented",
    "democratic",
    "democratic",
    "demoded",
    "demographic",
    "demographical",
    "demoniac",
    "demonian",
    "demonic",
    "demonstrable",
    "demonstrational",
    "demonstrative",
    "demotic",
    "demure",
    "demurrable",
    "dendrachate",
    "dendric",
    "dendriform",
    "dendritic",
    "dendrochronological",
    "dendroid",
    "dendrological",
    "dendrophagous",
    "dendrophilic",
    "dendrophilous",
    "dendrophobic",
    "deniable",
    "denim",
    "dense",
    "dental",
    "dentine",
    "dentophobic",
    "deodorizing",
    "departed",
    "departmental",
    "dependable",
    "dependent",
    "depictive",
    "depilatory",
    "depleted",
    "depletive",
    "depletory",
    "deplorable",
    "deportable",
    "deposable",
    "depositional",
    "depraved",
    "deprecative",
    "deprecatory",
    "depreciable",
    "depreciatory",
    "depressant",
    "depressed",
    "depressed",
    "depressible",
    "depressing",
    "depressive",
    "deprivable",
    "deprived",
    "derangeable",
    "deranged",
    "derelict",
    "derisible",
    "derisive",
    "derivable",
    "derivational",
    "derivative",
    "dermal",
    "dermatic",
    "dermatographic",
    "dermatoid",
    "dermatological",
    "dermatomic",
    "dermatophytic",
    "dermatoplastic",
    "dermatropic",
    "dermic",
    "dermographic",
    "dermoid",
    "derogative",
    "derogatory",
    "descendent",
    "descendible",
    "describable",
    "descriptive",
    "desecrated",
    "desert-like",
    "deserted",
    "desertic",
    "deserticolous",
    "desertlike",
    "deserved",
    "deserving",
    "designative",
    "designatory",
    "desirable",
    "desired",
    "desirous",
    "desolate",
    "despairful",
    "despairing",
    "desperate",
    "desperate",
    "despicable",
    "despisable",
    "despiteful",
    "despiteous",
    "despondent",
    "despondent",
    "despotic",
    "destined",
    "destitute",
    "destroyable",
    "destroyed",
    "destructible",
    "destructive",
    "detachable",
    "detailed",
    "detainable",
    "detectable",
    "detectible",
    "deteriorative",
    "determinable",
    "determinant",
    "determinate",
    "determinately",
    "determinative",
    "determined",
    "deterministic",
    "detestable",
    "detonable",
    "detonative",
    "detoxicant",
    "detractive",
    "detrimental",
    "deviant",
    "deviative",
    "deviceful",
    "devious",
    "devoid",
    "devoted",
    "devotional",
    "devout",
    "dewy",
    "dewy-eyed",
    "dexterous",
    "diabetic",
    "diabolic",
    "diagnosable",
    "diagnostic",
    "diagonal",
    "dialectal",
    "dialectical",
    "dialectologic",
    "dialectological",
    "diamant",
    "diamantiferous",
    "diamantine",
    "diamond",
    "diarthrodial",
    "dicey",
    "dichromatic",
    "dictatorial",
    "didactic",
    "diet",
    "dietary",
    "dietetic",
    "different",
    "differentiable",
    "differential",
    "difficult",
    "difficult",
    "diffident",
    "diffractive",
    "diffusible",
    "digestible",
    "digestional",
    "digestive",
    "digital",
    "digitiform",
    "dignified",
    "dignified",
    "dignifying",
    "digressive",
    "dihedral",
    "dihydrated",
    "dihydric",
    "dilapidated",
    "dilligent",
    "dim-witted",
    "diminished",
    "diminutive",
    "dimmed",
    "dimming",
    "dimply",
    "dingy",
    "dinky",
    "dinosaurian",
    "diopside",
    "diplocardiac",
    "diplomatic",
    "diplomatic",
    "dippy",
    "dire",
    "directionless",
    "directorial",
    "direful",
    "dirgeful",
    "dirt",
    "dirty",
    "dirty-faced",
    "disabled",
    "disadvantaged",
    "disaffected",
    "disagreeable",
    "disallowable		",
    "disappointed",
    "disappointing",
    "disarming",
    "disastrous",
    "disastrous",
    "disbursable",
    "discernible",
    "discerning",
    "disciplinable",
    "disciplinal",
    "disciplinary",
    "disciplined",
    "discoloured",
    "discombobulated",
    "discomfortable",
    "disconcerted",
    "disconsolate",
    "discontented",
    "discontinuous",
    "discophilic",
    "discountable",
    "discourageable",
    "discourteous",
    "discoverable 	",
    "discreditable	",
    "discreet	",
    "discrepant	",
    "discrete	",
    "discretional	",
    "discretionary	",
    "discussable	",
    "discussible	",
    "disdainful	",
    "diseased	",
    "disembodied	",
    "disenfranchised	",
    "disgraced",
    "disgraceful	",
    "disguisable	",
    "disgusted	",
    "disgusted",
    "disgustful	",
    "disgusting	",
    "dishevelled	",
    "dishonest	",
    "dishonorable	",
    "dishonourable	",
    "disillusioned	",
    "disillusive	",
    "disimpassioned	",
    "disinclined	",
    "disingenuous	",
    "disinherited	",
    "disintegrable	",
    "disintegrative	",
    "disintegratory	",
    "disinterested	",
    "dislikeable	",
    "disliked	",
    "disloyal	",
    "dismal	",
    "dismissible	",
    "dismissive	",
    "dismountable	",
    "disobedient	",
    "disordered	",
    "disorganized	",
    "disparaged	",
    "disparaging	",
    "dispassionate	",
    "dispellable	",
    "dispensable	",
    "dispersible	",
    "dispirited	",
    "dispiriting	",
    "dispiteous	",
    "displaceable	",
    "displayed	",
    "displeased	",
    "displeasing	",
    "displeasureable	",
    "disposable	",
    "dispossessed	",
    "dispossessory	",
    "disproportionable	",
    "disproportional	",
    "disprovable	",
    "disputable	",
    "disqualifiable	",
    "disquieted	",
    "disquieting	",
    "disregardful	",
    "disreputable	",
    "disrespectable	",
    "disrespectful	",
    "disruptive	",
    "dissatisfactory	",
    "dissatisfied	",
    "dissected	",
    "dissectible	",
    "dissentient	",
    "dissentious	",
    "dissident	",
    "dissimilar	",
    "dissociable	",
    "dissocial	",
    "dissociative	",
    "dissolvable	",
    "dissonant	",
    "dissuadable	",
    "dissuasive	",
    "dissyllabic	",
    "distant	",
    "distasteful	",
    "distended	",
    "distent	",
    "distillable	",
    "distinct	",
    "distinctive	",
    "distinguished	",
    "distinguishing",
    "distorted",
    "distortional",
    "distortive",
    "distracted",
    "distractible",
    "distractive",
    "distressful",
    "distributable",
    "distrustful",
    "disturbed",
    "disturbing",
    "disused",
    "disyllabic",
    "divergent",
    "diverse",
    "diversifiable",
    "diversified",
    "diversiform",
    "divinable",
    "divinatory",
    "divine",
    "diving",
    "divorceable",
    "dizzied",
    "dizzy",
    "dizzying",
    "docile",
    "doctoral",
    "doctorial",
    "doctrinaire",
    "doctrinal",
    "documentary",
    "doddered",
    "doddering",
    "dodecagonal",
    "dodecahedral",
    "dodecasyllabic",
    "dog-poor",
    "dog-tired",
    "dogged",
    "doggish",
    "doggoned",
    "doglike",
    "dogmatic",
    "dollfaced",
    "dollish",
    "dolomite",
    "dolorous",
    "dolostone",
    "doltish",
    "domestic",
    "domesticable",
    "domesticated",
    "domesticative",
    "dominant",
    "dominating",
    "domineering",
    "doomed",
    "dopey",
    "dopy",
    "dorky",
    "dormant",
    "dorsal",
    "dorsispinal",
    "dotted",
    "double-edged",
    "double-jointed",
    "doubtful",
    "doughty",
    "doughy",
    "dour",
    "doused",
    "dove-colored",
    "dovish",
    "dowdy",
    "downcast",
    "downfallen",
    "downhearted",
    "downtrodden",
    "downy",
    "dozing",
    "dozy",
    "drab",
    "draconian",
    "draconic",
    "drafty",
    "dragonish",
    "dragonlike",
    "dramatic",
    "dramatic",
    "dramatisable",
    "dramatizable",
    "dramaturgic",
    "dramaturgical",
    "drastic",
    "draughty",
    "drawn",
    "dreadable",
    "dreadful",
    "dreamful",
    "dreamlike",
    "dreamy",
    "drear",
    "drearisome",
    "dreary",
    "dressy",
    "drifty",
    "drinkable",
    "drip-dry",
    "dripping",
    "drippy",
    "driveable",
    "drizzly",
    "droll",
    "dronish",
    "drooly",
    "droopy",
    "drossy",
    "droughty",
    "drouthy",
    "drowsy",
    "druidic",
    "druidical",
    "dryadic",
    "dual-purpose",
    "dubious",
    "dubnium",
    "ducal",
    "duckie",
    "duelistic",
    "dull",
    "dullish",
    "dumb",
    "dumbfounded",
    "dumbstruck",
    "dumpish",
    "dumpy",
    "duncical	",
    "duncish",
    "dunderheaded",
    "dungy",
    "dunite",
    "durable",
    "durational",
    "durative",
    "duskish",
    "dusky",
    "dustless",
    "dustproof",
    "dusty",
    "duteous",
    "dutiable",
    "dutiful",
    "duty-bound",
    "dwarfed",
    "dwarfish",
    "dwarven",
    "dyable",
    "dying",
    "dynamic",
    "dynamistic ",
    "dynamitic",
    "dynastic",
    "dynastical",
    "dysfunctional",
    "dysmorphophobic",
    "dystopian",
    "dystopic",
    "eager",
    "eagle-eyed",
    "earnest",
    "earth",
    "earthborn",
    "earthbound",
    "earthen",
    "earthenware",
    "earthly",
    "earthy",
    "easeful",
    "eastbound",
    "eastern",
    "easternmost",
    "eastmost",
    "easy",
    "easy-going",
    "eatable",
    "eaved",
    "ebony",
    "ebullient",
    "eccentric",
    "eccentrical",
    "ecclesiastical",
    "ecclesiologic",
    "ecclesiological",
    "eclectic",
    "eclogite",
    "ecological",
    "ecologic",
    "econometrical",
    "econometric",
    "economic",
    "economical",
    "ecosystemic",
    "ecstatic",
    "ectocranial",
    "ectoplasmatic",
    "ectoplasmic",
    "ecumenical",
    "edacious",
    "edgy",
    "edible",
    "edificial",
    "editorial",
    "educable",
    "educated",
    "educational",
    "educative",
    "educatory",
    "eerie",
    "effaceable",
    "effectible",
    "effective",
    "effectual",
    "effeminate",
    "effervescent",
    "effervescible",
    "effete",
    "efficacious",
    "efficient",
    "effigial",
    "efflorescent",
    "effortful",
    "effortless",
    "effusive",
    "egalitarian",
    "egocentric",
    "egoistic",
    "egoistical",
    "egomaniacal",
    "egotistic",
    "egotistical",
    "egregious",
    "einsteinium",
    "ejective",
    "elaborate",
    "elaborative",
    "elastic",
    "elated",
    "elder",
    "elderly",
    "electoral",
    "electric",
    "electrical",
    "electrified",
    "electrobiological",
    "electrocardiographic",
    "electrodynamic",
    "electrokinetic",
    "electroluminescent",
    "electrolytic",
    "electromagnetic",
    "electromechanical",
    "electrometallurgical",
    "electrometric",
    "electrometrical",
    "electronic",
    "electrophilic",
    "electrophonic",
    "electrosensitive",
    "electrostatic",
    "elegant",
    "elemental",
    "elementary",
    "elephantiasic",
    "elephantine",
    "elephantoid",
    "elevated",
    "elfin",
    "elfish",
    "elicitable",
    "eligible",
    "eliminable",
    "elite",
    "ellipsoidal",
    "elliptic",
    "elliptical",
    "elmy",
    "eloquent",
    "elusive",
    "elvish",
    "emaciated",
    "emanatory",
    "emancipated",
    "emancipating",
    "emancipative",
    "emancipatory",
    "emasculated",
    "emasculative",
    "emasculatory",
    "embarrassed",
    "embarrassing",
    "embattled",
    "emblematic",
    "embolic",
    "embolismic",
    "embraceable",
    "embracive",
    "emerald",
    "emeritus",
    "emersed",
    "emetophobic",
    "emigrational",
    "emigrative",
    "emigratory",
    "eminent",
    "emotionable",
    "emotional",
    "emotionalistic",
    "emotionless",
    "emotive",
    "empathetic",
    "empathic",
    "emphatic",
    "empirical",
    "empiristic",
    "employable",
    "emptiable",
    "emptied",
    "empty",
    "empty",
    "empty-handed",
    "empty-headed",
    "empyrean",
    "emulsible",
    "emulsifiable",
    "emulsive",
    "enarthrodial",
    "encephalic",
    "encephalitic",
    "enchanted",
    "enchanting",
    "encouraging",
    "encyclopaedic",
    "endangered",
    "endemic",
    "endless",
    "endocardial",
    "endocranial",
    "endocrine",
    "endocrinologic",
    "endocrinological",
    "endocrinopathic",
    "endocrinous",
    "endodermal",
    "endodermic",
    "endowed",
    "endurable",
    "endurant",
    "enduring",
    "energetic",
    "energetistic",
    "energistic",
    "enervated",
    "enervative",
    "enetophobic",
    "enforceable",
    "engaged",
    "engaging",
    "enginous",
    "englacial",
    "engrammic",
    "enhanced",
    "enhancive",
    "enharmonic",
    "enigmatic",
    "enjambed",
    "enjoyable",
    "enlargeable",
    "enneahedral",
    "enneasyllabic",
    "enormous",
    "enraged",
    "enrapt",
    "enslaved",
    "enstatite",
    "enterprising",
    "entertaining",
    "enthralled",
    "enthroned",
    "enthusiastic",
    "entire",
    "entitled",
    "entodermal",
    "entodermic	",
    "entomologic",
    "entomological",
    "entomophagous",
    "entomophobic",
    "entrepreneurial",
    "enumerable",
    "enunciable",
    "enunciatory",
    "enuncuative",
    "enviable",
    "envious",
    "environmental",
    "enzymatic",
    "enzymolytic",
    "eolithic",
    "eonian",
    "ephebiphobic",
    "ephemeral",
    "epicardiac",
    "epicardial",
    "epicentral",
    "epicurean",
    "epidemic ",
    "epidermal",
    "epidermic",
    "epidermoid",
    "epimyocardial",
    "episodic",
    "epistemological",
    "epitaphic",
    "epoxy",
    "equable",
    "equal",
    "equalitarian",
    "equanimous",
    "equatable",
    "equational",
    "equatorial",
    "equestrian",
    "equiangular",
    "equicontinuous",
    "equidistant",
    "equilateral",
    "equilibratory",
    "equilibrious",
    "equilibristic",
    "equine",
    "equinophobic",
    "equipable",
    "equitable",
    "equivalent",
    "eradicable",
    "erasable",
    "erect",
    "erectable",
    "erectile",
    "erective",
    "ergasiophobic",
    "ergonomic",
    "ergophilic",
    "ergophobic",
    "ermined",
    "erosive",
    "errable",
    "erratic",
    "erythrophobic",
    "escapable",
    "esophageal",
    "esoteric",
    "especial",
    "essential",
    "establishable",
    "established",
    "establishmentarian",
    "esthetical",
    "esthetic",
    "eternal",
    "ethereal",
    "ethical",
    "ethnic",
    "ethnocentric",
    "ethnogenic",
    "ethnographic",
    "ethnographical",
    "ethnohistoric",
    "ethnohistorical",
    "ethnolinguistic",
    "ethnologic",
    "ethnological",
    "ethnomusicological",
    "ethologic",
    "ethological",
    "etymologic",
    "etymological",
    "eucalyptic",
    "euhedral",
    "euphoric",
    "evacuated",
    "evadable",
    "evadible",
    "evaluable",
    "evasive",
    "even",
    "even-handed",
    "even-minded",
    "even-tempered",
    "eventful",
    "evergreen",
    "everlasting",
    "everyday",
    "evident",
    "evil",
    "evil-eyed",
    "evil-minded",
    "evocable",
    "evolutional",
    "evolutionary",
    "evolutive",
    "evolvable",
    "evolved",
    "exacerbated",
    "exact",
    "exactable",
    "exacting",
    "exaggerated",
    "exalted",
    "exceedable",
    "excellent",
    "exceptional",
    "excess",
    "excessive",
    "exchangeable",
    "excisable",
    "excitable",
    "excited",
    "exciting",
    "exclaimational",
    "exclamatory",
    "exclusionary",
    "exclusionist",
    "exclusive",
    "exclusivistic",
    "excommunicable",
    "excusable",
    "executable",
    "exemplary",
    "exemplifiable",
    "exemplificative",
    "exemptible",
    "exhaustible",
    "exhaustive",
    "exilable",
    "existent",
    "existent",
    "existential",
    "existentialist",
    "existentialistic",
    "exodermal",
    "exorable",
    "exorcismal",
    "exorcistic",
    "exorcistical",
    "exoskeletal",
    "exoteric",
    "exothermic",
    "exotic",
    "expandable",
    "expanded",
    "expansive",
    "expectable",
    "expectant",
    "expected",
    "expecting",
    "expedient",
    "expediential",
    "expeditionary",
    "expeditious",
    "expensive",
    "experienced",
    "experimental",
    "expert",
    "explainable",
    "explicable",
    "exploding",
    "exploitable",
    "exploitative",
    "exploitatory",
    "exploitive",
    "explorable",
    "explosive",
    "exponential",
    "exportable",
    "exposable",
    "exposed",
    "expressible",
    "exquisite",
    "extended",
    "extendible",
    "extensible",
    "exterior",
    "exterminable",
    "external",
    "extinct",
    "extinguishable",
    "extinguished",
    "extra",
    "extracellular",
    "extracorporeal",
    "extragalactic",
    "extrajudicial",
    "extralegal",
    "extranuclear",
    "extraordinary",
    "extraplanetary",
    "extraterrestrial",
    "extraterritorial",
    "extraterritorial",
    "extraverted",
    "extravertish",
    "extravertive",
    "extremal",
    "extreme",
    "extrovert",
    "extroverted",
    "extrovertish",
    "extrovertive",
    "exuberant",
    "exultant",
    "eyeable",
    "fabled",
    "fabric",
    "fabulous",
    "facial",
    "facile",
    "factional",
    "factorable",
    "fadable",
    "faded",
    "faint",
    "fainthearted",
    "faintish",
    "fair",
    "fairish",
    "fairylike",
    "faithful",
    "faithful",
    "faithless",
    "fake",
    "falconiform",
    "falconine",
    "falconnoid",
    "false-hearted",
    "falsifiable",
    "famed",
    "fameless",
    "familial",
    "familiar",
    "familyish	",
    "famished",
    "famous",
    "fanatical",
    "fanciful",
    "fancy",
    "far-flung",
    "far-seeing",
    "far-sighted",
    "farcical",
    "fascinated",
    "fascinating",
    "fascist",
    "fashionable",
    "fast",
    "fast-moving",
    "fat-faced",
    "fat-like",
    "fat-witted",
    "fatal",
    "fatherly",
    "fathomable ",
    "fatigable",
    "fatlike",
    "fattening",
    "fattish",
    "fatty",
    "faultfinding",
    "faulty",
    "favourite",
    "fawning",
    "fearful",
    "fearless",
    "fearsome",
    "feasible-",
    "feather",
    "featherbrained",
    "feathered",
    "featheredged",
    "featherlight",
    "feathery",
    "federal",
    "feeble",
    "feeble-minded",
    "feeblish",
    "feedable",
    "feisty",
    "fel",
    "feldspar",
    "felicific",
    "felicitous",
    "feline",
    "fellow",
    "felonious",
    "felt",
    "female",
    "feminine",
    "feminist",
    "feministic",
    "femoral",
    "feral",
    "fermentable",
    "fermium",
    "fernlike",
    "ferny",
    "ferocious",
    "ferreous",
    "ferrety",
    "ferric",
    "ferriferous",
    "ferrous",
    "fertile",
    "fertilizable",
    "fervent",
    "fervid",
    "festive",
    "fetid",
    "feudalist",
    "feudal",
    "feverish",
    "feverous",
    "fibered",
    "fiberglass",
    "fibre",
    "fibroid",
    "fibrous",
    "fickle",
    "fictional",
    "fidgety",
    "fiendish",
    "fierce",
    "fiery",
    "fightable",
    "figurable",
    "filched",
    "filibusterous",
    "fillable",
    "filmable",
    "filterable",
    "filthy",
    "finable",
    "final",
    "financial",
    "financial",
    "findable",
    "fine",
    "fine-drawn",
    "fine-grain",
    "fine-grained",
    "fineable",
    "finespun",
    "finical",
    "finicky",
    "finnicky",
    "fire breathing",
    "fire retardant",
    "fire-breathing",
    "fire-resistant",
    "fire-retardant",
    "firebreathing",
    "fireless",
    "fireproof",
    "fireproof",
    "firm",
    "first",
    "first-born",
    "first-generation",
    "fiscal",
    "fishable",
    "fishy",
    "fittable",
    "fixable",
    "fixed",
    "fixed-income",
    "fizzy",
    "flabby",
    "flaky",
    "flamboyant",
    "flame-colored",
    "flameproof",
    "flaming",
    "flammable",
    "flamy",
    "flannel",
    "flashy",
    "flat",
    "flatterable",
    "flattering",
    "flattish",
    "flaunty",
    "flavorous",
    "flavoured",
    "flavourful",
    "flavourless",
    "flavoursome",
    "flavoury",
    "flawless",
    "flax",
    "flayed",
    "fleece",
    "fleecy",
    "fleeting",
    "flesh-colored",
    "fleshless",
    "fleshly",
    "fleshy",
    "flexible",
    "flexitarian",
    "flighty",
    "flimsy",
    "flinty",
    "flirtational",
    "flirtatious",
    "flirty",
    "floatable",
    "floating",
    "floaty",
    "flocculable",
    "floggable",
    "floodable",
    "floppy",
    "floral",
    "floreated",
    "floriated",
    "floricultural",
    "florid",
    "floriferous",
    "floristic",
    "flourishing",
    "floury",
    "flowable",
    "flowered",
    "flowering",
    "flowery",
    "fluent",
    "fluffy",
    "fluid",
    "fluidal",
    "fluidic",
    "fluorescent",
    "fluorite",
    "fluorspar",
    "flushed",
    "flyable",
    "flying",
    "foamy",
    "fogbound",
    "fogged",
    "foggy",
    "foggyish",
    "foil",
    "foilable",
    "foldable",
    "foliaceous",
    "foliaged",
    "foliated",
    "followable",
    "fond",
    "foolhardy",
    "foolish",
    "foolproof",
    "footed",
    "forbidden",
    "forbidding",
    "forcible",
    "fordable",
    "fore closable",
    "foreign",
    "foreknowable",
    "forensic",
    "foreseeable",
    "forest",
    "forestial",
    "forfeitable",
    "forgeable",
    "forgetful",
    "forgettable",
    "forgivable",
    "forlorn",
    "formable",
    "formal",
    "former",
    "formidable",
    "formivorous",
    "forthcoming",
    "fortified",
    "fortitudinous",
    "fortuitous",
    "fortunate",
    "fortune-hunting",
    "fortuneless",
    "forworn",
    "fossil-like",
    "fossilisable",
    "fossillike",
    "foul-mouthed	",
    "foulard",
    "foulmouthed",
    "foxlike",
    "foxy",
    "fozy",
    "fractious",
    "fracturable",
    "fragile",
    "fragrant",
    "frail",
    "framable",
    "francium",
    "frangible",
    "frank",
    "frantic",
    "fraternal",
    "fratricidal",
    "freakish",
    "freaky",
    "freckle-faced",
    "freckled",
    "freckly",
    "free ",
    "free-swimming",
    "free-trade",
    "freeborn",
    "freemasonic",
    "freethinking",
    "freezable",
    "freezing",
    "frenzied",
    "fresh",
    "fretful",
    "freudian",
    "friended",
    "friendless-",
    "friendly",
    "friggatriskaidekaphobic",
    "frightenable",
    "frightened",
    "frightening",
    "frigid",
    "frilly",
    "frisky",
    "frivolous",
    "frizzly",
    "frizzy",
    "frogged",
    "froggy",
    "frolicky",
    "frolicsome",
    "front",
    "frost breathing",
    "frost-breathing",
    "frostbitten",
    "frostbreathing",
    "frosted",
    "frosty",
    "frothy",
    "frousy",
    "frouzy",
    "frowsy",
    "frowzy",
    "frozen",
    "fructivorous",
    "frugal",
    "frugivorous",
    "fruitarian",
    "fruited",
    "fruitful",
    "fruity",
    "fruticose",
    "fuchsia",
    "full-grown",
    "full-time",
    "full",
    "fumbling",
    "functional",
    "fundamental",
    "fungal",
    "fungic",
    "fungicidal",
    "fungiform",
    "fungoid",
    "fungous",
    "fungus",
    "funny",
    "fun",
    "fur",
    "furious",
    "furred",
    "furry",
    "furtive",
    "fusible",
    "fussy",
    "futile",
    "future",
    "futuristic",
    "fuzzy",
    "gabardine",
    "gabby",
    "gadgety",
    "gainable",
    "galactic",
    "galactoid",
    "gallant",
    "galloping",
    "gamboge",
    "gammy",
    "gamy",
    "gangly",
    "gangrene",
    "gangrenous",
    "gargantuan",
    "garish",
    "garlicky",
    "garnet",
    "garnishable",
    "gaseous",
    "gasolinic",
    "gassy",
    "gastric",
    "gastroenterologic",
    "gastrointestinal",
    "gastronomic",
    "gastronomical",
    "gastroscopic",
    "gastrovascular",
    "gatherable",
    "gauche",
    "gaudy",
    "gaugeable",
    "gaunt",
    "gauze",
    "gauzy",
    "gelatinoid",
    "gelatinous",
    "gemmological",
    "gemmy",
    "gemological",
    "gemstone",
    "genealogic",
    "genealogical",
    "general",
    "general-purpose",
    "generic",
    "generous",
    "genetic",
    "genial",
    "genius",
    "genocidal",
    "gentile",
    "gentle",
    "gentled",
    "gentlemanlike",
    "gentlemanly",
    "gentlewomanly",
    "gentling",
    "genuine",
    "geode",
    "geographical",
    "geologic",
    "geological",
    "geomedical",
    "geometric",
    "geometrical",
    "geophilic",
    "georgiaite",
    "gephyrophobic",
    "gerascophobic",
    "germfree",
    "germicidal",
    "germinable",
    "germless",
    "germlike",
    "germproof",
    "gerontophobic",
    "ghast",
    "ghastful",
    "ghastly",
    "ghetto",
    "ghostlike",
    "ghostly",
    "ghoulish",
    "giant",
    "giddied",
    "giddy",
    "giddying",
    "gift-wrapped",
    "gifted",
    "giftwrapped",
    "gigantean",
    "gigantesque",
    "gigantic",
    "giggly",
    "gimmicky",
    "girlish",
    "girly",
    "giveable",
    "glacial",
    "glaciered",
    "glaciologic",
    "glaciological",
    "glad",
    "gladiatorial",
    "glamorous",
    "glandlike",
    "glandular",
    "glandulous",
    "glass",
    "glassy",
    "glaucophane",
    "glazed",
    "gleaming",
    "gleeful",
    "gleesome",
    "glistening",
    "glittery",
    "global",
    "gloomful",
    "gloomy",
    "glorious",
    "glossophilic",
    "glossophobic",
    "glossy",
    "glowing",
    "gluey",
    "glum",
    "gluteal",
    "glutinous",
    "gluttonous",
    "glycemic",
    "gnarled",
    "gnarly",
    "gnatty",
    "gnawable",
    "gnomic",
    "gnomish",
    "gnomologic",
    "gnomological",
    "gnomonic",
    "god-fearing",
    "godforsaken",
    "godless",
    "godlike",
    "godly",
    "godsent",
    "gold",
    "gold-filled",
    "gold-foil",
    "gold-leaf",
    "golden",
    "goldenrod",
    "good",
    "good-hearted	",
    "good-humoured",
    "good-looking",
    "good-natured",
    "good-sized",
    "good-tempered",
    "goodish",
    "goodly",
    "gooey",
    "goofy",
    "goosebumpy",
    "goosepimply",
    "gorgeable",
    "gorgeous",
    "gorillian",
    "gorilline",
    "gorilloid",
    "gossipy",
    "gothic",
    "gourdlike",
    "governable",
    "governing",
    "governmental",
    "grabbable ",
    "graceful",
    "graceless",
    "gracious",
    "gradable",
    "grained",
    "grainy",
    "graminivorous",
    "grand",
    "grandfatherly",
    "grandiloquent",
    "grandiose",
    "grandmotherly",
    "grandparental",
    "granite",
    "granitic",
    "granivorous",
    "grantable",
    "grapey",
    "graphic",
    "graphicial",
    "graphite",
    "grapy",
    "graspable",
    "grass-green",
    "grasslike",
    "grassy",
    "grateful",
    "gratis",
    "gratuitous",
    "grave",
    "gravelish",
    "gravelly",
    "gray",
    "grayish",
    "grazeable",
    "greasy",
    "great-hearted",
    "great",
    "greedsome",
    "greedy",
    "green",
    "greenish",
    "greensick",
    "gregarious",
    "greisen",
    "greyish",
    "grey",
    "grief-stricken",
    "grieving",
    "grievous",
    "griffinesque",
    "griffinish",
    "grilled",
    "grim",
    "grindable",
    "grisly",
    "groggy",
    "groovelike",
    "groovy",
    "gross",
    "grotesque",
    "grouchy",
    "groundable",
    "growable",
    "grown",
    "grown-up",
    "grubby",
    "grumpy",
    "grusome",
    "guardable",
    "gubernatorial",
    "guerdon",
    "guessable",
    "guidable",
    "guileless",
    "guiltless",
    "guilty",
    "gullible",
    "gummous",
    "gummy",
    "gun-metal",
    "gun-shy",
    "gushy",
    "gustable",
    "gutless",
    "gutsy",
    "gymnasial",
    "gymnastic",
    "gynephilic",
    "gynophobic",
    "gypsum",
    "habitual",
    "haemophobic",
    "hair-raising",
    "hairsplitting",
    "hairy",
    "half",
    "half-alive",
    "half-angry",
    "half-asleep",
    "half-awake",
    "half-bare",
    "half-bleached",
    "half-boiled",
    "half-crazed",
    "half-crazy",
    "half-dazed",
    "half-democratic",
    "half-destroyed",
    "half-divine",
    "half-feminine",
    "half-hypnotised",
    "half-intellectual",
    "half-intelligible",
    "half-joking",
    "half-liberal",
    "half-linen",
    "half-minded",
    "half-petrified",
    "half-playful",
    "half-pleased",
    "half-pleasing",
    "half-romantic",
    "half-round",
    "half-syllabled",
    "half-theatrical",
    "half-white",
    "half-witted",
    "half-womanly",
    "half-woolen",
    "halite",
    "hallowed",
    "hallucinational",
    "hallucinative",
    "hallucinatory",
    "hallucinogenic",
    "halophilic",
    "hand-drawn",
    "hand-held",
    "handcrafted",
    "handheld",
    "handmade",
    "handsewn",
    "handsome",
    "handsomeish",
    "handwoven",
    "handwritten",
    "handy",
    "hapless",
    "happy",
    "haptephobic",
    "harassed",
    "hard",
    "hard-featured",
    "hard-headed",
    "hard-shell",
    "hard-working",
    "hardhearted",
    "harebrained",
    "harlequinesque",
    "harmful",
    "harmless",
    "harmonic",
    "harmonious",
    "harpaxophilic",
    "harsh",
    "hassium",
    "hasteful",
    "hasteless",
    "hasty",
    "hated",
    "hateful",
    "haughty",
    "haunted",
    "hawk-eyed",
    "hawkish",
    "haywire",
    "hazardous",
    "hazy",
    "head",
    "headless",
    "headstrong",
    "healthful",
    "healthy",
    "heart-free",
    "heart-rending",
    "heart-stricken",
    "heart-warming",
    "heart-whole",
    "heartaching",
    "heartbreaking",
    "heartbroken",
    "heartfelt",
    "heartless",
    "heartrending",
    "heartsick",
    "heartsickening",
    "heartsore",
    "heated",
    "heathen",
    "heathenish",
    "heaven-sent",
    "heavenly",
    "heavy",
    "heavy-hearted",
    "heavyset",
    "hedenbergite",
    "hedonistic",
    "heedful",
    "heedless",
    "heinous",
    "heliodor",
    "heliophilic",
    "heliophobic",
    "helminthologic",
    "helminthological",
    "helpful",
    "helpless",
    "hemihedral",
    "hemispheric",
    "hemispherical",
    "hemispheroidal",
    "hemophobic",
    "hemp",
    "hendecagonal",
    "hendecahedral",
    "hendecasyllabic",
    "hennish",
    "heptagonal",
    "heptahedral",
    "heptahedrical",
    "heptasyllabic",
    "herbaceous	",
    "herbal",
    "herbicidal",
    "herbivorous",
    "herby",
    "herculean",
    "heretical",
    "hermitic",
    "hermitical",
    "hermitish",
    "hermitlike",
    "heroic",
    "herpetologic",
    "herpetological",
    "herringlike",
    "hesitant",
    "hessian",
    "hexadic",
    "hexaemeric",
    "hexagonal",
    "hexagrammoid",
    "hexahedral",
    "hexakosioihexekontahexaphobic",
    "hexametral ",
    "hexametric",
    "hexametrical",
    "hexangular",
    "hexapartite",
    "hexasyllabic",
    "hexed",
    "hick",
    "hidden",
    "hideous",
    "hieroglyphic",
    "high",
    "high-class",
    "high-explosive",
    "high-spirited",
    "high-spiritedly",
    "highborn",
    "highbred",
    "highfaluting",
    "highhanded",
    "highly-explosive",
    "hilarious",
    "hillocked",
    "hillocky",
    "hilly",
    "hip",
    "hippophagous",
    "hippophilic",
    "hippophobic",
    "hippy",
    "hirsutophilic",
    "historic",
    "historic",
    "historical",
    "historical",
    "historied",
    "historiographical",
    "historiographic",
    "hogged",
    "hoggish",
    "hoglike",
    "holistic",
    "hollow",
    "hollowhearted",
    "holographic",
    "holohedral",
    "holy",
    "home-grown",
    "home-maden",
    "homebred",
    "homebrewed",
    "homeless",
    "homely",
    "homemade",
    "homeopathic",
    "homesick",
    "homespun",
    "homey",
    "homicidal",
    "hominine",
    "hominoid",
    "honest",
    "honey-sweet",
    "honeyed",
    "honeyful",
    "honeysuckled",
    "honorary",
    "honorific",
    "honourable",
    "honourable",
    "honourless",
    "hopeful",
    "hoplophobia",
    "hopping",
    "horizontal",
    "hormonal",
    "horn-mad",
    "hornblende",
    "horoscopic",
    "horrendous",
    "horrible",
    "horrid",
    "horrific",
    "horrified",
    "horrifying",
    "horror-struck",
    "horselike",
    "horseplayful",
    "horsey",
    "horsy",
    "horticultural",
    "hospitable",
    "hostile",
    "hot",
    "hot-headed",
    "hot-tempered",
    "hotheaded",
    "houndish",
    "houndlike",
    "houndy",
    "huge",
    "hulkingsuperstrong",
    "hulky",
    "human",
    "humane",
    "humanitarian",
    "humanlike",
    "humanoid",
    "humble",
    "humbled",
    "humdrum",
    "humid",
    "humiliated",
    "humoristic",
    "humorous",
    "humourful",
    "humourless",
    "humoursome",
    "hungry",
    "hurried",
    "hurt",
    "hurtful",
    "hush-hush",
    "hyacinth",
    "hydrated",
    "hydrogen",
    "hydrometallurgical",
    "hydrophilic",
    "hydrophobic",
    "hygenic",
    "hygienic",
    "hygrophilic",
    "hylophagous",
    "hylotheistic",
    "hylotheistical",
    "hyperactive",
    "hyperallergenic",
    "hyperangelic",
    "hyperangelical",
    "hyperbolic",
    "hyperbrutal",
    "hypercephalic",
    "hyperdemocratic",
    "hyperintelligent",
    "hypermystical",
    "hyperpolysyllabic",
    "hyperprophetic",
    "hyperprophetical",
    "hyperrational",
    "hyperritualistic",
    "hyperromantic",
    "hypersaintly",
    "hypersceptical",
    "hyperscholastic",
    "hypersensitive",
    "hyperspherical",
    "hypersthene",
    "hypervigilant",
    "hypnotic",
    "hypnotised",
    "hypnotizing",
    "hypoactive",
    "hypoallergenic",
    "hypocephalic",
    "hypocritical",
    "hypodermal",
    "hypoglycemic",
    "hypothetical",
    "hysterical",
    "iabsolute",
    "iambic",
    "ice-cold",
    "icebound",
    "iced",
    "ichthyophagous",
    "ichthyophobic",
    "icicled",
    "icky",
    "iconic",
    "iconophilic",
    "icosahedral",
    "ideal",
    "idealistic",
    "identical",
    "ideological",
    "idiocratic",
    "idiocratical",
    "idiosyncratic",
    "idiotic",
    "idiotproof",
    "idle",
    "idled",
    "idling",
    "igneous",
    "ignitable",
    "igniteable",
    "ignoble",
    "ignorant",
    "ignored",
    "ill-advised",
    "ill-affected",
    "ill-behaved",
    "ill-bred",
    "ill-considered",
    "ill-defined",
    "ill-disposed",
    "ill-fated",
    "ill-favoured",
    "ill-gotten",
    "ill-humoured",
    "ill-informed",
    "ill-judged",
    "ill-looking",
    "ill-mannered",
    "ill-natured",
    "ill-sorted",
    "ill-starred",
    "ill-suited",
    "ill-tempered",
    "ill-timed",
    "ill-willed",
    "illegal",
    "illegible",
    "illhumored",
    "illicit",
    "illimitable",
    "illiterate",
    "illogical",
    "illtempered",
    "illuminating",
    "illusory",
    "illustrious",
    "imaginative",
    "immaculate",
    "immaterial	",
    "immature",
    "immediate",
    "immense",
    "imminent",
    "immobile",
    "immoderate",
    "immolated",
    "immoral",
    "immortal",
    "immovable",
    "immoveable",
    "immune",
    "immunological",
    "imparisyllabic",
    "impassionate",
    "impassioned",
    "impatient",
    "impeccable",
    "impending",
    "imperfect",
    "imperial",
    "imperialistic",
    "imperious ",
    "impertinent",
    "impervious",
    "impious",
    "impish",
    "impolite",
    "important",
    "imported",
    "imposing",
    "impossible",
    "impotent",
    "impoverished",
    "imprecise",
    "impregnable",
    "impressed",
    "impressive",
    "improbable",
    "improved",
    "improvident",
    "improvised",
    "imprudent",
    "impudent",
    "impulsive",
    "inaccurate",
    "inadequate",
    "inadvertent",
    "inanimate",
    "inappropriate",
    "inartistic",
    "inattentive",
    "inborn",
    "inbred",
    "incandescent",
    "incapable",
    "incautious",
    "incendiary",
    "incensed",
    "incognisant",
    "incognizant",
    "incoherent",
    "incombustible",
    "incompatible",
    "incompetent",
    "incomplete",
    "incomprehensible",
    "inconclusive",
    "inconsequential",
    "inconsequent",
    "inconsiderate",
    "inconspicuous",
    "inconstant",
    "incontinuous",
    "inconvenient",
    "incorporated",
    "incorporeal",
    "incorruptible",
    "incorrupt",
    "increased",
    "incredible",
    "incredulous",
    "incurable",
    "indecipherable",
    "indecisive",
    "indefatigable",
    "indefinite",
    "independent",
    "indestructible",
    "indicolite",
    "indifferent",
    "indigenous",
    "indigo",
    "indigo-blue",
    "indigoid",
    "indiscreet",
    "indisposed",
    "indistinct",
    "indistinctive",
    "individual",
    "individualistic",
    "indomitable",
    "indoor",
    "industrial",
    "industrialized",
    "industrious",
    "inedible",
    "ineffective",
    "inept",
    "inexistent",
    "inexpensive",
    "inexperienced",
    "inexplosive",
    "inextinguishable",
    "infamous",
    "infantile",
    "infantine",
    "infatuated",
    "infectious",
    "inferior",
    "infertile",
    "infinite",
    "infirm",
    "inflammable",
    "inflatable",
    "influential",
    "influenzal",
    "influenzalike",
    "informal",
    "ingenious",
    "ingenuous",
    "inglorious",
    "inherent",
    "inherited",
    "inhuman",
    "inhumane",
    "initial",
    "injudicious",
    "injured",
    "injurious",
    "inky",
    "inland",
    "inner",
    "innocent",
    "innocuous",
    "innovative",
    "inodorous",
    "inopportune",
    "inorganic",
    "inquiring",
    "inquisitive",
    "insane",
    "insanitary",
    "insectean",
    "insecticidal",
    "insectile",
    "insectival",
    "insectivorous",
    "insectologic",
    "insectological",
    "insecure",
    "insensate",
    "insensible",
    "insensitive",
    "insentient",
    "inseverable",
    "inside",
    "insidious",
    "insignificant",
    "insincere",
    "insipid",
    "insistent",
    "insolent",
    "insomniac",
    "inspirational",
    "instant",
    "institutional",
    "instrumental",
    "insubordinate",
    "insufficient",
    "insulaphilic",
    "insulted",
    "insulting",
    "insured",
    "insurrectional",
    "insurrectionary",
    "intact",
    "intangible",
    "integral",
    "intellectual",
    "intellectualistic",
    "intelligent",
    "intelligible",
    "intense",
    "intensive",
    "interacademic",
    "interartistic",
    "interchurch",
    "interclerical",
    "intercontradictory",
    "intercorporate",
    "intercosmic",
    "intercranial",
    "intercrystalline",
    "interdental",
    "interdestructive",
    "interested",
    "interesting",
    "interfaith",
    "interglacial",
    "interglandular",
    "intergovernmental",
    "interhemispheric",
    "interior",
    "interisland",
    "interlibrary",
    "intermarine",
    "intermediate",
    "intermetallic",
    "internal",
    "international",
    "internuclear",
    "interoceanic",
    "interparenthetic",
    "interparenthetical",
    "interplanetary",
    "interreligious",
    "interscholastic",
    "interscience",
    "interspinal",
    "interspinous",
    "intersubjective",
    "interuniversity",
    "intestinal",
    "intimate",
    "intolerable",
    "intolerant",
    "intoxicated",
    "intracardiac",
    "intracranial",
    "intradermal",
    "intragovernmental",
    "intranational",
    "intranuclear",
    "intrapsychic",
    "intraspinal",
    "intravert",
    "intraverted",
    "intravertish",
    "intriguing",
    "introvert",
    "introverted",
    "introvertish",
    "intrusive",
    "invaluable",
    "invasive	",
    "inverse",
    "inversive",
    "invigorative",
    "invincible",
    "invincible",
    "invisibility",
    "invisible",
    "involuntary",
    "involved",
    "invulnerable",
    "ionic",
    "irascible",
    "irate",
    "iridescent",
    "irksome",
    "iron-gray",
    "iron-grey",
    "iron-hearted",
    "ironbound",
    "ironclad",
    "ironfisted",
    "ironhanded",
    "ironic",
    "ironical ",
    "irradiated",
    "irrational",
    "irrationalist",
    "irrationalistic",
    "irregular",
    "irrelevant",
    "irrepressible",
    "irreproachable",
    "irresistible",
    "irresponsible",
    "irresponsive",
    "irreversible",
    "irritable",
    "irritated",
    "irritating",
    "isinglass",
    "islandish",
    "islandless",
    "islandlike",
    "isleless",
    "isleted",
    "isoceles",
    "isogonal",
    "isogonic",
    "isolated",
    "isopolitical",
    "isotope",
    "itching",
    "itchy",
    "itty-bitty",
    "ivory",
    "ivory-towered",
    "jade-green",
    "jade",
    "jaded",
    "jadeite",
    "jadish",
    "jagged",
    "jaunty",
    "jazzy",
    "jealous",
    "jean-like",
    "jeffersonite",
    "jellied",
    "jestful",
    "jesting",
    "jet-black",
    "jet",
    "jewel",
    "jingoistic",
    "jittery",
    "jobless",
    "jockeyish",
    "jocund",
    "jokeless",
    "joking",
    "jolly",
    "journalary",
    "journalish",
    "journalistic",
    "jovial",
    "joyful",
    "joyless",
    "joyous",
    "jubilant",
    "judgemental",
    "judgmental",
    "judicial",
    "judicious",
    "juice",
    "juiced",
    "juicy",
    "jumping",
    "jumpy",
    "junior",
    "just",
    "jute",
    "juvenal",
    "juvenescent",
    "juvenile",
    "kainolophobic",
    "kainophobic",
    "kakotopic",
    "kaleidoscopic",
    "kamikaze",
    "kaolin",
    "kaolinite",
    "kaput",
    "karmic",
    "katatonic",
    "keen",
    "keraunophobic",
    "ketogenetic",
    "ketogenic",
    "ketonic",
    "khaki",
    "kilted",
    "kimberlite",
    "kinaesthetic",
    "kind",
    "kind-hearted",
    "kindly",
    "kinesthetic",
    "kinetic",
    "king-size",
    "kinglike",
    "kingly",
    "kitschy",
    "kittenish",
    "klepto",
    "kleptomaniac",
    "kleptomanic",
    "klutzy",
    "knavish",
    "knee-deep",
    "knee-high",
    "knee-length",
    "knightly",
    "knitted",
    "knotted",
    "knotty",
    "knowing",
    "knowledgeable",
    "known",
    "knuckleheaded",
    "kooky",
    "kosher",
    "kunzite",
    "kyanite",
    "laborious",
    "labyrinthine",
    "lace",
    "lace-like",
    "lacertilian",
    "lackadaisical",
    "lacklustre",
    "laconic",
    "lacquer",
    "lacquerware",
    "lacy",
    "ladyish",
    "ladylike",
    "lagging",
    "laissez-faire",
    "lambskin",
    "lambswool",
    "lame",
    "lamentable",
    "laminate",
    "lamproite",
    "lamprophyre",
    "land-poor",
    "lapis",
    "lardy",
    "large",
    "large-hearted",
    "large-scale",
    "largish",
    "larval",
    "larvicidal",
    "larvivorous",
    "last",
    "late",
    "latticed",
    "laudable",
    "lavender",
    "lavish",
    "law-abiding",
    "lawful",
    "lawful",
    "lawless",
    "lawlike",
    "lawrencium",
    "lawyerlike",
    "lawyerly",
    "lazuline",
    "lazy",
    "lazyish",
    "leachy",
    "lead",
    "leading",
    "leady",
    "leafed",
    "leaflike",
    "leafy",
    "lean",
    "learned",
    "leather",
    "leathern",
    "leathery",
    "leek-green",
    "leery",
    "left",
    "leftist",
    "legal",
    "legal",
    "legalistic",
    "legatine",
    "legendary",
    "legged",
    "leggy",
    "legible",
    "legislated",
    "legislative",
    "legislative",
    "legislatorial",
    "legless",
    "leisurable",
    "leisured",
    "leisureless",
    "lemon",
    "lemonish",
    "lemony",
    "lemuroid",
    "lengthy",
    "leopard-print",
    "lepidolite",
    "leprous",
    "lethal",
    "lethargic",
    "letter-high",
    "letter-perfect",
    "lettered",
    "level",
    "lexical",
    "lexicographic",
    "lexicographical",
    "lexicologic",
    "lexicological",
    "lexiconophilic",
    "lexicostatistic",
    "lexicostatistical",
    "lherzolite",
    "liable",
    "liberal	",
    "liberal",
    "liberalistic",
    "liberated",
    "liberating",
    "libertarian",
    "liberticidal",
    "life-size",
    "lifeless",
    "light",
    "light-hearted",
    "lighted",
    "lightsome",
    "lightweight",
    "lignite",
    "lignivorous",
    "ligyrophobic",
    "likable",
    "like",
    "like-minded",
    "liked",
    "likely",
    "lilac",
    "lily-livered",
    "lily-white ",
    "limbless",
    "lime",
    "limestone",
    "limitless",
    "limivorous",
    "limnophilic",
    "limpid",
    "limping",
    "limy",
    "linear",
    "linen",
    "lineny",
    "linguistic",
    "linoleum",
    "linty",
    "lion-hearted",
    "lionesque",
    "lionly",
    "lipophobic",
    "liquid",
    "literal",
    "literal-minded",
    "literalistic",
    "literary",
    "literary",
    "literate",
    "lithe",
    "lithophilic",
    "little",
    "littlish",
    "live",
    "lively",
    "livid",
    "living",
    "loath",
    "loathful",
    "loathsome",
    "local",
    "locomotive",
    "locomotor",
    "locustal",
    "logical",
    "logophilic",
    "lonely",
    "lonesome",
    "long-suffering",
    "long-term",
    "longish",
    "long",
    "looney",
    "loony",
    "loopy",
    "lopsided",
    "lost",
    "lousy",
    "loutish",
    "lovable",
    "loveable",
    "lovecraftian",
    "loved",
    "loveless",
    "lovelorn",
    "lovely",
    "loverless",
    "lovesick",
    "lovesome",
    "lovey-dovey",
    "loving",
    "low",
    "low-cost",
    "low-fat",
    "low-key",
    "low-spirited",
    "lowborn",
    "lowbred",
    "lower-class",
    "lowish",
    "lowly",
    "loyal",
    "lucid",
    "lucky",
    "ludicrous",
    "lukewarm",
    "luminescent",
    "luminiferous",
    "luminous",
    "lumpish",
    "lumpy",
    "lunar",
    "lunatic",
    "lunies",
    "lunisolar",
    "luny",
    "lupine",
    "luscious",
    "lush",
    "lustered",
    "lustrous",
    "luxuriant",
    "luxurious",
    "luxurious",
    "lycanthropic",
    "lygophilic",
    "lygophobic",
    "lying",
    "lyrical",
    "macabre",
    "machiavellian",
    "macho",
    "macrobiotic",
    "macroclimatic",
    "macroeconomic",
    "macroeconomical",
    "macronuclear",
    "macroscopic",
    "maddening",
    "maddish",
    "magenta",
    "magic",
    "magical",
    "magnanimous",
    "magnesial",
    "magnesian",
    "magnesic",
    "magnesium",
    "magnetic",
    "magnific",
    "magnificent",
    "mahogany",
    "maimouphilic",
    "main",
    "maize",
    "majestic",
    "major",
    "makeshift",
    "malacologic",
    "malacological",
    "maladroit",
    "malcontent",
    "male",
    "maleficent",
    "malevolent",
    "malicious",
    "malignant",
    "maligned",
    "malleable",
    "malnourished",
    "malodorous",
    "malophilic",
    "mammalian",
    "mammalogical",
    "mammoth",
    "man-made",
    "managerial",
    "managing",
    "maniacal",
    "manic",
    "manic-depressive",
    "manipulable",
    "manipulative",
    "manlike",
    "manly",
    "mannerly",
    "marauding",
    "marble",
    "marginal",
    "marine",
    "marital",
    "maritime",
    "marked",
    "marmatite",
    "maroon",
    "married",
    "marshlike",
    "marshy",
    "marvellous",
    "masculine",
    "masochistic",
    "masonic",
    "massive",
    "master",
    "masterful",
    "masticated",
    "material",
    "materialistic",
    "maternal",
    "maternalistic",
    "mathematical",
    "matriarchal",
    "matriarchic",
    "matricidal",
    "matrilateral",
    "matrilineal",
    "matrimonial",
    "matronal",
    "matronly",
    "mature",
    "maudlin",
    "mauve",
    "maximum",
    "maxixe",
    "mazelike",
    "meagre",
    "mean",
    "meaningful",
    "meaningless",
    "meanspirited",
    "measled",
    "measly",
    "meaty",
    "mechanical",
    "mechanistic",
    "meddlesome",
    "mediaeval",
    "medical",
    "medical",
    "medicinal",
    "medicore",
    "medium",
    "medium-sized",
    "meek",
    "mega",
    "megacephalic",
    "megalomaniacal",
    "megamalophilic",
    "meitnerium",
    "melancholy",
    "melissophobic",
    "melittologic",
    "melittological",
    "mellow",
    "melodic",
    "melodious",
    "melodramatic",
    "melting	",
    "mendelevium",
    "menial",
    "mental",
    "mercantile",
    "mercenary",
    "merciful",
    "mercurial",
    "mere",
    "meritocrat",
    "meritocratic",
    "merry",
    "mesodermal",
    "mesodermic",
    "messianic",
    "messy",
    "metal",
    "metalled",
    "metallic",
    "metalliferous",
    "metalline",
    "metallographic",
    "metallographical",
    "metamathematical ",
    "metamorphic",
    "metamorphous",
    "metaphoric",
    "metaphorical",
    "metaphysical",
    "metapsychological",
    "metazoic",
    "metempsychic",
    "metempsychic",
    "metempsychosic",
    "metempsychosical",
    "meteorographic",
    "meteorological",
    "meteoropathologic-",
    "meticulous",
    "metrophilic",
    "metropolitan",
    "mettlesome",
    "mica",
    "microbial",
    "microbian",
    "microbic",
    "microbicidal",
    "microbiologic",
    "microbiological",
    "microbiophobic",
    "microclimatic",
    "microclimatologic",
    "microclimatological",
    "microcosmic",
    "microcosmical",
    "microcystalline",
    "microeconomic",
    "microeconomical",
    "microphysical",
    "microscopic",
    "mid",
    "middle-class",
    "middle",
    "mighty",
    "mild",
    "militant",
    "militaristic",
    "military",
    "milk-livered",
    "milk-white",
    "milky",
    "minced",
    "mindful",
    "mindless",
    "mineralogical",
    "mineralogic",
    "miniature",
    "minimal",
    "minimum",
    "miniscule",
    "ministerial",
    "mini",
    "minor",
    "minuscular",
    "minute",
    "miraculous",
    "mirky",
    "mirthful",
    "miry",
    "misandrist",
    "misandrous",
    "misanthropic",
    "miscellaneous",
    "mischievous",
    "miscreant",
    "miserable",
    "miserly",
    "misleading",
    "misogynic",
    "misogynistic",
    "misogynous",
    "missing",
    "mistrustful",
    "misty",
    "misunderstood",
    "mobile",
    "moderate",
    "modern",
    "modernistic",
    "modest",
    "modish",
    "moist",
    "moistful",
    "moldavite",
    "molecular",
    "moleskin",
    "molybdenite",
    "momentary",
    "monarchal",
    "monarchical",
    "monarchist",
    "monarchistic",
    "monetary",
    "money-grubbing",
    "monkeyish",
    "monochromatic",
    "monochrome",
    "monocultural",
    "monodramatic",
    "monogamous",
    "monolithic",
    "monometallic",
    "mononuclear",
    "monophagous",
    "monosyllabic",
    "monotonous",
    "monstrous",
    "monumental",
    "moody",
    "moonish",
    "moonlit",
    "moonstone",
    "moonwalking",
    "moony",
    "mopey",
    "moral",
    "morbid",
    "moronic",
    "morose",
    "mossy",
    "motherly",
    "motionless",
    "moudly",
    "mountable",
    "mountainous",
    "mousey",
    "mousy",
    "moving",
    "mucky",
    "mudbrick",
    "muddled",
    "muddy",
    "multicoloured",
    "multicystalline",
    "multilineal",
    "multilinear",
    "multimetallic",
    "multinuclear",
    "multipurpose",
    "mundane",
    "murderous",
    "murky",
    "muscovite",
    "mushroomy",
    "mushy",
    "musical",
    "musicianly",
    "musicological",
    "musophobic",
    "mustard",
    "mutant",
    "mutated",
    "mutinous",
    "mutual",
    "muzzled",
    "mycologic",
    "mycological",
    "mycophagous",
    "myocardial",
    "myopic",
    "myrmecological",
    "myrmecophagous",
    "myrmecophilic",
    "myrmecophilous",
    "myrtle",
    "mysophobic",
    "mysterious",
    "mystical",
    "mythical",
    "mythical",
    "mythoclastic",
    "mythological",
    "mythopoeic",
    "naggish",
    "naggy",
    "naive",
    "naked",
    "naptunium",
    "narcissistic",
    "narcistic",
    "narcoleptic",
    "narrow",
    "nasty",
    "natant",
    "natatorial",
    "natatory",
    "national",
    "national",
    "nationalistic",
    "nationalistic",
    "native",
    "natural",
    "naughty",
    "nauseating",
    "nauseous",
    "nautical",
    "naval",
    "navy",
    "near",
    "near-sighted",
    "nearby",
    "nearsighted",
    "neat",
    "nebulous",
    "necessary",
    "necromantic",
    "necromantical",
    "necrophagous",
    "necrophobic",
    "necropolitan",
    "necrotic",
    "needless",
    "needy",
    "negative",
    "neglectful",
    "negligent",
    "neighbourly",
    "nematologic",
    "nematological",
    "nemophilic",
    "neofascist",
    "neon",
    "neophilic",
    "neophobic",
    "nepheline",
    "nephelite",
    "nephrite",
    "nepotic",
    "nepotistic",
    "nepotistical",
    "nerdy	",
    "nervous",
    "nettlesome",
    "neuroeconomic",
    "neuroeconomical",
    "neurological",
    "neurotic",
    "neutered",
    "neutral",
    "neutralizing",
    "new-rich",
    "newborn",
    "newspaperish",
    "newsworthy",
    "newsy",
    "next",
    "nice",
    "nickel",
    "nickelic",
    "nickeliferous",
    "nickelous",
    "nifty",
    "niggling ",
    "nightmarish",
    "nihilistic",
    "nimble",
    "nirvanic",
    "nitpicking",
    "nitro",
    "nitrophilic",
    "nobelium",
    "noble",
    "noble-minded",
    "nocturnal",
    "noetic",
    "noir",
    "nomadic",
    "nomophobic",
    "non-moving",
    "non-traditional",
    "nonabsolute",
    "nonabsolutistic",
    "nonacademic",
    "nonacademical",
    "nonacculturated",
    "nonagrarian",
    "nonagricultural",
    "nonalgebraic",
    "nonalgebraical",
    "nonallergenic",
    "nonangelic",
    "nonartistic",
    "nonartistical",
    "nonatheistic",
    "nonatheistical",
    "nonblack",
    "noncapitalistic",
    "noncarcinogenic",
    "noncarnivorous",
    "nonchalant",
    "nonchurched",
    "nonchurchgoing",
    "noncollinear",
    "noncontinuous",
    "noncontradictory",
    "noncorporate",
    "noncorporative",
    "noncreative",
    "noncriminal",
    "noncrystalline",
    "noncrystallised",
    "noncrystallising",
    "noncultural",
    "noncultured",
    "nondeadly",
    "nondecasyllabic",
    "nondemocratical",
    "nondemocratic",
    "nondenominational",
    "nondeodorizing",
    "nondescript",
    "nondesirous",
    "nondespotic",
    "nondestructive",
    "nondifficult",
    "nondiplomatic",
    "nondramatic",
    "noneconomical",
    "noneducable",
    "noneducational",
    "nonempty",
    "nonessential",
    "nonevolutional",
    "nonevolutionary",
    "nonevolving",
    "nonexistent",
    "nonexistential",
    "nonexisting",
    "nonexperimental",
    "nonfalsifiable",
    "nonfat",
    "nonfatal",
    "nonfinancial",
    "nonfireproof",
    "nonflammable",
    "nonfragrant",
    "nongeometric",
    "nongeometrical",
    "nonglacial",
    "nongreen",
    "nonhazardous",
    "nonhistoric",
    "nonhistorical",
    "nonincorporated",
    "nonincorporative",
    "nonintrospective",
    "nonintroversive",
    "nonintroverted",
    "noninvincible",
    "nonirrational",
    "nonlegal",
    "nonlegislative",
    "nonlineal",
    "nonlinear",
    "nonliteral",
    "nonliterary",
    "nonliving",
    "nonluminous",
    "nonmagnetic",
    "nonmathematic",
    "nonmathematical",
    "nonmedicable",
    "nonmedical",
    "nonmedicative",
    "nonmelodramatic",
    "nonmercenary",
    "nonmetallic",
    "nonmetalliferous",
    "nonmetallurgic",
    "nonmetallurgical",
    "nonmonarchal",
    "nonmonarchial",
    "nonmonarchic",
    "nonmonarchistic",
    "nonmystic",
    "nonmystical",
    "nonmythical",
    "nonmythologic",
    "nonmythological",
    "nonnational",
    "nonnationalistic",
    "nonobjective",
    "nonobjectivistic",
    "nonodoriferous",
    "nonodorous",
    "nonorganic",
    "nonpartisan",
    "nonphilosophic",
    "nonphilosophical",
    "nonplanetary",
    "nonpoisonous",
    "nonpolitical",
    "nonpriestly",
    "nonprogressive",
    "nonproift",
    "nonprophetic",
    "nonprophetical",
    "nonpsychiatric",
    "nonpsychic",
    "nonpsychical",
    "nonpsychoanalytic",
    "nonpsychoanalytical",
    "nonpsychologic",
    "nonpsychological",
    "nonpsychopathic",
    "nonpsychotic",
    "nonrational",
    "nonrationalised",
    "nonrationalistic",
    "nonrationalistical",
    "nonrectangular",
    "nonreligious",
    "nonritualistic",
    "nonromantic",
    "nonround",
    "nonroyal",
    "nonscholarly",
    "nonscholastic",
    "nonscholastical",
    "nonscientific",
    "nonsecular",
    "nonsensical",
    "nonsentient",
    "nonskeptic",
    "nonskeptical",
    "nonsolar",
    "nonsolicitous",
    "nonspheral",
    "nonspheric",
    "nonspherical",
    "nonspinal",
    "nonspiny",
    "nonspirited",
    "nonspiritous",
    "nonspiritual",
    "nonspirituous",
    "nonstick",
    "nonsticky",
    "nonstop",
    "nonsubjective",
    "nonterrestrial",
    "nonterritorial",
    "nontheatric",
    "nontheatrical",
    "nontheistic",
    "nontheistical",
    "nontheocratic",
    "nontheocratical",
    "nontheologic",
    "nontheological",
    "nontoxic",
    "nontrigonometric",
    "nontrigonometrical",
    "nonvacant",
    "nonvagrant",
    "nonvaluable",
    "nonvalued",
    "nonzoologic",
    "nonzoological",
    "normal",
    "northbound",
    "northeastern",
    "northern",
    "northernmost",
    "northmost",
    "northwestern",
    "nosey",
    "nosophobic",
    "nostalgic",
    "nosy",
    "notable",
    "notaphilic",
    "noteworthy",
    "notorious",
    "novel",
    "novice",
    "nubuck",
    "nuclear",
    "nude",
    "numb",
    "numbing",
    "numeric",
    "numerical",
    "nuptial",
    "nutbrown",
    "nutlike	",
    "nutritional",
    "nutritious",
    "nutty",
    "nyctophilic",
    "nyctophobic",
    "nylon",
    "oafish",
    "obedient",
    "obeliskoid",
    "obese",
    "objective",
    "objective",
    "oblivious",
    "oblong",
    "obnoxious",
    "obscene",
    "obsequious",
    "observant",
    "obsessive",
    "obsidian",
    "obsolete",
    "obtuse",
    "obvious",
    "occasional ",
    "occupational",
    "ocean-going",
    "oceanic",
    "oceanlike",
    "oceanographic",
    "oceanographical",
    "ochre",
    "octagonal",
    "octahedral",
    "odd",
    "odious",
    "odorful",
    "odoriferous-",
    "odorous",
    "odourful",
    "odourless",
    "off-colour",
    "offbeat",
    "offended",
    "offensive",
    "official",
    "ogreish",
    "oily",
    "okay",
    "old",
    "old-fashioned",
    "olericultural",
    "olfactophobic",
    "oligoantigenic",
    "olive",
    "olivine",
    "olympic",
    "ombrophilic",
    "ombrophobic",
    "ominous",
    "omnipotent",
    "omnipresent",
    "omniscient",
    "omnivorous",
    "omphacite",
    "ondontophobic",
    "onerous",
    "oniony",
    "only",
    "onyx",
    "oozy",
    "opal",
    "open-minded",
    "open",
    "operatic",
    "operational",
    "operose",
    "ophidiophilic",
    "ophidiophobic",
    "ophiophilic",
    "ophthalmological",
    "opinionated",
    "opposite",
    "oppressed",
    "oppressive",
    "optic",
    "optical",
    "optimal",
    "optimistic",
    "optometric",
    "optometrical",
    "orange",
    "orchestral",
    "orcish",
    "ordinary",
    "ore",
    "organic",
    "organisational",
    "organizational",
    "organoactinoid",
    "organometallic",
    "oriental",
    "original",
    "originative",
    "ornamental",
    "ornate",
    "ornery",
    "ornithologic",
    "ornithological",
    "ornithophilic",
    "ornithophobic",
    "orthoclase",
    "orthodontic",
    "orthodox",
    "orthogonal",
    "oryzivorous",
    "oscitant",
    "osmophilic",
    "osmophobic",
    "ossivorous",
    "ostentatious",
    "ostracized",
    "other",
    "otherworldly",
    "outdoor",
    "outdoorsy",
    "outer",
    "outgoing",
    "outraged",
    "outrageous",
    "outside",
    "outstanding",
    "oval",
    "overaggressive",
    "overbearing",
    "overbig",
    "overbrutal",
    "overburdened",
    "overconfident",
    "overconservative",
    "overconstant",
    "overcooked",
    "overcultured",
    "overcurious",
    "overdesirous",
    "overdestructive",
    "overdramatic",
    "overdry",
    "overemotional",
    "overempty",
    "overfaithful",
    "overgrown",
    "overhaughty",
    "overhostile",
    "overjoyed",
    "overjoyful",
    "overjoyous",
    "overliberal",
    "overliterary",
    "overluxuriant",
    "overluxurious",
    "overnoble",
    "overparticular",
    "overpolitical",
    "overpriced",
    "overrated",
    "overrational",
    "overreligious",
    "overseas",
    "oversize",
    "overskeptical",
    "oversolemn",
    "overtheatrical",
    "overvigorous",
    "overweak",
    "overwealthy",
    "overweight",
    "overwhelming",
    "overzealous",
    "oxygen",
    "oxymoronic",
    "pachydermal",
    "pachydermatous",
    "pachydermic",
    "pachydermoid",
    "pachydermous",
    "pacified",
    "pacifist",
    "pacifistic",
    "padparadscha",
    "paediatric",
    "pagan",
    "paganist",
    "paganistic",
    "painful",
    "painstaking",
    "painted",
    "palaeobiologic",
    "palaeobiological",
    "palaeobotanic",
    "palaeobotanical",
    "palaeoclimatologic",
    "palaeoclimatological",
    "palaeoecologic",
    "palaeoecological",
    "palaeological",
    "palaeophilic",
    "palaeozoologic",
    "palaeozoological",
    "pale",
    "paleobiologic",
    "paleobiological",
    "paleoclimatologic",
    "paleoclimatological",
    "paleoecologic",
    "paleoecological",
    "paleogeologic",
    "paleographic",
    "paleographical",
    "paleogrographical",
    "paleolithic",
    "paleological",
    "paleopsychic",
    "paleopsychological",
    "paleozoologic",
    "paleozoological",
    "palish",
    "pallid",
    "pancratic",
    "pancreatic",
    "panicky",
    "panoramic",
    "panphobic",
    "panpsychic",
    "panpsychistic",
    "pantheistic",
    "pantheistical",
    "paper",
    "paper-shelled",
    "papery",
    "papyraceous",
    "papyral",
    "paradoxal",
    "paradoxical",
    "paraffin",
    "paragonit",
    "paragonita",
    "paragonite",
    "parallel",
    "paralysed",
    "paralytic",
    "paralyzed",
    "paralyzing",
    "paramedical",
    "paramilitant",
    "paramilitaristic",
    "paramilitary	",
    "paramount",
    "paranoiac",
    "paranoid",
    "paranormal",
    "parapsychological",
    "parasitic",
    "parasiticidal",
    "paraskavedekatriaphobic",
    "paraskavidekatriaphobic",
    "parenthetic",
    "parenthetical",
    "parisyllabic",
    "parliamentary",
    "parochial",
    "parochialist",
    "parodic",
    "parodistic",
    "parsimonious",
    "part-time",
    "partial",
    "particular",
    "partly-coloured",
    "passionate ",
    "passive",
    "pastoral",
    "pasty",
    "pasty-faced",
    "patchwork",
    "patchy",
    "paternal",
    "pathetic",
    "pathworky",
    "patient",
    "patriarchal",
    "patriarchic",
    "patriarchical",
    "patrician",
    "patricidal",
    "patrilateral",
    "patrilineal",
    "patriotic",
    "patronal",
    "patronising",
    "patronizing",
    "pattern",
    "patterned",
    "patterny",
    "peaceable",
    "peaceful",
    "peach",
    "peachy",
    "peacockish",
    "peacocky",
    "pear",
    "pearl",
    "pearlized",
    "pearly",
    "peat",
    "pebble-dashed",
    "pebbly",
    "peckish",
    "peculiar",
    "pedagogical",
    "pedagogic",
    "pedagogish",
    "pedagoguish",
    "pedantic",
    "pediatric",
    "pediophobic",
    "pedophobic",
    "peerless",
    "peevish",
    "peewee",
    "pegmatite",
    "pelage",
    "penniless",
    "penny-pinching",
    "penny-wise",
    "pensive",
    "pentagonal",
    "pentagonoid",
    "pentangular",
    "pentasyllabic",
    "pepperish",
    "peppery",
    "peppy",
    "perceptive",
    "perfect",
    "perfumy",
    "pericardial",
    "pericranial",
    "peridental",
    "peridot",
    "peridotite",
    "periglacial",
    "perilous",
    "perispheric",
    "perispherical",
    "peristerophilic",
    "periwinkle",
    "periwinkled",
    "perkish",
    "perky",
    "perlucin",
    "permanent",
    "permier",
    "pernicious",
    "pernickety",
    "perovskite",
    "perpendicular",
    "perpetual",
    "perplexed",
    "perseverant",
    "persevering",
    "persimmon",
    "persistent",
    "persnickety",
    "personal",
    "perspicacious",
    "persuasive",
    "pescatarian",
    "pesky",
    "pessimistic",
    "pestersome",
    "pesticidal",
    "pestilent",
    "petaled",
    "petaline",
    "petalled",
    "petalless",
    "petalous",
    "petit",
    "petit-bourgeois",
    "petite",
    "petrified",
    "petrophilic",
    "pettifogging",
    "pettish",
    "petty",
    "petulant",
    "phagophobic",
    "phanerocystalline",
    "phantasmagorial",
    "phantasmagorian",
    "phantasmagoric",
    "phantasmagorical",
    "phantasmal",
    "phantastic",
    "phantastical",
    "phantom-like",
    "phantomlike",
    "pharmaceutical",
    "pharmacologic",
    "pharmacological",
    "phenocryst",
    "phenomenal",
    "philalethic",
    "philanthropic",
    "philharmonic",
    "philologic",
    "philological",
    "philosophical",
    "philosophical",
    "phlegmy",
    "phlogopite",
    "phobic",
    "phobophobic",
    "phonolite",
    "phonophobic",
    "phony",
    "phosphorescent",
    "phosphorus",
    "photodramatic",
    "photographic",
    "photoluminescent",
    "photonuclear",
    "photophilic",
    "photophobic",
    "photosensitive",
    "physical",
    "physiological",
    "phytoclimatologic",
    "phytoclimatological",
    "phytophilic",
    "pickled",
    "picky",
    "pictorial",
    "pictural",
    "picturesque",
    "piecemeal",
    "piercing",
    "pigeon-hearted",
    "pigeonite",
    "piggish",
    "pigish",
    "pilfered",
    "pillared",
    "pilotable",
    "pine",
    "pinelike",
    "pink",
    "pinkish",
    "pint-size",
    "piny",
    "pious",
    "piperaceous",
    "piratic",
    "piratical",
    "piscatorial",
    "piscatory",
    "piscicultural",
    "pisciform",
    "piscine",
    "piscivorous",
    "pisiform",
    "pitch-black",
    "pitch-dark",
    "piteous",
    "pithikosophilic",
    "pitiful",
    "pixilated",
    "pixyish",
    "placid",
    "plagihedral",
    "plaid",
    "plaided",
    "plain",
    "planetary",
    "planetoidal",
    "planispherical",
    "planktologic",
    "planktological",
    "plantsemiorganic",
    "plaster",
    "plastered",
    "plastery",
    "plastic",
    "platonic",
    "plausible",
    "playful",
    "pleasable",
    "pleasant",
    "pleased",
    "pleasing",
    "pleasurable",
    "pleasurable",
    "pleasure-seeking",
    "pleasureful",
    "plucky",
    "plug-ugly",
    "plump",
    "pluriliteral",
    "plush",
    "plushed",
    "plutonium",
    "poachable",
    "pock-marked",
    "poetic	",
    "pogonophilic",
    "pointless",
    "poisoned",
    "poisonous",
    "pokeable",
    "polar",
    "polarized",
    "polished",
    "polite",
    "political",
    "polka-dotted",
    "pollotarian",
    "polluted",
    "polonium",
    "polycystalline",
    "polyester",
    "polygonal",
    "polyhedral",
    "polyhistoric",
    "polymorphonuclear",
    "polynuclear",
    "polyphagous",
    "polysyllabic ",
    "pompous",
    "poor",
    "poor-spirited",
    "poorly",
    "popular",
    "porcelain",
    "porcine",
    "porky",
    "porous",
    "portable",
    "portly",
    "portrayable",
    "positive",
    "possessive",
    "possible",
    "post-apocalyptic",
    "post-modern",
    "post-war",
    "postal",
    "postarthritic",
    "postcardiac",
    "postdental",
    "postglacial",
    "postindustrial",
    "postlegal",
    "postpericardial",
    "postprophetic",
    "postscholastic",
    "pot-bellied",
    "potbellied",
    "potent",
    "potential",
    "potty",
    "poverty-stricken",
    "powder-blue",
    "powdery",
    "powellite",
    "powerful",
    "practical",
    "pragmatic",
    "pre-existent",
    "preachy",
    "preagricultural",
    "prealgebraic",
    "preartistic",
    "prebeloved",
    "prebronze",
    "precambrian",
    "precapitalistic",
    "precardiac",
    "precarnival",
    "precious",
    "precise",
    "precolourable",
    "precosmical",
    "precosmic",
    "precranial",
    "precrystalline",
    "precultural",
    "predacious",
    "predatory",
    "predesirous",
    "predespondent",
    "predestitute",
    "predeterminate",
    "predeterminative",
    "predicatable",
    "predictive",
    "prediplomatic",
    "predisastrous",
    "predominant",
    "predramatic",
    "preeconomic",
    "preeconomical",
    "preevolutional",
    "preferred",
    "prefinancial",
    "prefriendly",
    "preggers",
    "preglacial",
    "pregnant",
    "prehistoric",
    "prelawful",
    "prelegal",
    "prelegislative",
    "preliminary",
    "preliterary",
    "preliterate",
    "preluxurious",
    "premature",
    "premedical",
    "premium",
    "premolar",
    "premonarchal",
    "premonarchial",
    "premonarchical",
    "premythical",
    "prenatal",
    "prenational",
    "preobjective",
    "preoccupied",
    "preoceanic",
    "preodorous",
    "prepolitical",
    "prepsychological",
    "prepubescent",
    "prerational",
    "preregal",
    "preromantic",
    "preroyal",
    "prescient",
    "prescientific",
    "presecular",
    "presentient",
    "preshrunk",
    "presidential",
    "presolar",
    "prespinal",
    "prestigious",
    "presumptuous",
    "pretentious",
    "preterlegal",
    "preterrestrial",
    "prettied",
    "pretty",
    "prettying",
    "prettyish",
    "previgilant",
    "previous",
    "priceless",
    "pricey",
    "prickly",
    "prideful",
    "priestless",
    "priestly",
    "priggish",
    "prim",
    "primaeval",
    "primary",
    "primatologic",
    "primatological",
    "prime",
    "primitive",
    "primordial",
    "princely",
    "principal",
    "printed",
    "prior",
    "prismatic",
    "prissy",
    "pristine",
    "private",
    "privatized",
    "privileged",
    "privy",
    "proabolition",
    "proabsolutism",
    "proabsolutist",
    "proacademic",
    "proagrarian",
    "probable",
    "procapitalism",
    "prochurch",
    "proclergy",
    "proclerical",
    "prodemocrat",
    "prodemocratic",
    "productive",
    "profascist",
    "professional",
    "proficient",
    "profitable",
    "profound",
    "progressive",
    "progressive",
    "prolific",
    "promethean",
    "prominent",
    "promising",
    "promonarchy",
    "pronationalist",
    "pronationalistic",
    "proper",
    "prophesiable",
    "prophetic",
    "prophetic",
    "prophetical",
    "propolitics",
    "proportionable",
    "proportional",
    "proportioned",
    "proposed",
    "proromantic",
    "prosaic",
    "proscholastic",
    "proscience",
    "proscientific",
    "proselytical",
    "proselytistic",
    "prosperous",
    "protactium",
    "protected",
    "protective",
    "protozoological",
    "proud",
    "prouniversity",
    "provincial",
    "prudent",
    "prudish",
    "pseudoacademic",
    "pseudoanaemic",
    "pseudoangelic",
    "pseudoangelical",
    "pseudoartistic",
    "pseudoconservative",
    "pseudocrystalline",
    "pseudocultural",
    "pseudodemocratic",
    "pseudodivine",
    "pseudodramatic",
    "pseudoeconomical",
    "pseudofaithful",
    "pseudohexagonal",
    "pseudohistoric",
    "pseudohistorical",
    "pseudoinsane",
    "pseudolegal",
    "pseudolegislative",
    "pseudoliberal",
    "pseudoliterary",
    "pseudomedical",
    "pseudomythical",
    "pseudonational",
    "pseudonoble",
    "pseudopolitical",
    "pseudopriestly	",
    "pseudoprophetic",
    "pseudoprophetical",
    "pseudopsychological",
    "pseudoregal",
    "pseudoreligious",
    "pseudorhombohedral",
    "pseudoromantic",
    "pseudoroyal",
    "pseudoscholarly",
    "pseudoscholastic",
    "pseudoscientific",
    "pseudospiritual",
    "pseudotetragonal",
    "pseudozoological",
    "psychasthenic",
    "psychedelic",
    "psychiatric",
    "psychiatrical",
    "psychic",
    "psychoactive",
    "psychoanalytic",
    "psychoanalytical",
    "psychodelic ",
    "psychodiagnostic",
    "psychogenic",
    "psychographic",
    "psychological",
    "psychometric",
    "psychometrical",
    "psychoneurotic",
    "psychopathic",
    "psychopathologic",
    "psychopathological",
    "psychopharmacological",
    "psychophobic",
    "psychosocial",
    "psychosomatic",
    "psychotherapeutic",
    "psychotic",
    "psychotropic",
    "psychrophilic",
    "pubescent",
    "public",
    "publicized",
    "pudgy",
    "puerile",
    "puffy",
    "pugnacious",
    "pumice",
    "pumpkin",
    "punctilious",
    "punctual",
    "puny",
    "puppyish",
    "puppylike",
    "pure-hearted",
    "pure",
    "purebred",
    "purgatorial",
    "puritanical",
    "purple",
    "purplish",
    "purply",
    "purposeful",
    "purposeless",
    "puss-like",
    "putrid",
    "puzzled",
    "puzzling",
    "pygmyish",
    "pygmy",
    "pyrite",
    "pyrocrystalline",
    "pyrophobic",
    "pyroxene",
    "quaint",
    "qualified",
    "quarrelsome",
    "quarter-witted",
    "quartziferous",
    "quartzitic",
    "quartz",
    "queasy",
    "queenlike",
    "queenly",
    "quelled",
    "quenched",
    "quenching",
    "querulous",
    "questionable",
    "quibbling",
    "quick",
    "quick-tempered",
    "quick-witted",
    "quicksilvery",
    "quiescent",
    "quilted",
    "quintessential",
    "quixotic",
    "rabid",
    "radiant",
    "radiated",
    "radiation",
    "radical",
    "radioactive",
    "radiological",
    "radioluminescent",
    "radiophobic",
    "radium",
    "radon",
    "raggedraggedy",
    "raggle-taggle",
    "raging",
    "rainbow",
    "rainbowy",
    "rainproof",
    "rainy",
    "rancid",
    "rancorous",
    "rancour",
    "random",
    "ranidaphobic",
    "rapid",
    "rapt",
    "raptorial",
    "rapturous",
    "rare",
    "rash",
    "raskly",
    "rational",
    "rational",
    "ratlike",
    "rattish",
    "rattlebrained",
    "rattleheaded",
    "ravenous",
    "rawhide",
    "rayon",
    "readaptable",
    "readjustable",
    "ready",
    "ready-witted",
    "real",
    "realisable",
    "reanalyzable",
    "reapproachable",
    "rear",
    "rearmost",
    "rearrangeable",
    "reasonable",
    "reasonless",
    "reattachable",
    "rebel",
    "rebellious",
    "rebuffable",
    "rebuttable",
    "receivable",
    "recent",
    "receptive",
    "rechargeable",
    "recidivistic",
    "recitable",
    "reckless",
    "reckonable",
    "reclaimable",
    "reclinable",
    "recloseable",
    "reclusive",
    "recognized",
    "recommendable",
    "recompensable",
    "reconcilable",
    "reconstructible",
    "recordable",
    "recoverable",
    "recruitable",
    "rectangular",
    "rectilinear",
    "red-blooded",
    "reddish",
    "redeemable",
    "redemandable",
    "redissoluble",
    "redistillable",
    "redoubtable",
    "redressible",
    "reduced	",
    "redundant",
    "reedy",
    "refertilizable",
    "refillable",
    "reflectible",
    "reflective",
    "reflexional",
    "reflexive",
    "reforgeable",
    "reformable",
    "refractable",
    "refractional",
    "refractive",
    "refracturable",
    "refreshful",
    "refreshing",
    "refundable",
    "refusable",
    "refutable",
    "regainable",
    "regal",
    "regardable",
    "regenerable ",
    "regenerated",
    "regenerative",
    "regional",
    "registerable",
    "registered",
    "registrable",
    "regretful",
    "regrettable",
    "regulable",
    "regular",
    "rehearsable",
    "reincarnated",
    "reincarnating",
    "reinflatable",
    "reinforced",
    "reissuable",
    "rejectable",
    "rejoiceful",
    "relapsable",
    "relatable",
    "relative",
    "relaxative",
    "relaxatory",
    "relaxed",
    "relaxer",
    "releasable",
    "relegable",
    "relevant",
    "reliable",
    "reliant",
    "relievable",
    "relieved",
    "religionistic",
    "religious",
    "religious",
    "relishable",
    "reluctant",
    "remaining",
    "remarkable",
    "remittable",
    "remorseful",
    "remorseless",
    "removable",
    "renderable",
    "renegotiable",
    "renewed",
    "renounceable",
    "renowned",
    "reobtainable",
    "repairable",
    "repayable",
    "repealable",
    "repeatable",
    "repellent",
    "reponsible",
    "reportable",
    "reprehensible",
    "representational",
    "representative",
    "repressed",
    "repressible",
    "repressive",
    "reproachable",
    "reproductive",
    "reptilian",
    "reptiloid",
    "republican",
    "republishable",
    "repulsive",
    "repunishable",
    "required",
    "resalable",
    "resealable",
    "resentful",
    "reservable",
    "reserved",
    "resident",
    "residential",
    "resigned",
    "resistant",
    "resolvable",
    "respectable",
    "respected",
    "respectful",
    "respirable",
    "responsive",
    "restful",
    "resting",
    "restless",
    "restorable",
    "restorative",
    "restored",
    "restoring",
    "restrainable",
    "restrictive",
    "resurrectional",
    "resurrectionary",
    "resurrective",
    "resuscitative",
    "retail",
    "retaliative",
    "retaliatory",
    "retired",
    "retiring",
    "retouchable",
    "retrievable",
    "retrophilic",
    "returnable",
    "reunitable",
    "reusable",
    "revealable",
    "revengeful",
    "revenual",
    "revenued",
    "revered",
    "reverend",
    "reverent",
    "reversible",
    "reviewable",
    "reviled",
    "revisitable",
    "revivable",
    "revocable",
    "revolting",
    "revolutionary",
    "rheophilic",
    "rhinestone",
    "rhinophilic",
    "rhizophilic",
    "rhombic",
    "rhombohedral",
    "rhyolite",
    "ribbonlike",
    "ribbony",
    "rich",
    "rideable",
    "ridiculous",
    "right",
    "right-wing",
    "rightable",
    "righteous",
    "rightist",
    "riotous",
    "ripe",
    "ripening",
    "risky",
    "ritualistic",
    "ritzy",
    "rival",
    "roastable",
    "roasted",
    "roasting",
    "robo",
    "robotic",
    "robotlike",
    "robust",
    "rock-bound",
    "rock-faced",
    "rockable",
    "rocky",
    "roentgenium",
    "roguish",
    "rollable",
    "romantic",
    "romantic",
    "romanticistic",
    "rookie",
    "roomy",
    "ropable",
    "ropeable",
    "rose-colored",
    "roseate",
    "roselike",
    "rosy",
    "rotatable",
    "rotten",
    "rough",
    "round",
    "round-built",
    "rounded",
    "rowable",
    "royal",
    "royal",
    "royalistic",
    "rubber",
    "rubbery",
    "rubbly",
    "rubellite",
    "rubidium",
    "rubied",
    "ruby",
    "ruddy",
    "rude",
    "ruinable",
    "ruinous",
    "ruling",
    "runic",
    "running",
    "runtish",
    "runty",
    "rural",
    "russet",
    "rust",
    "rusted",
    "rustic",
    "rusty",
    "rutherfordium",
    "rutile",
    "saccharine",
    "sacramental",
    "sacred",
    "sacrificial",
    "sacrilegious",
    "saddened",
    "saddening",
    "sadistic",
    "safe",
    "sagacious",
    "sainted",
    "saintless",
    "saintly",
    "salamandrine",
    "salaried",
    "saline",
    "salmon",
    "salmonlike",
    "salmonoid",
    "salted",
    "saltish",
    "saltwater",
    "salty",
    "sanctified",
    "sanctimonious",
    "sand",
    "sanded	",
    "sandpapery",
    "sandstone",
    "sandy",
    "sane",
    "sangria",
    "sanguine",
    "sanidine",
    "sanitarian",
    "sanitary",
    "sapient",
    "sapphire",
    "sappy",
    "sarcastic",
    "sarcophilic",
    "sardonic",
    "sassy",
    "satiated",
    "satin",
    "satiny",
    "satirical",
    "satisfactory",
    "satisfied",
    "savage ",
    "savorous",
    "savourless",
    "savoury",
    "savvy",
    "sawdustish",
    "sawdusty",
    "scabby",
    "scabrous",
    "scaled",
    "scaley",
    "scaly",
    "scandalous",
    "scarabaeiform",
    "scarabaeoid",
    "scarecrowish",
    "scarecrowy",
    "scared",
    "scarlet",
    "scarred",
    "scary",
    "scathing",
    "scatterbrained",
    "scattered",
    "scavenger",
    "sceptical",
    "scheelite",
    "schematic",
    "scholarless",
    "scholarly",
    "scholarly",
    "scholastic",
    "scholastic",
    "scholiastic",
    "scientific",
    "scientific",
    "scintillating",
    "sciophilic",
    "scoleciphobic",
    "scopophobic",
    "scornful",
    "scorpaenoid",
    "scorpioid",
    "scorpionic",
    "scotophobic",
    "scowlful",
    "scrapable",
    "scratchy",
    "scrawny",
    "scribblenautable",
    "scribblenautible",
    "scribblenautical",
    "scribblenautic",
    "scribblenautilogical",
    "scribblenautilogic",
    "scribblenautophilic",
    "scribblenautophobic",
    "scribblephobic",
    "scribbophobic",
    "scribophobic",
    "scrummy",
    "scrumptious",
    "sculpturesque",
    "scummy",
    "sea-green",
    "sea-island",
    "seaborgium",
    "seaborne",
    "seafaring",
    "seagoing",
    "seal-brown",
    "seared",
    "seasick",
    "seasonal",
    "seaworthy",
    "secluded",
    "seclusive",
    "second-best",
    "second-class",
    "second-hand",
    "second-rate",
    "secondary",
    "secret",
    "secretive",
    "secular",
    "secularistic",
    "secure",
    "sedate",
    "sedentary",
    "sediment",
    "sedulous",
    "seedy",
    "seemly",
    "segregated",
    "seismic",
    "seismographic",
    "seismographical",
    "seismologic",
    "seismological",
    "seismoscopic",
    "select",
    "selective",
    "selenite",
    "selenium",
    "self-assured",
    "self-aware",
    "self-centered",
    "self-colored",
    "self-conceited",
    "self-contradiction",
    "self-deprecating",
    "self-depreciative",
    "self-destroyed",
    "self-destroying",
    "self-disgraced",
    "self-disgracing",
    "self-disquieting",
    "self-dissatisfied",
    "self-educated",
    "self-emptying",
    "self-evolved",
    "self-evolving",
    "self-existent",
    "self-honoured",
    "self-hypnotic",
    "self-hypnotised",
    "self-indulgent",
    "self-loving",
    "self-pleased",
    "self-pleasing",
    "self-righteous",
    "self-satisfied",
    "self-taught",
    "self-teaching",
    "self-trained",
    "self-vulcanising",
    "selfish",
    "selfless",
    "semantic",
    "semi-illiterate",
    "semi-intellectual",
    "semi-intellectualized",
    "semi-intelligent",
    "semi-ironic",
    "semi-ironical",
    "semiacademic",
    "semiacademical",
    "semiacidic",
    "semiacidified",
    "semiacidulated",
    "semiadhesive",
    "semiagricultural",
    "semibleached",
    "semiboiled",
    "semicapitalistic",
    "semiconservative",
    "semicontinuous",
    "semicrystalline",
    "semicultured",
    "semidestructive",
    "semidivine",
    "semidramatic",
    "semidramatical",
    "semidry",
    "semiemotional",
    "semiexperimental",
    "semifluid",
    "semigeometric",
    "semigeometrical",
    "semihistoric",
    "semihistorical",
    "semilegislative",
    "semiliberal",
    "semiliquid",
    "semiliterate",
    "semimagical",
    "semimagnetic",
    "semimagnetical",
    "semimarine",
    "semimathematical",
    "semimedicinal",
    "semimetallic",
    "semimonarchic",
    "semimonarchical",
    "semimystical",
    "semimythic",
    "semimythical",
    "seminationalistic",
    "semineurotic",
    "semineutral",
    "seminocturnal",
    "semiobjective",
    "semiparalysis",
    "semiparalyzed",
    "semipassive",
    "semipeaceful",
    "semipetrified",
    "semiphilosophic",
    "semiphilosophical",
    "semipoisonous",
    "semipolitical",
    "semiprimitive",
    "semiprogressive",
    "semipsychologic",
    "semipsychological",
    "semirationalised",
    "semirebellious",
    "semireligious",
    "semiretired",
    "semiromantic",
    "semiround",
    "semischolastic",
    "semisolemn",
    "semispheric",
    "semisubterranean",
    "semitheatric",
    "semitheatrical",
    "semitheological",
    "semivolcanic",
    "semivulcanised",
    "senatorial",
    "senile",
    "senior",
    "senseless",
    "sensible",
    "sensitive",
    "sensualist",
    "sentient",
    "sentimental",
    "separate",
    "sepia",
    "septic",
    "sequined",
    "seraphic",
    "serene",
    "serge",
    "sericate	",
    "sericeous",
    "sericultural",
    "serious",
    "serpentiform",
    "serpentine",
    "servile",
    "severe",
    "sewable",
    "shabby",
    "shaded",
    "shadeful",
    "shadowed",
    "shadowgraphic",
    "shadowy",
    "shady",
    "shaggy",
    "shagreen",
    "shakespearean",
    "shallow",
    "shamanic",
    "shamanistic",
    "shamefaced",
    "shameful ",
    "shameless",
    "shapable",
    "shapeable",
    "shapely",
    "shared",
    "sharp",
    "sharp-cut",
    "sharp-eyed",
    "sharp-set",
    "sharp-sighted",
    "sharp-tongued",
    "sharp-witted",
    "shaven-",
    "sheepish",
    "sheepskin",
    "sheer",
    "shell shocked",
    "shell-shocked",
    "shelled",
    "shellshocked",
    "shelly",
    "shiftable",
    "shifty",
    "shimmery",
    "shiny",
    "shocked",
    "shockproof",
    "shoddy",
    "shogunal",
    "short",
    "short-circuited",
    "short-handed",
    "short-sighted",
    "short-tempered",
    "short-term",
    "shorted",
    "shortish",
    "shortsighted",
    "shrewd",
    "shrinkable",
    "shrubby",
    "shrunken",
    "shy",
    "sibling",
    "sickening",
    "sicklied",
    "sickly",
    "sick",
    "siderophyllite",
    "sienna",
    "sighted",
    "sightless",
    "sightly",
    "significant",
    "silicone",
    "silken",
    "silk",
    "silky",
    "silly",
    "silt",
    "silty",
    "silvan",
    "silver",
    "silverish",
    "silvern",
    "silvery",
    "silvicolous",
    "silvicultural",
    "simaroubaceous",
    "simian",
    "similar",
    "simious",
    "simple",
    "simple-hearted",
    "simple-minded",
    "sincere",
    "sinful",
    "single",
    "single-minded",
    "sinister",
    "sinistrous",
    "sinking",
    "sinless",
    "sirenian",
    "sirenic",
    "sisterlike",
    "sisterly",
    "sitophobic",
    "sizable",
    "sizeable",
    "sized",
    "sizy",
    "skaldic",
    "skarn",
    "skeletal",
    "skeleton-like",
    "skeletonlike",
    "skeptical",
    "sketched",
    "sketchy",
    "skilful",
    "skilled",
    "skimpy",
    "skinny",
    "skipping",
    "skittish",
    "sky-blue",
    "skyborne",
    "skyscraping",
    "slandered",
    "slate",
    "slavish",
    "slavocratic",
    "sleepful",
    "sleeping",
    "sleepless",
    "sleepy",
    "slender",
    "slick",
    "slight",
    "slim",
    "slimline",
    "slimming",
    "slimy",
    "slippery",
    "slithery",
    "slobbery",
    "sloppy",
    "slothful",
    "slovenly",
    "slow",
    "slow-motion",
    "slow-moving",
    "slow-witted",
    "sludgy",
    "sluggish",
    "slumberless",
    "slumberous",
    "slushy",
    "small",
    "small-minded",
    "small-scale",
    "small-time",
    "smallish",
    "smart",
    "smart-aleck",
    "smart-alecky",
    "smarty",
    "smashable",
    "smashed",
    "smellable",
    "smelly",
    "smileless",
    "smiling",
    "smoggy",
    "smoking",
    "smoky",
    "smooth",
    "smooth-spoken",
    "smooth-tongued",
    "smudgeless",
    "smug",
    "snaky",
    "snappish",
    "snappy",
    "snazzy",
    "sneaking",
    "sneaky",
    "snide",
    "snippy",
    "snively",
    "snobbish",
    "snoopy",
    "snooty",
    "snoozy",
    "snotty",
    "snow-clad",
    "snow-white",
    "snowbound",
    "snowcapped",
    "snowy",
    "snug",
    "snugging",
    "so-called",
    "soaked",
    "soap-like",
    "soaplike",
    "soapstone",
    "soapsudsy",
    "soapy",
    "sociable",
    "social",
    "social-minded",
    "socialist",
    "socialistic",
    "socialized",
    "socioeconomic",
    "socioeconomical",
    "sociological",
    "sociopathic",
    "sociophobic",
    "sociopolitical",
    "sociopsychological",
    "sodalite",
    "sodium",
    "soft",
    "soft-hearted",
    "softish",
    "soggy",
    "solar",
    "soldierlike",
    "soldierly",
    "sole",
    "solemn",
    "solid",
    "solidifiable",
    "solitary",
    "sombre",
    "sombrous",
    "some",
    "somniphobic",
    "songful",
    "sonic",
    "sonorous",
    "soot",
    "sooty",
    "sophisticated",
    "sophomoric",
    "sopping",
    "soppy",
    "sorcerous",
    "sorrowless	",
    "sorry",
    "soubrettish",
    "sought-after",
    "soulful",
    "soulless",
    "sound",
    "soupy",
    "sour",
    "sourdough",
    "soured",
    "sourish",
    "southbound",
    "southeastern",
    "southeastward",
    "southern",
    "southernmost",
    "southmost",
    "southwestern",
    "spacious",
    "spangly",
    "spare",
    "sparkling",
    "sparse ",
    "spatial",
    "special",
    "specialized",
    "specific",
    "specified",
    "specious",
    "spectacular",
    "spectrophobic",
    "specular",
    "speculative",
    "speedful",
    "speedless",
    "speedy",
    "spellbound",
    "spendthrift",
    "sphalerite",
    "sphene",
    "spheral",
    "sphereless",
    "spherelike",
    "spherical",
    "spherical",
    "spheroidal",
    "spherular",
    "sphingine",
    "sphinxian",
    "spicey",
    "spicy",
    "spidersilk",
    "spidery",
    "spiky",
    "spinal",
    "spined",
    "spineless",
    "spinelike",
    "spinescent",
    "spiniferous",
    "spinous",
    "spinulose",
    "spiny",
    "spirite",
    "spirited",
    "spiritless",
    "spiritous",
    "spiritual",
    "spiritualistic",
    "spiritual",
    "spiteful",
    "splendid",
    "splendiferous",
    "splendorous",
    "splintery",
    "splurgy",
    "spodumene",
    "spoiled",
    "spongy",
    "spontaneous",
    "spooky",
    "sporadic",
    "sportful",
    "sporting",
    "sportive",
    "sportsmanlike",
    "sportsmanly",
    "sporty",
    "spotless",
    "spottable",
    "spotted",
    "spotty",
    "sprightful",
    "sprightly",
    "spring-loaded",
    "springy",
    "sprucing",
    "spy",
    "squalid",
    "square",
    "squarish",
    "squeamish",
    "squirarchal",
    "squirarchical",
    "squirearchal",
    "squirearchical",
    "squirrelish",
    "squirrellike",
    "squirrelly",
    "squishy",
    "stable",
    "stagnant",
    "stagnantory",
    "stainable",
    "stalactiform",
    "stalagmitic",
    "stalagmitical",
    "stalagmometric",
    "stale",
    "stalwart",
    "stampable",
    "standard",
    "standardisable",
    "star-crossed",
    "star-spangled",
    "star-studded",
    "starchy",
    "starred",
    "starry",
    "starved",
    "starving",
    "statesmanlike",
    "statesmanly",
    "static",
    "stational",
    "stationary",
    "statistical",
    "statued",
    "statuelike",
    "statuesque",
    "statutory",
    "steadfast",
    "stealthful",
    "stealthless",
    "stealthy",
    "steam-heated",
    "steamy",
    "steel",
    "steep",
    "stegophilic",
    "stellar",
    "stenchful",
    "stereotyped",
    "sterile",
    "sterilised",
    "sterilized",
    "sterling",
    "sticky",
    "stigmatophilic",
    "still",
    "still-life",
    "stimulated",
    "stimulating",
    "stingy",
    "stinky",
    "stoic",
    "stoical",
    "stolen",
    "stomach-achy",
    "stomachy",
    "stone",
    "stone-broke",
    "stoned",
    "stonelike",
    "stoneware",
    "stoney",
    "stony",
    "stony-hearted",
    "stoppable",
    "stormproof",
    "stormy",
    "stout",
    "stouthearted",
    "stoutish",
    "straight",
    "straight-laced",
    "straightforward",
    "strained",
    "strange",
    "strategic",
    "straw-colored",
    "streaky",
    "streetsmart",
    "streetwise",
    "strengthened",
    "strenuous",
    "stressed",
    "stressful",
    "stretchable",
    "stretchy",
    "stricken",
    "strict",
    "striking",
    "stringent",
    "striped",
    "stripy",
    "strong",
    "strong-minded",
    "strong-willed",
    "strongish",
    "strontium",
    "structural",
    "stubborn",
    "stuck",
    "stuck-up",
    "studious",
    "stuffed",
    "stumplike",
    "stumpy",
    "stunty",
    "stupendous",
    "stupid",
    "stylish",
    "suave",
    "subabsolute",
    "subacademic",
    "subacademical",
    "subalgebraic",
    "subalgebraical",
    "subatomic",
    "subaverage",
    "subclimatic",
    "subconscious",
    "subcranial",
    "subcrystalline",
    "subcultural",
    "subdendroid",
    "subdendroidal",
    "subdermal",
    "subdermic",
    "subdivine",
    "subdued",
    "subendocardial",
    "suberin",
    "subevergreen",
    "subgeometric",
    "subgeometrical",
    "subglacial",
    "subhedral",
    "subhemispheric",
    "subhemispherical",
    "subhexagonal",
    "subjective",
    "subjective",
    "sublimational",
    "sublime",
    "subliminal",
    "sublinear",
    "submetallic",
    "submissive	",
    "subocean",
    "suboceanic",
    "subordinate",
    "subpentagonal",
    "subpericardiac",
    "subpericardial",
    "subpericranial",
    "subpolygonal",
    "subpyramidal",
    "subpyramidic",
    "subpyramidical",
    "subpyriform",
    "subquadrangular",
    "subquadrate",
    "subquinquefid",
    "subrectangular",
    "subsequent",
    "subservient",
    "subsimian",
    "subsimious",
    "subsolar",
    "subsonic",
    "subspheric ",
    "subspherical",
    "substantial",
    "subterranean",
    "subterraqueous",
    "subterrestrial",
    "subtle",
    "subtractive",
    "subtransparent",
    "subtrapezoid",
    "subtrapezoidal",
    "subtriangular",
    "subtrigonal",
    "subtrihedral-",
    "subtropical",
    "suburban",
    "suburbicarian",
    "subversive",
    "subwealthy",
    "subzero",
    "succeedable",
    "successful",
    "successive",
    "succinct",
    "succulent",
    "sudden",
    "sudoriferous",
    "sudorific",
    "sudsy",
    "suede",
    "sufficient",
    "suffixal",
    "sugar",
    "sugar-candy",
    "sugar-cane",
    "sugar-loaf",
    "sugared",
    "sugarless",
    "sugary",
    "suicidal",
    "suitable",
    "sulfureous",
    "sulfur",
    "sulfuric",
    "sulfurous",
    "sulfuryl",
    "sulky",
    "sullen",
    "sultanic",
    "sultanlike",
    "sun-dried",
    "sunbaked",
    "sunbeamed",
    "sunbeamy",
    "sunlit",
    "sunny",
    "sunshiny",
    "super-duper",
    "super-smooth",
    "superagrarian",
    "superangelic",
    "superb",
    "superbeloved",
    "supercatastrophic",
    "supercilious",
    "supercolossal",
    "superconservative",
    "supercriminal",
    "supercurious",
    "superdemocratic",
    "superdesirous",
    "superdifficult",
    "superdivine",
    "superenergetic",
    "superexcited",
    "superficial",
    "superfluous",
    "supergenerous",
    "superglacial",
    "superhistoric",
    "superhistorical",
    "superimportant",
    "superior",
    "superlative",
    "superlucky",
    "superluxurious",
    "supermarine",
    "supermathematical",
    "supernational",
    "supernatural",
    "supernaturalistic",
    "superpolite",
    "superpowered",
    "superrational",
    "superregal",
    "superromantic",
    "supersafe",
    "superscholarly",
    "superscientific",
    "supersecretive",
    "supersecular",
    "supersecure",
    "supersensitive",
    "superserious",
    "supersmart",
    "supersolar",
    "supersolemn",
    "supersonic",
    "superspiritual",
    "superstitious",
    "superstrict",
    "superstylish",
    "supersweet",
    "superterrestrial",
    "superugly",
    "supervigilant",
    "supervigorous",
    "superwealthy",
    "supery",
    "superzealous",
    "supplemental",
    "supplementary",
    "suppletive",
    "supporting",
    "supportive",
    "supranational",
    "supreme",
    "surah",
    "sure",
    "sure-footed",
    "surgical",
    "surly",
    "surprised",
    "surprising",
    "surreal",
    "surreptitious",
    "susceptible",
    "suspect",
    "suspicious",
    "sustainable",
    "svelte",
    "swallowable",
    "swampy",
    "swanky",
    "swash-buckling",
    "sweated",
    "sweating",
    "sweaty",
    "sweepable",
    "sweet",
    "sweet-scented",
    "sweet-tempered",
    "sweltering",
    "swift",
    "swift-footed",
    "swimming",
    "swindled",
    "swinish",
    "swirly",
    "sybaritic",
    "sycophantic",
    "syllabic",
    "sylphic",
    "sylphish",
    "sylphlike",
    "sylphy",
    "symbiotic",
    "symbolic",
    "symmetric",
    "symmetrical",
    "sympathetic",
    "symphonic",
    "symphonious",
    "symptomatic",
    "synarchist",
    "synecologic",
    "synecological",
    "synonymous",
    "synthetic",
    "syrupy",
    "tabarded",
    "taboo",
    "tacky",
    "tactful",
    "tactical",
    "tailor-made",
    "tailored",
    "tainted",
    "talented",
    "talismanic",
    "talismanical",
    "talkable",
    "talkative",
    "talky",
    "tall",
    "tame",
    "tamed",
    "taming",
    "tangerine",
    "tangible",
    "tangled",
    "tangy",
    "tanned",
    "tantalizing",
    "tantalous",
    "tanzanite",
    "tapestried",
    "taphophobic",
    "tardy",
    "targeted",
    "tart",
    "tasteful",
    "tasteless",
    "tasty",
    "tattooed",
    "taupe",
    "taurine",
    "taut",
    "tautological",
    "tawdry",
    "tax-deductible",
    "tax-exempt",
    "taxidermal",
    "taxidermic",
    "taxidermy",
    "taxing",
    "taxonomic",
    "taxonomical",
    "teal",
    "tearful",
    "tearing",
    "teary",
    "technical	",
    "technocrat",
    "technocratic",
    "technological",
    "technophilic",
    "technophobic",
    "techy",
    "tectonic",
    "tedious",
    "teen",
    "teenage",
    "teensy",
    "teensy-weensy",
    "teeny",
    "teeny-tiny",
    "teeny-weeny",
    "tekite",
    "telegraphic",
    "telegraphical",
    "telekinetic",
    "telepathic",
    "temperamental",
    "temperate",
    "temporal ",
    "temporary",
    "tempting",
    "temptuous",
    "tender",
    "tender-hearted",
    "tense",
    "tenuous",
    "terdekaphobia",
    "teriyaki",
    "termitic",
    "terra-cotta",
    "terrazzo",
    "terrestrial",
    "terrible",
    "terrific",
    "terrified",
    "terrifying",
    "territorial",
    "territorial",
    "terror-stricken",
    "terrorful",
    "terroristic",
    "terrorless",
    "terse",
    "tertiary",
    "testy",
    "tetartohedral",
    "tetragonal",
    "tetrahedral",
    "textbookish",
    "textile",
    "thalassophilic",
    "thankful",
    "thankless",
    "theatrical",
    "theatrical",
    "theistical",
    "theistic",
    "theocentric",
    "theocratical",
    "theocratic",
    "theodicean",
    "theological",
    "theomorphic",
    "theophagous",
    "theophilic",
    "theoretical",
    "theosophical",
    "theosophic",
    "therapeutic",
    "thermal",
    "thermodynamic",
    "thermonuclear",
    "thermophilic",
    "thermophobic",
    "thick-skulled",
    "thick-witted",
    "thickset",
    "thick",
    "thieving",
    "thievish",
    "thin",
    "thinnish",
    "thirsty",
    "thistle",
    "thistly",
    "thorium",
    "thorny",
    "thorough",
    "thoroughbred",
    "thoughtful",
    "thoughtless",
    "threadbare",
    "threatening",
    "threatful",
    "threpterophilic",
    "thrifty",
    "thrillful",
    "thrilling",
    "ticklish",
    "tidal",
    "tidy",
    "tiff",
    "tigers-eye",
    "tight-knit",
    "timbrophilic",
    "time-consuming",
    "timeless",
    "timely",
    "timid",
    "tin",
    "tin-foil",
    "tinned",
    "tinny",
    "tinted",
    "tiny",
    "tippable",
    "tired",
    "tireless",
    "tiresome",
    "titanic",
    "titaniferous",
    "titanite",
    "titanium",
    "titanous",
    "toadish",
    "toadyish",
    "tokophobic",
    "tolerant",
    "tomophobic",
    "tongue-tied",
    "toothsome",
    "top-secret",
    "topaz",
    "topazine",
    "topiary",
    "topnotch",
    "torrential",
    "torrid",
    "tortoise shell",
    "tortoise shelled",
    "totalitarian",
    "touchy",
    "tough",
    "touristic",
    "touristy",
    "tourmaline",
    "tourmalinic",
    "tow-colored",
    "towering",
    "toxic",
    "toxicological",
    "toxophilic",
    "toylike",
    "trachyte",
    "traditional",
    "tragic",
    "trainsick",
    "traitorous",
    "tranquil",
    "transcendent",
    "transcendental",
    "transcendentalistic",
    "transcolour",
    "transcrystalline",
    "transcultural",
    "transhuman",
    "transient",
    "translucent",
    "translunar",
    "transmarine",
    "transoceanic",
    "transparent",
    "transplanetary",
    "transrational",
    "trapezial",
    "trapeziform",
    "trapezohedral",
    "trapezohedron",
    "trashy",
    "tratasyllabic",
    "tratasyllabical",
    "traumatic",
    "traumatized",
    "traumatophobic",
    "travel-sick",
    "travelsick",
    "treacherous",
    "treasonable",
    "treasonous",
    "treelike",
    "tremendous",
    "trendy",
    "tribal",
    "trichophobia",
    "trickish",
    "tricksome",
    "tricksy",
    "tricky",
    "tricolour",
    "tricoloured",
    "tridymite",
    "trifling",
    "trigonal",
    "trigonometric",
    "trigonometrical",
    "trigonous",
    "trihedral",
    "trilateral",
    "trilinear",
    "triliteral",
    "trimetallic",
    "triskaidekaphobic",
    "trisyllabic",
    "trisyllabical",
    "triumphal",
    "triumphant",
    "trivial",
    "troglodytic",
    "troglodytical",
    "trogonoid",
    "trophic",
    "trophied",
    "tropical",
    "troubled",
    "troublesome",
    "troubling",
    "true-blue",
    "true-born",
    "true-hearted",
    "trustful",
    "trusting",
    "trustworthy",
    "truthful",
    "trypanophobic",
    "tsarist",
    "tsaristic",
    "tsunamic",
    "tubby",
    "tuneful",
    "turbid",
    "turophilic",
    "turpentinic",
    "turquoise",
    "turtle shell",
    "turtle shelled",
    "tweed",
    "tweedy",
    "twill",
    "two-faced",
    "typhlophilic",
    "typical",
    "tyrannical",
    "tyrannicidal	",
    "tyrannous",
    "tzarist",
    "tzaristic",
    "uber",
    "ubiquitary",
    "ubiquitous",
    "ugly",
    "ulcerative",
    "ulcerous",
    "ultimate",
    "ultraconservative",
    "ultrafaultless",
    "ultramarine",
    "ultramicroscopic",
    "ultramicroscopical",
    "ultramodern",
    "ultramundane",
    "ultrapink",
    "ultrashort",
    "ultrasonic",
    "ultratropical",
    "umbral",
    "unable ",
    "unacademic",
    "unacademical",
    "unacceptable",
    "unaccepted",
    "unacidic",
    "unacidulated",
    "unacknowledged",
    "unactivated",
    "unadhesive",
    "unadjoining",
    "unadored",
    "unadult",
    "unadventurous",
    "unadverturesome",
    "unadvised",
    "unaesthetic",
    "unaesthetical",
    "unafraid",
    "unaggressive",
    "unagrarian",
    "unagricultural",
    "unalgebraical",
    "unalienated",
    "unallegorical",
    "unallegorised",
    "unallergic",
    "unalliterated",
    "unalliterative",
    "unalphabetic",
    "unalphabetical",
    "unalphabetised",
    "unamazed",
    "unambitious",
    "unamiable",
    "unamicable",
    "unamorous",
    "unamusable",
    "unamused",
    "unamusing",
    "unanarchic",
    "unanarchistic",
    "unangry",
    "unanguished",
    "unanimated",
    "unanimating",
    "unannotated",
    "unapologetic",
    "unappealing",
    "unappeased",
    "unappreciated",
    "unapproachable",
    "unarithmetical",
    "unarmed",
    "unaroused",
    "unartful",
    "unartistic",
    "unassuming",
    "unathletic",
    "unattractive",
    "unauthorized",
    "unavoidable",
    "unawake",
    "unawakeable",
    "unaware",
    "unbackward",
    "unbathed",
    "unbeatable",
    "unbeaten",
    "unbecoming",
    "unbefriended",
    "unbelievable",
    "unbeloved",
    "unbiased",
    "unbiological",
    "unblacked",
    "unblackened",
    "unblued",
    "unbrowned",
    "unbuoyant",
    "unburied",
    "unburning",
    "uncalorific",
    "uncanny",
    "uncapitalistic",
    "uncarnivorous",
    "uncatalogued",
    "uncategorised",
    "uncertain",
    "unchanged",
    "uncharitable",
    "uncheerable",
    "uncheered",
    "uncheerful",
    "uncheering",
    "uncheery",
    "unchildish",
    "unchildlike",
    "uncitizenly",
    "uncivic",
    "uncivil",
    "uncivilisable",
    "uncivilised",
    "unclean",
    "uncleanable",
    "uncleaned",
    "uncleansable",
    "uncleansed",
    "unclear",
    "uncolourable",
    "uncoloured",
    "uncomfortable",
    "uncommon",
    "uncompetent",
    "unconfident",
    "uncongested",
    "uncongestive",
    "unconquerable",
    "unconscious",
    "unconstant",
    "unconstitutional",
    "uncontagious",
    "uncontinuous",
    "uncontradictable",
    "uncontradicted",
    "uncontradictious",
    "uncontradictive",
    "uncontradictory",
    "uncontrollable",
    "uncooked",
    "uncooperative",
    "uncouth",
    "uncovered",
    "uncreative",
    "uncrystalled",
    "uncrystalline",
    "uncrystallisable",
    "uncrystallised",
    "unculturable",
    "uncultured",
    "uncurable",
    "undamageable",
    "undamaged",
    "undamaging",
    "undead",
    "undecided",
    "undecipherable",
    "undefeatable",
    "undefeated",
    "undefiled",
    "undeified",
    "undeistical",
    "undejected",
    "undelicious",
    "undelighted",
    "undelightful",
    "undelighting",
    "undemocratic",
    "undeniable",
    "undenominated",
    "underage",
    "underaverage",
    "undercoloured",
    "undercover",
    "undereducated",
    "underemployed",
    "underground",
    "underhanded",
    "underpowered",
    "underpriced",
    "underprivileged",
    "underqualified",
    "understated",
    "understood",
    "underterrestrial",
    "underweight",
    "undesirable",
    "undesired",
    "undesirous",
    "undespaired",
    "undespairing",
    "undespised",
    "undespising",
    "undespondent",
    "undespotic",
    "undestined",
    "undestitute",
    "undestroyed",
    "undestructible",
    "undestructive",
    "undevilish",
    "undifficult",
    "undigestible",
    "undignified",
    "undiplomatic",
    "undiseased",
    "undisgraced",
    "undisgusted",
    "undisheartened",
    "undisheveled",
    "undishevelled",
    "undishonoured",
    "undivinable",
    "undivined",
    "undivining",
    "undramatic",
    "undramatical",
    "undramatisable",
    "undramatised",
    "undrinkable",
    "undyed",
    "unearthly",
    "uneasy",
    "uneconomic",
    "uneconomical",
    "uneconomising",
    "uneducated",
    "unemotional",
    "unemployed",
    "unemptied",
    "unempty",
    "unentertainable",
    "unentertained",
    "unentertaining",
    "unenthusiastic",
    "unequal",
    "unequaled",
    "unequalled",
    "unethical",
    "unevolved",
    "unevolving",
    "unexistent",
    "unexistential",
    "unexisting	 ",
    "unexpected",
    "unexperimental",
    "unexplainable",
    "unexplained",
    "unextraordinary",
    "unextravagant",
    "unfair",
    "unfaithful",
    "unfashionable",
    "unfavourable",
    "unfeared",
    "unfearful",
    "unfearing",
    "unfeeling",
    "unfired",
    "unfiring",
    "unfit",
    "unfleshly",
    "unfooled",
    "unfoolish",
    "unforgiving",
    "unfortunate",
    "unfragrant  ",
    "unfriended ",
    "unfrightened ",
    "unfrightening ",
    "ungentlemanly ",
    "ungeometric ",
    "ungeometrical ",
    "unglacial ",
    "unglaciated ",
    "ungodlike ",
    "ungodly ",
    "ungracious ",
    "ungrammatical ",
    "ungreened",
    "unhappy ",
    "unhealthy ",
    "unheavenly ",
    "unheedful ",
    "unheeding ",
    "unhelpful ",
    "unhelping ",
    "unhistoric ",
    "unhistorical ",
    "unhistoried ",
    "unholy ",
    "unhonoured ",
    "unhuman ",
    "unhumane ",
    "unhumanistic ",
    "unhumanitarian ",
    "unhydrated ",
    "unhygenic ",
    "unhygienic ",
    "unicolor",
    "unidentifiable",
    "unidentified ",
    "uniform ",
    "uniformitarian",
    "unilateral ",
    "unilateralised",
    "uniliteral ",
    "unimaginable ",
    "unimaginative ",
    "unimmunised",
    "unimportant",
    "unimpoverished",
    "unincorporated",
    "uninfected",
    "uninfectious",
    "uninfested",
    "uninformed",
    "uninspirable",
    "uninspired",
    "uninspiring",
    "uninsured",
    "unintellectual",
    "unintelligent",
    "unintentional",
    "uninterested",
    "uninteresting ",
    "unintroversive ",
    "unintroverted ",
    "uninvincible ",
    "uninvolved ",
    "unique ",
    "unirritable ",
    "unirritated ",
    "unisex ",
    "united ",
    "universal ",
    "unjust ",
    "unkempt ",
    "unkind ",
    "unkindhearted ",
    "unkissed ",
    "unknown ",
    "unlawful ",
    "unlegal ",
    "unlegalised ",
    "unlegislated ",
    "unlegislative ",
    "unleisurely ",
    "unliberalised ",
    "unliberalized ",
    "unliberated ",
    "unlight ",
    "unlighted ",
    "unlightened ",
    "unlikely ",
    "unlimited ",
    "unlit ",
    "unliterary ",
    "unliterate ",
    "unlovable ",
    "unloved ",
    "unlovely",
    "unlucky",
    "unlunar",
    "unluxuriant",
    "unluxuriating",
    "unluxurious",
    "unmarried",
    "unmathematical",
    "unmedical",
    "unmedicinal",
    "unmelodramatic",
    "unmelted",
    "unmercenary",
    "unmerchantable",
    "unmerciful",
    "unmetalled",
    "unmetallic",
    "unmetallurgic",
    "unmetallurgical",
    "unmindful",
    "unmodified",
    "unmonarchic",
    "unmonarchical",
    "unmotivated",
    "unmystic",
    "unmystical",
    "unmystified",
    "unmythical",
    "unmythological",
    "unnarrow-minded",
    "unnational",
    "unnationalised",
    "unnationalistic",
    "unnecessary",
    "unneeded",
    "unnoted",
    "unnoteworthy",
    "unnoticeable",
    "unnoticed",
    "unobjective",
    "unobservant",
    "unoceanic",
    "unodoriferous",
    "unodorous",
    "unoperatable",
    "unopinionated",
    "unopinioned",
    "unoptimistic",
    "unostentatious",
    "unoutlawed",
    "unpacified",
    "unpacifistic",
    "unpaid",
    "unparalleled",
    "unparalysed",
    "unparenthesised",
    "unparenthesized",
    "unparenthetic",
    "unparenthetical",
    "unphilosophic",
    "unphilosophical",
    "unplayable",
    "unplayful",
    "unpleasant",
    "unpleased",
    "unpleasing",
    "unpleasurable",
    "unpoliced",
    "unpolitical",
    "unpopular",
    "unpraiseworthy",
    "unpredestined",
    "unpredictable",
    "unpretending",
    "unpretentious",
    "unprincipled",
    "unprofessional",
    "unprofitable",
    "unpronounceable",
    "unprophesied",
    "unprophetic",
    "unprophetical",
    "unprotected",
    "unpsychic",
    "unpsychological",
    "unpsychopathic",
    "unpsychotic",
    "unpurified",
    "unqualified",
    "unquenchable",
    "unquenched",
    "unquiet",
    "unquietable",
    "unquieted",
    "unquieting",
    "unrationable",
    "unrational",
    "unrationalised",
    "unrationalising",
    "unread",
    "unreadable",
    "unreal",
    "unrealistic",
    "unreasonable",
    "unrectangular",
    "unrefrigerated",
    "unregal",
    "unrelative",
    "unrelativistic",
    "unrelaxable",
    "unrelaxed",
    "unrelaxing",
    "unreligioned",
    "unreligious",
    "unremarkable",
    "unremorseful",
    "unreputable",
    "unrestrained",
    "unrestricted",
    "unrestrictive",
    "unrideable",
    "unritual",
    "unritualistic",
    "unrivaled",
    "unromantic",
    "unromanticised",
    "unrounded",
    "unruly",
    "unsafe",
    "unsainted",
    "unsaintly",
    "unsalted",
    "unsalty",
    "unsanitary",
    "unsanitised",
    "unsanitized",
    "unsatisfied",
    "unsavoury",
    "unscholastic	",
    "unschooled",
    "unscientific",
    "unscrupulous",
    "unsecular",
    "unsecularised",
    "unsecure",
    "unselfish",
    "unsentient",
    "unshakable",
    "unshaken",
    "unsightly",
    "unsinful",
    "unsinkable",
    "unskeptical",
    "unskillful",
    "unsleepy",
    "unsocial",
    "unsolar",
    "unsolemn",
    "unsolemnified",
    "unsolemnised",
    "unsolicitated",
    "unsolicited ",
    "unsolicitous",
    "unsophisticated",
    "unspecialized",
    "unspecific",
    "unspecified",
    "unspectacular",
    "unspherical",
    "unspirited",
    "unspiriting",
    "unspiritual",
    "unstable",
    "unstoppable",
    "unsubjective",
    "unsuccessful",
    "unsuitable",
    "unsuited",
    "unsure",
    "unsuspecting",
    "unsustainable",
    "unsweet",
    "unsweetened",
    "unsyllabicated",
    "unsyllabified",
    "unsyllabled",
    "unsympathetic",
    "untalented",
    "untameable",
    "unterrestrial",
    "unthankful",
    "unthanking",
    "untheatric",
    "untheistic",
    "untheistical",
    "untheological",
    "untheologic",
    "unthinkable",
    "unthinking",
    "untidied",
    "untidy",
    "untidying",
    "untimely",
    "untiring",
    "untouchable",
    "untraditional",
    "untrigonometrical",
    "untrigonometric",
    "untroublesome",
    "untrusting",
    "untruthful",
    "ununbium",
    "ununhexium",
    "ununoctium",
    "ununpentium",
    "ununquadium",
    "ununseptium",
    "ununtrium",
    "unusual",
    "unvacant",
    "unvagrant",
    "unventuresome",
    "unventurous",
    "unverifiable",
    "unverified",
    "unwanted",
    "unwashed",
    "unwasteful",
    "unwealthy",
    "unwearied",
    "unwelcome",
    "unwhite",
    "unwhited",
    "unwhitened",
    "unwhitewashed",
    "unwholesome",
    "unwieldable",
    "unwieldy",
    "unwilling",
    "unwise",
    "unwitty",
    "unwomanish",
    "unwomanlike",
    "unworldly",
    "unworthy",
    "upbeat",
    "upper",
    "upper-class",
    "uppity",
    "upright",
    "upset",
    "upstanding",
    "uptight",
    "uranium",
    "urban",
    "urbane",
    "urgent",
    "urological",
    "usable",
    "used",
    "useful",
    "useless",
    "usual",
    "usurious",
    "utilitarian",
    "utilizable",
    "utopian",
    "utopic",
    "vacant",
    "vaccinated",
    "vacuous",
    "vague",
    "vain",
    "vainglorious",
    "valiant",
    "valid",
    "valorous",
    "valuable",
    "valued",
    "vampiric",
    "vanilla",
    "vanillic",
    "vanitied",
    "vanquishable",
    "vapid",
    "vaporescent",
    "vaporific",
    "vaporish",
    "vaporous",
    "vapory",
    "vapourescent",
    "vapourific",
    "vapourish",
    "vapoury",
    "variable",
    "varicoloured",
    "varied",
    "varve",
    "varying",
    "vast",
    "vaterite",
    "vegan",
    "veganarchist",
    "vegetal",
    "vegetarian",
    "vegetative",
    "veiny",
    "vellum",
    "velour",
    "velvet",
    "velveteen",
    "velvety",
    "venal",
    "venerable",
    "venerated",
    "vengeful",
    "venomous",
    "ventriloquial",
    "ventriloquistic",
    "venturesome",
    "venturous",
    "venustraphobic",
    "verastile",
    "verbose",
    "verifiable",
    "verified",
    "vermicidal",
    "vermicular",
    "vermiform",
    "vermillion",
    "verminous",
    "vermivorous",
    "vernal",
    "versicolor",
    "vertical",
    "very blue",
    "very flying",
    "very mad",
    "very very blue",
    "very very flying",
    "very very mad",
    "very very very blue",
    "very very very flying",
    "very very very mad",
    "vestigial",
    "vexatious",
    "vibrant",
    "viceregal",
    "vicious",
    "victimized",
    "victorious",
    "videophilic",
    "viewable",
    "vigilant",
    "vigorous",
    "vile",
    "villainous",
    "vincible",
    "vinegarish",
    "vinegary",
    "vinicultural",
    "vinifera",
    "vinyl",
    "violent",
    "violet",
    "violety",
    "viperine",
    "viperish",
    "viperous",
    "viral",
    "virile",
    "virtuous",
    "visible",
    "visionary",
    "vital",
    "vitriolic",
    "vivacious",
    "vivid",
    "vixenish",
    "vixenly",
    "vocational",
    "voguish",
    "volatile",
    "volcanic",
    "volcanologic",
    "volcanological",
    "voltaic",
    "volumed",
    "voluminous",
    "voluptuary",
    "voluptuous",
    "voodooistic",
    "voracious",
    "vulcanian",
    "vulcanisable	",
    "vulcanological",
    "vulgar",
    "vulnerable",
    "vulpine",
    "wacky",
    "wafery",
    "wageless",
    "wageworking",
    "wailful",
    "wailsome",
    "waiting",
    "wakeful",
    "wakeless",
    "walking",
    "wandering",
    "wanted",
    "warless",
    "warlike",
    "warm",
    "warm-blooded",
    "warm-hearted",
    "warmish",
    "warmthless ",
    "warriorlike",
    "wartlike",
    "warty",
    "wary",
    "washable",
    "washed-out",
    "washed-up",
    "waspish",
    "waspy",
    "wasteful",
    "watchful",
    "water-repellent",
    "water-resistant",
    "waterborne",
    "waterbreathing",
    "watercolour",
    "watered-down",
    "waterish",
    "waterlocked",
    "waterlog",
    "waterlogged",
    "waterproof",
    "watertight",
    "waterworn",
    "watery",
    "wavy",
    "wax",
    "waxy",
    "wayfaring",
    "wayward",
    "weak",
    "weak-minded",
    "weakened",
    "weakhanded",
    "weakish",
    "weakly",
    "weakwilled",
    "wealthy",
    "wealthy",
    "weaponed",
    "weaponised",
    "weaponless",
    "wearable",
    "wearied",
    "weariful",
    "weariless",
    "wearing",
    "wearish",
    "wearisome",
    "wearproof",
    "wearying",
    "weary",
    "weather-beaten",
    "weathered",
    "weatherproof",
    "weathertight",
    "weatherworn",
    "webbed",
    "webby",
    "wedded",
    "wee",
    "weedy",
    "weeping",
    "weepy",
    "weighable",
    "weighted",
    "weightless",
    "weighty",
    "weird",
    "welcome",
    "well",
    "well-accepted",
    "well-beloved",
    "well-blacked",
    "well-born",
    "well-browned",
    "well-coloured",
    "well-cultured",
    "well-desired",
    "well-destroyed",
    "well-dramatized",
    "well-dressed",
    "well-educated",
    "well-freckled",
    "well-groomed",
    "well-knotted",
    "well-known",
    "well-loved",
    "well-made",
    "well-mannered",
    "well-needed",
    "well-off",
    "well-philosophised",
    "well-pleased",
    "well-policed",
    "well-understood",
    "werewolf-like",
    "westbound",
    "western",
    "westernmost",
    "wet-proof",
    "wetproof",
    "wettish",
    "whacky",
    "wheat",
    "wheezy",
    "whimsical",
    "white",
    "white-collar",
    "white-faced",
    "white-livered",
    "whited",
    "whitish",
    "whole-souled",
    "whole-wheat",
    "wholehearted",
    "wholesome",
    "wicked",
    "wide",
    "wide-awake",
    "wide-eyed",
    "widespread",
    "widish",
    "wieldable",
    "wieldy",
    "wifely",
    "wild",
    "wilful",
    "willing",
    "wily",
    "wimpy",
    "winded",
    "windowy",
    "windy",
    "winged",
    "wingless",
    "winning",
    "winsome",
    "winter-hardy",
    "winterish",
    "wintery",
    "wintry",
    "wired",
    "wisdomless",
    "wise",
    "wised",
    "wishful",
    "wispy",
    "wisteria",
    "wistful",
    "witching",
    "witchy",
    "witless",
    "witted",
    "witting",
    "witty",
    "wizardlike",
    "wizardly",
    "woebegone",
    "woeful",
    "woesome",
    "wolfish",
    "wolflike",
    "womanish",
    "womanly",
    "wonder-stricken",
    "wonderful",
    "wondrous",
    "wood",
    "wood-block",
    "wooded",
    "wooden",
    "wooden-headed",
    "woodsy",
    "woody",
    "wool",
    "woollen",
    "woolly",
    "woolly-headed",
    "woozy",
    "word-perfect",
    "wordy",
    "working",
    "working-class",
    "worldly-minded",
    "worldly-wise",
    "worldwide",
    "wormish",
    "wormlike",
    "wormy",
    "worn-out",
    "worried",
    "worriless",
    "worrisome",
    "worrying",
    "worse",
    "worthless",
    "worthwhile",
    "worthy",
    "wounded",
    "wraith-like",
    "wraithlike",
    "wrapped",
    "wrathful",
    "wretched",
    "wrinkleable",
    "wrinkled",
    "wrinkleless",
    "wrinkly",
    "written",
    "wrong-headed",
    "wrongful",
    "wroth",
    "wrought-iron",
    "wuthering",
    "xanadu",
    "xenolith",
    "xenophobic",
    "xerophagous",
    "xerophobic",
    "xylophagous",
    "yeasty",
    "yellow",
    "yellow-bellied",
    "yellowish",
    "yester",
    "yestern",
    "yielding",
    "yokelish",
    "young",
    "youthful",
    "yummy",
    "zany	",
    "zanyish",
    "zealous",
    "zebra-print",
    "zebraic",
    "zebraprint",
    "zebrine",
    "zincic",
    "zinciferous",
    "zincky",
    "zincoid",
    "zincous",
    "zincy",
    "zinnwaldite",
    "zippered",
    "zippy",
    "zircon",
    "zodiacal",
    "zoisite",
    "zombie",
    "zombified",
    "zoographic",
    "zoographical",
    "zoolatrous ",
    "zoological",
    "zoometric",
    "zoometrical",
    "zoophagous",
    "zoophobic",
]
#  }}}


class CorrectHorseBatteryStaple:
    def __init__(self, nouns, adjectives):
        self.nouns = [noun.strip() for noun in nouns if noun.strip()]
        self.adjectives = [
            adjective.strip() for adjective in adjectives if adjective.strip()
        ]

    def generate(self):
        return "{} {} {} {}".format(
            random.choice(self.adjectives),
            random.choice(self.nouns),
            random.choice(self.nouns),
            random.choice(self.nouns),
        )


def make_resp(data):
    return f"""\
HTTP/1.1 200 OK
Server: correcthorsebatterystaple/1.0.0
Content-Type: text/plain
Content-Length: {len(data)}

{data}"""


def single_server(host, port, correcthorsebatterystaple):
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
        sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        print(f"Server starting on {host}:{port}")
        sock.bind((host, port))
        sock.listen(10)
        try:
            while True:
                client, addr = sock.accept()
                data = client.recv(4096)  # This should be enough for the HTML header
                client.send(make_resp(correcthorsebatterystaple.generate()).encode())
                client.close()
        except KeyboardInterrupt:
            print("Bye")


def select_server(host, port, correcthorsebatterystaple):
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
        sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        print(f"Server starting on {host}:{port}")
        sock.bind((host, port))
        sock.listen(10)
        try:
            waiting_for_request = [sock]
            waiting_for_response = []
            while True:
                read_list = [sock]
                readable, writable, errored = select.select(
                    waiting_for_request, waiting_for_response, []
                )
                for s in writable:
                    s.send(make_resp(correcthorsebatterystaple.generate()).encode())
                    s.close()
                    waiting_for_response.remove(s)
                for s in readable:
                    if s is sock:
                        client, addr = sock.accept()
                        waiting_for_request.append(client)
                    else:
                        data = s.recv(4096)  # But... really we don't care.
                        # literally any request is going to get back a
                        # correct horse battery staple
                        waiting_for_response.append(s)
                        waiting_for_request.remove(s)
        except KeyboardInterrupt:
            print("Bye")


def epoll_server(host, port, correcthorsebatterystaple):
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
        sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        print(f"Server starting on {host}:{port}")
        sock.bind((host, port))
        sock.listen(10)
        sock.setblocking(0)

        epoll = select.epoll()
        epoll.register(sock.fileno(), select.EPOLLIN)
        try:
            connections = {}
            while True:
                events = epoll.poll(1)
                for fileno, event in events:
                    if fileno == sock.fileno():
                        conn, addr = sock.accept()
                        conn.setblocking(0)
                        epoll.register(conn.fileno(), select.EPOLLIN)
                        connections[conn.fileno()] = conn
                    elif event & select.EPOLLIN:
                        data = connections[fileno].recv(
                            4096
                        )  # Don't care about this data either
                        epoll.modify(fileno, select.EPOLLOUT)
                    elif event & select.EPOLLOUT:
                        connections[fileno].send(
                            make_resp(correcthorsebatterystaple.generate()).encode()
                        )
                        epoll.modify(fileno, 0)
                        connections[fileno].shutdown(socket.SHUT_RDWR)
                    elif event & select.EPOLLHUP:
                        epoll.unregister(fileno)
                        connections[fileno].close()
                        del connections[fileno]
        except KeyboardInterrupt:
            print("Bye")
        finally:
            epoll.unregister(sock.fileno())
            epoll.close()


def ok_go(launch="single", host="127.0.0.1", port=80, gen=None):
    if launch == "single":
        single_server(host=host, port=port, correcthorsebatterystaple=gen)
    elif launch == "select":
        select_server(host=host, port=port, correcthorsebatterystaple=gen)
    elif launch == "epoll":
        epoll_server(host=host, port=port, correcthorsebatterystaple=gen)
    else:
        sys.exit("No launcher {} known!".format(launch))


def do_it():  # Shia LeBeouf!
    args = parser.parse_args()
    if args.version:
        print(__version__)
        sys.exit()
    root = args.root
    stapelerfahrer = CorrectHorseBatteryStaple(nouns=NOUNS, adjectives=ADJECTIVES)

    if args.one:
        print(stapelerfahrer.generate())
    else:
        ok_go(launch=args.launch, host=args.host, port=args.port, gen=stapelerfahrer)


if __name__ == "__main__":
    do_it()
